#ifndef CGS_SGENT_UTF_H
#define CGS_SGENT_UTF_H 1

/*
*    SGML entity to UTF-8
*    Is used before conversion to lower case, so this table is mixed case.
*
*    Warning: The char array sizes below are on the edge;
*    Keep track of sizes when you add new entities.
*
*    This file is based on:
*    https://www.w3.org/2003/entities/2007xml/unicode.xml.zip
*    See:
*    https://www.w3.org/Consortium/Legal/2002/copyright-software-20021231.html
*/

/*  At least one longer then the largest SGML entity  */
#define CGS_ENT_SIZ 36
/*  At least one longer then the largest UTF-8 multi byte string  */
#define CGS_UTF_SIZ  8
enum { CGS_ENT_MAX  = CGS_ENT_SIZ - 1 };
enum { CGS_ENT_MAX2 = CGS_ENT_MAX - 1 };

/*  Total size is multiple of eight  */
struct sgent2u {
	char ent[CGS_ENT_SIZ];
	char utf[CGS_UTF_SIZ];
	int  len;
};

struct sgent2u sgent2utab[] = { \
	/*  LATIN CAPITAL LETTER AE  */
	{ "AElig", "\xc3\x86", 2 },
	/*  AMPERSAND  */
	{ "AMP", "\x26", 1 },
	/*  GREEK CAPITAL LETTER ALPHA WITH TONOS  */
	{ "Aacgr", "\xce\x86", 2 },
	/*  LATIN CAPITAL LETTER A WITH ACUTE  */
	{ "Aacute", "\xc3\x81", 2 },
	/*  LATIN CAPITAL LETTER A WITH BREVE  */
	{ "Abreve", "\xc4\x82", 2 },
	/*  LATIN CAPITAL LETTER A WITH CIRCUMFLEX  */
	{ "Acirc", "\xc3\x82", 2 },
	/*  CYRILLIC CAPITAL LETTER A  */
	{ "Acy", "\xd0\x90", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL A  */
	{ "Afr", "\xf0\x9d\x94\x84", 4 },
	/*  GREEK CAPITAL LETTER ALPHA  */
	{ "Agr", "\xce\x91", 2 },
	/*  LATIN CAPITAL LETTER A WITH GRAVE  */
	{ "Agrave", "\xc3\x80", 2 },
	/*  GREEK CAPITAL LETTER ALPHA  */
	{ "Alpha", "\xce\x91", 2 },
	/*  LATIN CAPITAL LETTER A WITH MACRON  */
	{ "Amacr", "\xc4\x80", 2 },
	/*  DOUBLE LOGICAL AND  */
	{ "And", "\xe2\xa9\x93", 3 },
	/*  LATIN CAPITAL LETTER A WITH OGONEK  */
	{ "Aogon", "\xc4\x84", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL A  */
	{ "Aopf", "\xf0\x9d\x94\xb8", 4 },
	/*  FUNCTION APPLICATION  */
	{ "ApplyFunction", "\xe2\x81\xa1", 3 },
	/*  LATIN CAPITAL LETTER A WITH RING ABOVE  */
	{ "Aring", "\xc3\x85", 2 },
	/*  MATHEMATICAL SCRIPT CAPITAL A  */
	{ "Ascr", "\xf0\x9d\x92\x9c", 4 },
	/*  COLON EQUALS  */
	{ "Assign", "\xe2\x89\x94", 3 },
	/*  TWO ASTERISKS ALIGNED VERTICALLY  */
	{ "Ast", "\xe2\x81\x91", 3 },
	/*  LATIN CAPITAL LETTER A WITH TILDE  */
	{ "Atilde", "\xc3\x83", 2 },
	/*  LATIN CAPITAL LETTER A WITH DIAERESIS  */
	{ "Auml", "\xc3\x84", 2 },
	/*  SET MINUS  */
	{ "Backslash", "\xe2\x88\x96", 3 },
	/*  INTEGRAL WITH DOUBLE STROKE  */
	{ "Barint", "\xe2\xa8\x8e", 3 },
	/*  SHORT DOWN TACK WITH OVERBAR  */
	{ "Barv", "\xe2\xab\xa7", 3 },
	/*  PERSPECTIVE  */
	{ "Barwed", "\xe2\x8c\x86", 3 },
	/*  LOGICAL AND WITH DOUBLE OVERBAR  */
	{ "Barwedl", "\xe2\xa9\x9e", 3 },
	/*  CYRILLIC CAPITAL LETTER BE  */
	{ "Bcy", "\xd0\x91", 2 },
	/*  BECAUSE  */
	{ "Because", "\xe2\x88\xb5", 3 },
	/*  SCRIPT CAPITAL B  */
	{ "Bernoullis", "\xe2\x84\xac", 3 },
	/*  GREEK CAPITAL LETTER BETA  */
	{ "Beta", "\xce\x92", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL B  */
	{ "Bfr", "\xf0\x9d\x94\x85", 4 },
	/*  GREEK CAPITAL LETTER BETA  */
	{ "Bgr", "\xce\x92", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL B  */
	{ "Bopf", "\xf0\x9d\x94\xb9", 4 },
	/*  BREVE  */
	{ "Breve", "\xcb\x98", 2 },
	/*  SCRIPT CAPITAL B  */
	{ "Bscr", "\xe2\x84\xac", 3 },
	/*  GEOMETRICALLY EQUIVALENT TO  */
	{ "Bumpeq", "\xe2\x89\x8e", 3 },
	/*  BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL  */
	{ "Bvert", "\xe2\x94\x86", 3 },
	/*  CYRILLIC CAPITAL LETTER CHE  */
	{ "CHcy", "\xd0\xa7", 2 },
	/*  COPYRIGHT SIGN  */
	{ "COPY", "\xc2\xa9", 2 },
	/*  LATIN CAPITAL LETTER C WITH ACUTE  */
	{ "Cacute", "\xc4\x86", 2 },
	/*  DOUBLE INTERSECTION  */
	{ "Cap", "\xe2\x8b\x92", 3 },
	/*  DOUBLE-STRUCK ITALIC CAPITAL D  */
	{ "CapitalDifferentialD", "\xe2\x85\x85", 3 },
	/*  BLACK-LETTER CAPITAL C  */
	{ "Cayleys", "\xe2\x84\xad", 3 },
	/*  LATIN CAPITAL LETTER C WITH CARON  */
	{ "Ccaron", "\xc4\x8c", 2 },
	/*  LATIN CAPITAL LETTER C WITH CEDILLA  */
	{ "Ccedil", "\xc3\x87", 2 },
	/*  LATIN CAPITAL LETTER C WITH CIRCUMFLEX  */
	{ "Ccirc", "\xc4\x88", 2 },
	/*  VOLUME INTEGRAL  */
	{ "Cconint", "\xe2\x88\xb0", 3 },
	/*  LATIN CAPITAL LETTER C WITH DOT ABOVE  */
	{ "Cdot", "\xc4\x8a", 2 },
	/*  CEDILLA  */
	{ "Cedilla", "\xc2\xb8", 2 },
	/*  MIDDLE DOT  */
	{ "CenterDot", "\xc2\xb7", 2 },
	/*  BLACK-LETTER CAPITAL C  */
	{ "Cfr", "\xe2\x84\xad", 3 },
	/*  GREEK CAPITAL LETTER CHI  */
	{ "Chi", "\xce\xa7", 2 },
	/*  CIRCLED DOT OPERATOR  */
	{ "CircleDot", "\xe2\x8a\x99", 3 },
	/*  CIRCLED MINUS  */
	{ "CircleMinus", "\xe2\x8a\x96", 3 },
	/*  CIRCLED PLUS  */
	{ "CirclePlus", "\xe2\x8a\x95", 3 },
	/*  CIRCLED TIMES  */
	{ "CircleTimes", "\xe2\x8a\x97", 3 },
	/*  CLOCKWISE CONTOUR INTEGRAL  */
	{ "ClockwiseContourIntegral", "\xe2\x88\xb2", 3 },
	/*  RIGHT DOUBLE QUOTATION MARK  */
	{ "CloseCurlyDoubleQuote", "\xe2\x80\x9d", 3 },
	/*  RIGHT SINGLE QUOTATION MARK  */
	{ "CloseCurlyQuote", "\xe2\x80\x99", 3 },
	/*  PROPORTION  */
	{ "Colon", "\xe2\x88\xb7", 3 },
	/*  DOUBLE COLON EQUAL  */
	{ "Colone", "\xe2\xa9\xb4", 3 },
	/*  IDENTICAL TO  */
	{ "Congruent", "\xe2\x89\xa1", 3 },
	/*  SURFACE INTEGRAL  */
	{ "Conint", "\xe2\x88\xaf", 3 },
	/*  CONTOUR INTEGRAL  */
	{ "ContourIntegral", "\xe2\x88\xae", 3 },
	/*  DOUBLE-STRUCK CAPITAL C  */
	{ "Copf", "\xe2\x84\x82", 3 },
	/*  N-ARY COPRODUCT  */
	{ "Coproduct", "\xe2\x88\x90", 3 },
	/*  ANTICLOCKWISE CONTOUR INTEGRAL  */
	{ "CounterClockwiseContourIntegral", "\xe2\x88\xb3", 3 },
	/*  VECTOR OR CROSS PRODUCT  */
	{ "Cross", "\xe2\xa8\xaf", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL C  */
	{ "Cscr", "\xf0\x9d\x92\x9e", 4 },
	/*  DOUBLE UNION  */
	{ "Cup", "\xe2\x8b\x93", 3 },
	/*  EQUIVALENT TO  */
	{ "CupCap", "\xe2\x89\x8d", 3 },
	/*  DOUBLE-STRUCK ITALIC CAPITAL D  */
	{ "DD", "\xe2\x85\x85", 3 },
	/*  RIGHTWARDS ARROW WITH DOTTED STEM  */
	{ "DDotrahd", "\xe2\xa4\x91", 3 },
	/*  CYRILLIC CAPITAL LETTER DJE  */
	{ "DJcy", "\xd0\x82", 2 },
	/*  CYRILLIC CAPITAL LETTER DZE  */
	{ "DScy", "\xd0\x85", 2 },
	/*  CYRILLIC CAPITAL LETTER DZHE  */
	{ "DZcy", "\xd0\x8f", 2 },
	/*  DOUBLE DAGGER  */
	{ "Dagger", "\xe2\x80\xa1", 3 },
	/*  DOWNWARDS TWO HEADED ARROW  */
	{ "Darr", "\xe2\x86\xa1", 3 },
	/*  VERTICAL BAR DOUBLE LEFT TURNSTILE  */
	{ "Dashv", "\xe2\xab\xa4", 3 },
	/*  LATIN CAPITAL LETTER D WITH CARON  */
	{ "Dcaron", "\xc4\x8e", 2 },
	/*  CYRILLIC CAPITAL LETTER DE  */
	{ "Dcy", "\xd0\x94", 2 },
	/*  NABLA  */
	{ "Del", "\xe2\x88\x87", 3 },
	/*  GREEK CAPITAL LETTER DELTA  */
	{ "Delta", "\xce\x94", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL D  */
	{ "Dfr", "\xf0\x9d\x94\x87", 4 },
	/*  GREEK CAPITAL LETTER DELTA  */
	{ "Dgr", "\xce\x94", 2 },
	/*  ACUTE ACCENT  */
	{ "DiacriticalAcute", "\xc2\xb4", 2 },
	/*  DOT ABOVE  */
	{ "DiacriticalDot", "\xcb\x99", 2 },
	/*  DOUBLE ACUTE ACCENT  */
	{ "DiacriticalDoubleAcute", "\xcb\x9d", 2 },
	/*  GRAVE ACCENT  */
	{ "DiacriticalGrave", "\x60", 1 },
	/*  SMALL TILDE  */
	{ "DiacriticalTilde", "\xcb\x9c", 2 },
	/*  DIAMOND OPERATOR  */
	{ "Diamond", "\xe2\x8b\x84", 3 },
	/*  DOUBLE-STRUCK ITALIC SMALL D  */
	{ "DifferentialD", "\xe2\x85\x86", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL D  */
	{ "Dopf", "\xf0\x9d\x94\xbb", 4 },
	/*  DIAERESIS  */
	{ "Dot", "\xc2\xa8", 2 },
	/*  COMBINING FOUR DOTS ABOVE  */
	{ "DotDot", "\xe2\x83\x9c", 3 },
	/*  APPROACHES THE LIMIT  */
	{ "DotEqual", "\xe2\x89\x90", 3 },
	/*  SURFACE INTEGRAL  */
	{ "DoubleContourIntegral", "\xe2\x88\xaf", 3 },
	/*  DIAERESIS  */
	{ "DoubleDot", "\xc2\xa8", 2 },
	/*  DOWNWARDS DOUBLE ARROW  */
	{ "DoubleDownArrow", "\xe2\x87\x93", 3 },
	/*  LEFTWARDS DOUBLE ARROW  */
	{ "DoubleLeftArrow", "\xe2\x87\x90", 3 },
	/*  LEFT RIGHT DOUBLE ARROW  */
	{ "DoubleLeftRightArrow", "\xe2\x87\x94", 3 },
	/*  VERTICAL BAR DOUBLE LEFT TURNSTILE  */
	{ "DoubleLeftTee", "\xe2\xab\xa4", 3 },
	/*  LONG LEFTWARDS DOUBLE ARROW  */
	{ "DoubleLongLeftArrow", "\xe2\x9f\xb8", 3 },
	/*  LONG LEFT RIGHT DOUBLE ARROW  */
	{ "DoubleLongLeftRightArrow", "\xe2\x9f\xba", 3 },
	/*  LONG RIGHTWARDS DOUBLE ARROW  */
	{ "DoubleLongRightArrow", "\xe2\x9f\xb9", 3 },
	/*  RIGHTWARDS DOUBLE ARROW  */
	{ "DoubleRightArrow", "\xe2\x87\x92", 3 },
	/*  TRUE  */
	{ "DoubleRightTee", "\xe2\x8a\xa8", 3 },
	/*  UPWARDS DOUBLE ARROW  */
	{ "DoubleUpArrow", "\xe2\x87\x91", 3 },
	/*  UP DOWN DOUBLE ARROW  */
	{ "DoubleUpDownArrow", "\xe2\x87\x95", 3 },
	/*  PARALLEL TO  */
	{ "DoubleVerticalBar", "\xe2\x88\xa5", 3 },
	/*  DOWNWARDS ARROW  */
	{ "DownArrow", "\xe2\x86\x93", 3 },
	/*  DOWNWARDS ARROW TO BAR  */
	{ "DownArrowBar", "\xe2\xa4\x93", 3 },
	/*  DOWNWARDS ARROW LEFTWARDS OF UPWARDS ARROW  */
	{ "DownArrowUpArrow", "\xe2\x87\xb5", 3 },
	/*  COMBINING INVERTED BREVE  */
	{ "DownBreve", "\xcc\x91", 2 },
	/*  LEFT BARB DOWN RIGHT BARB DOWN HARPOON  */
	{ "DownLeftRightVector", "\xe2\xa5\x90", 3 },
	/*  LEFTWARDS HARPOON WITH BARB DOWN FROM BAR  */
	{ "DownLeftTeeVector", "\xe2\xa5\x9e", 3 },
	/*  LEFTWARDS HARPOON WITH BARB DOWNWARDS  */
	{ "DownLeftVector", "\xe2\x86\xbd", 3 },
	/*  LEFTWARDS HARPOON WITH BARB DOWN TO BAR  */
	{ "DownLeftVectorBar", "\xe2\xa5\x96", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWN FROM BAR  */
	{ "DownRightTeeVector", "\xe2\xa5\x9f", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWNWARDS  */
	{ "DownRightVector", "\xe2\x87\x81", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWN TO BAR  */
	{ "DownRightVectorBar", "\xe2\xa5\x97", 3 },
	/*  DOWN TACK  */
	{ "DownTee", "\xe2\x8a\xa4", 3 },
	/*  DOWNWARDS ARROW FROM BAR  */
	{ "DownTeeArrow", "\xe2\x86\xa7", 3 },
	/*  DOWNWARDS DOUBLE ARROW  */
	{ "Downarrow", "\xe2\x87\x93", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL D  */
	{ "Dscr", "\xf0\x9d\x92\x9f", 4 },
	/*  LATIN CAPITAL LETTER D WITH STROKE  */
	{ "Dstrok", "\xc4\x90", 2 },
	/*  GREEK CAPITAL LETTER ETA WITH TONOS  */
	{ "EEacgr", "\xce\x89", 2 },
	/*  GREEK CAPITAL LETTER ETA  */
	{ "EEgr", "\xce\x97", 2 },
	/*  LATIN CAPITAL LETTER ENG  */
	{ "ENG", "\xc5\x8a", 2 },
	/*  LATIN CAPITAL LETTER ETH  */
	{ "ETH", "\xc3\x90", 2 },
	/*  GREEK CAPITAL LETTER EPSILON WITH TONOS  */
	{ "Eacgr", "\xce\x88", 2 },
	/*  LATIN CAPITAL LETTER E WITH ACUTE  */
	{ "Eacute", "\xc3\x89", 2 },
	/*  LATIN CAPITAL LETTER E WITH CARON  */
	{ "Ecaron", "\xc4\x9a", 2 },
	/*  LATIN CAPITAL LETTER E WITH CIRCUMFLEX  */
	{ "Ecirc", "\xc3\x8a", 2 },
	/*  CYRILLIC CAPITAL LETTER E  */
	{ "Ecy", "\xd0\xad", 2 },
	/*  LATIN CAPITAL LETTER E WITH DOT ABOVE  */
	{ "Edot", "\xc4\x96", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL E  */
	{ "Efr", "\xf0\x9d\x94\x88", 4 },
	/*  GREEK CAPITAL LETTER EPSILON  */
	{ "Egr", "\xce\x95", 2 },
	/*  LATIN CAPITAL LETTER E WITH GRAVE  */
	{ "Egrave", "\xc3\x88", 2 },
	/*  ELEMENT OF  */
	{ "Element", "\xe2\x88\x88", 3 },
	/*  LATIN CAPITAL LETTER E WITH MACRON  */
	{ "Emacr", "\xc4\x92", 2 },
	/*  WHITE MEDIUM SQUARE  */
	{ "EmptySmallSquare", "\xe2\x97\xbb", 3 },
	/*  WHITE SMALL SQUARE  */
	{ "EmptyVerySmallSquare", "\xe2\x96\xab", 3 },
	/*  LATIN CAPITAL LETTER E WITH OGONEK  */
	{ "Eogon", "\xc4\x98", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL E  */
	{ "Eopf", "\xf0\x9d\x94\xbc", 4 },
	/*  GREEK CAPITAL LETTER EPSILON  */
	{ "Epsilon", "\xce\x95", 2 },
	/*  TWO CONSECUTIVE EQUALS SIGNS  */
	{ "Equal", "\xe2\xa9\xb5", 3 },
	/*  MINUS TILDE  */
	{ "EqualTilde", "\xe2\x89\x82", 3 },
	/*  RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON  */
	{ "Equilibrium", "\xe2\x87\x8c", 3 },
	/*  SCRIPT CAPITAL E  */
	{ "Escr", "\xe2\x84\xb0", 3 },
	/*  EQUALS SIGN ABOVE TILDE OPERATOR  */
	{ "Esim", "\xe2\xa9\xb3", 3 },
	/*  GREEK CAPITAL LETTER ETA  */
	{ "Eta", "\xce\x97", 2 },
	/*  LATIN CAPITAL LETTER E WITH DIAERESIS  */
	{ "Euml", "\xc3\x8b", 2 },
	/*  THERE EXISTS  */
	{ "Exists", "\xe2\x88\x83", 3 },
	/*  DOUBLE-STRUCK ITALIC SMALL E  */
	{ "ExponentialE", "\xe2\x85\x87", 3 },
	/*  CYRILLIC CAPITAL LETTER EF  */
	{ "Fcy", "\xd0\xa4", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL F  */
	{ "Ffr", "\xf0\x9d\x94\x89", 4 },
	/*  BLACK MEDIUM SQUARE  */
	{ "FilledSmallSquare", "\xe2\x97\xbc", 3 },
	/*  BLACK SMALL SQUARE  */
	{ "FilledVerySmallSquare", "\xe2\x96\xaa", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL F  */
	{ "Fopf", "\xf0\x9d\x94\xbd", 4 },
	/*  FOR ALL  */
	{ "ForAll", "\xe2\x88\x80", 3 },
	/*  SCRIPT CAPITAL F  */
	{ "Fouriertrf", "\xe2\x84\xb1", 3 },
	/*  SCRIPT CAPITAL F  */
	{ "Fscr", "\xe2\x84\xb1", 3 },
	/*  CYRILLIC CAPITAL LETTER GJE  */
	{ "GJcy", "\xd0\x83", 2 },
	/*  GREATER-THAN SIGN  */
	{ "GT", "\x3e", 1 },
	/*  TURNED SANS-SERIF CAPITAL G  */
	{ "Game", "\xe2\x85\x81", 3 },
	/*  GREEK CAPITAL LETTER GAMMA  */
	{ "Gamma", "\xce\x93", 2 },
	/*  GREEK LETTER DIGAMMA  */
	{ "Gammad", "\xcf\x9c", 2 },
	/*  LATIN CAPITAL LETTER G WITH BREVE  */
	{ "Gbreve", "\xc4\x9e", 2 },
	/*  LATIN CAPITAL LETTER G WITH CEDILLA  */
	{ "Gcedil", "\xc4\xa2", 2 },
	/*  LATIN CAPITAL LETTER G WITH CIRCUMFLEX  */
	{ "Gcirc", "\xc4\x9c", 2 },
	/*  CYRILLIC CAPITAL LETTER GHE  */
	{ "Gcy", "\xd0\x93", 2 },
	/*  LATIN CAPITAL LETTER G WITH DOT ABOVE  */
	{ "Gdot", "\xc4\xa0", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL G  */
	{ "Gfr", "\xf0\x9d\x94\x8a", 4 },
	/*  VERY MUCH GREATER-THAN  */
	{ "Gg", "\xe2\x8b\x99", 3 },
	/*  GREEK CAPITAL LETTER GAMMA  */
	{ "Ggr", "\xce\x93", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL G  */
	{ "Gopf", "\xf0\x9d\x94\xbe", 4 },
	/*  GREATER-THAN OR EQUAL TO  */
	{ "GreaterEqual", "\xe2\x89\xa5", 3 },
	/*  GREATER-THAN EQUAL TO OR LESS-THAN  */
	{ "GreaterEqualLess", "\xe2\x8b\x9b", 3 },
	/*  GREATER-THAN OVER EQUAL TO  */
	{ "GreaterFullEqual", "\xe2\x89\xa7", 3 },
	/*  DOUBLE NESTED GREATER-THAN  */
	{ "GreaterGreater", "\xe2\xaa\xa2", 3 },
	/*  GREATER-THAN OR LESS-THAN  */
	{ "GreaterLess", "\xe2\x89\xb7", 3 },
	/*  GREATER-THAN OR SLANTED EQUAL TO  */
	{ "GreaterSlantEqual", "\xe2\xa9\xbe", 3 },
	/*  GREATER-THAN OR EQUIVALENT TO  */
	{ "GreaterTilde", "\xe2\x89\xb3", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL G  */
	{ "Gscr", "\xf0\x9d\x92\xa2", 4 },
	/*  MUCH GREATER-THAN  */
	{ "Gt", "\xe2\x89\xab", 3 },
	/*  CYRILLIC CAPITAL LETTER HARD SIGN  */
	{ "HARDcy", "\xd0\xaa", 2 },
	/*  CARON  */
	{ "Hacek", "\xcb\x87", 2 },
	/*  CIRCUMFLEX ACCENT  */
	{ "Hat", "\x5e", 1 },
	/*  LATIN CAPITAL LETTER H WITH CIRCUMFLEX  */
	{ "Hcirc", "\xc4\xa4", 2 },
	/*  BLACK-LETTER CAPITAL H  */
	{ "Hfr", "\xe2\x84\x8c", 3 },
	/*  SCRIPT CAPITAL H  */
	{ "HilbertSpace", "\xe2\x84\x8b", 3 },
	/*  DOUBLE-STRUCK CAPITAL H  */
	{ "Hopf", "\xe2\x84\x8d", 3 },
	/*  BOX DRAWINGS LIGHT HORIZONTAL  */
	{ "HorizontalLine", "\xe2\x94\x80", 3 },
	/*  SCRIPT CAPITAL H  */
	{ "Hscr", "\xe2\x84\x8b", 3 },
	/*  LATIN CAPITAL LETTER H WITH STROKE  */
	{ "Hstrok", "\xc4\xa6", 2 },
	/*  GEOMETRICALLY EQUIVALENT TO  */
	{ "HumpDownHump", "\xe2\x89\x8e", 3 },
	/*  DIFFERENCE BETWEEN  */
	{ "HumpEqual", "\xe2\x89\x8f", 3 },
	/*  CYRILLIC CAPITAL LETTER IE  */
	{ "IEcy", "\xd0\x95", 2 },
	/*  LATIN CAPITAL LIGATURE IJ  */
	{ "IJlig", "\xc4\xb2", 2 },
	/*  CYRILLIC CAPITAL LETTER IO  */
	{ "IOcy", "\xd0\x81", 2 },
	/*  GREEK CAPITAL LETTER IOTA WITH TONOS  */
	{ "Iacgr", "\xce\x8a", 2 },
	/*  LATIN CAPITAL LETTER I WITH ACUTE  */
	{ "Iacute", "\xc3\x8d", 2 },
	/*  LATIN CAPITAL LETTER I WITH CIRCUMFLEX  */
	{ "Icirc", "\xc3\x8e", 2 },
	/*  CYRILLIC CAPITAL LETTER I  */
	{ "Icy", "\xd0\x98", 2 },
	/*  GREEK CAPITAL LETTER IOTA WITH DIALYTIKA  */
	{ "Idigr", "\xce\xaa", 2 },
	/*  LATIN CAPITAL LETTER I WITH DOT ABOVE  */
	{ "Idot", "\xc4\xb0", 2 },
	/*  BLACK-LETTER CAPITAL I  */
	{ "Ifr", "\xe2\x84\x91", 3 },
	/*  GREEK CAPITAL LETTER IOTA  */
	{ "Igr", "\xce\x99", 2 },
	/*  LATIN CAPITAL LETTER I WITH GRAVE  */
	{ "Igrave", "\xc3\x8c", 2 },
	/*  BLACK-LETTER CAPITAL I  */
	{ "Im", "\xe2\x84\x91", 3 },
	/*  LATIN CAPITAL LETTER I WITH MACRON  */
	{ "Imacr", "\xc4\xaa", 2 },
	/*  DOUBLE-STRUCK ITALIC SMALL I  */
	{ "ImaginaryI", "\xe2\x85\x88", 3 },
	/*  RIGHTWARDS DOUBLE ARROW  */
	{ "Implies", "\xe2\x87\x92", 3 },
	/*  DOUBLE INTEGRAL  */
	{ "Int", "\xe2\x88\xac", 3 },
	/*  INTEGRAL  */
	{ "Integral", "\xe2\x88\xab", 3 },
	/*  N-ARY INTERSECTION  */
	{ "Intersection", "\xe2\x8b\x82", 3 },
	/*  INVISIBLE SEPARATOR  */
	{ "InvisibleComma", "\xe2\x81\xa3", 3 },
	/*  INVISIBLE TIMES  */
	{ "InvisibleTimes", "\xe2\x81\xa2", 3 },
	/*  LATIN CAPITAL LETTER I WITH OGONEK  */
	{ "Iogon", "\xc4\xae", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL I  */
	{ "Iopf", "\xf0\x9d\x95\x80", 4 },
	/*  GREEK CAPITAL LETTER IOTA  */
	{ "Iota", "\xce\x99", 2 },
	/*  SCRIPT CAPITAL I  */
	{ "Iscr", "\xe2\x84\x90", 3 },
	/*  LATIN CAPITAL LETTER I WITH TILDE  */
	{ "Itilde", "\xc4\xa8", 2 },
	/*  CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I  */
	{ "Iukcy", "\xd0\x86", 2 },
	/*  LATIN CAPITAL LETTER I WITH DIAERESIS  */
	{ "Iuml", "\xc3\x8f", 2 },
	/*  LATIN CAPITAL LETTER J WITH CIRCUMFLEX  */
	{ "Jcirc", "\xc4\xb4", 2 },
	/*  CYRILLIC CAPITAL LETTER SHORT I  */
	{ "Jcy", "\xd0\x99", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL J  */
	{ "Jfr", "\xf0\x9d\x94\x8d", 4 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL J  */
	{ "Jopf", "\xf0\x9d\x95\x81", 4 },
	/*  MATHEMATICAL SCRIPT CAPITAL J  */
	{ "Jscr", "\xf0\x9d\x92\xa5", 4 },
	/*  CYRILLIC CAPITAL LETTER JE  */
	{ "Jsercy", "\xd0\x88", 2 },
	/*  CYRILLIC CAPITAL LETTER UKRAINIAN IE  */
	{ "Jukcy", "\xd0\x84", 2 },
	/*  CYRILLIC CAPITAL LETTER HA  */
	{ "KHcy", "\xd0\xa5", 2 },
	/*  GREEK CAPITAL LETTER CHI  */
	{ "KHgr", "\xce\xa7", 2 },
	/*  CYRILLIC CAPITAL LETTER KJE  */
	{ "KJcy", "\xd0\x8c", 2 },
	/*  GREEK CAPITAL LETTER KAPPA  */
	{ "Kappa", "\xce\x9a", 2 },
	/*  LATIN CAPITAL LETTER K WITH CEDILLA  */
	{ "Kcedil", "\xc4\xb6", 2 },
	/*  CYRILLIC CAPITAL LETTER KA  */
	{ "Kcy", "\xd0\x9a", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL K  */
	{ "Kfr", "\xf0\x9d\x94\x8e", 4 },
	/*  GREEK CAPITAL LETTER KAPPA  */
	{ "Kgr", "\xce\x9a", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL K  */
	{ "Kopf", "\xf0\x9d\x95\x82", 4 },
	/*  MATHEMATICAL SCRIPT CAPITAL K  */
	{ "Kscr", "\xf0\x9d\x92\xa6", 4 },
	/*  CYRILLIC CAPITAL LETTER LJE  */
	{ "LJcy", "\xd0\x89", 2 },
	/*  LESS-THAN SIGN  */
	{ "LT", "\x3c", 1 },
	/*  LATIN CAPITAL LETTER L WITH ACUTE  */
	{ "Lacute", "\xc4\xb9", 2 },
	/*  GREEK CAPITAL LETTER LAMDA  */
	{ "Lambda", "\xce\x9b", 2 },
	/*  MATHEMATICAL LEFT DOUBLE ANGLE BRACKET  */
	{ "Lang", "\xe2\x9f\xaa", 3 },
	/*  SCRIPT CAPITAL L  */
	{ "Laplacetrf", "\xe2\x84\x92", 3 },
	/*  LEFTWARDS TWO HEADED ARROW  */
	{ "Larr", "\xe2\x86\x9e", 3 },
	/*  LATIN CAPITAL LETTER L WITH CARON  */
	{ "Lcaron", "\xc4\xbd", 2 },
	/*  LATIN CAPITAL LETTER L WITH CEDILLA  */
	{ "Lcedil", "\xc4\xbb", 2 },
	/*  CYRILLIC CAPITAL LETTER EL  */
	{ "Lcy", "\xd0\x9b", 2 },
	/*  MATHEMATICAL LEFT ANGLE BRACKET  */
	{ "LeftAngleBracket", "\xe2\x9f\xa8", 3 },
	/*  LEFTWARDS ARROW  */
	{ "LeftArrow", "\xe2\x86\x90", 3 },
	/*  LEFTWARDS ARROW TO BAR  */
	{ "LeftArrowBar", "\xe2\x87\xa4", 3 },
	/*  LEFTWARDS ARROW OVER RIGHTWARDS ARROW  */
	{ "LeftArrowRightArrow", "\xe2\x87\x86", 3 },
	/*  LEFT CEILING  */
	{ "LeftCeiling", "\xe2\x8c\x88", 3 },
	/*  MATHEMATICAL LEFT WHITE SQUARE BRACKET  */
	{ "LeftDoubleBracket", "\xe2\x9f\xa6", 3 },
	/*  DOWNWARDS HARPOON WITH BARB LEFT FROM BAR  */
	{ "LeftDownTeeVector", "\xe2\xa5\xa1", 3 },
	/*  DOWNWARDS HARPOON WITH BARB LEFTWARDS  */
	{ "LeftDownVector", "\xe2\x87\x83", 3 },
	/*  DOWNWARDS HARPOON WITH BARB LEFT TO BAR  */
	{ "LeftDownVectorBar", "\xe2\xa5\x99", 3 },
	/*  LEFT FLOOR  */
	{ "LeftFloor", "\xe2\x8c\x8a", 3 },
	/*  LEFT RIGHT ARROW  */
	{ "LeftRightArrow", "\xe2\x86\x94", 3 },
	/*  LEFT BARB UP RIGHT BARB UP HARPOON  */
	{ "LeftRightVector", "\xe2\xa5\x8e", 3 },
	/*  LEFT TACK  */
	{ "LeftTee", "\xe2\x8a\xa3", 3 },
	/*  LEFTWARDS ARROW FROM BAR  */
	{ "LeftTeeArrow", "\xe2\x86\xa4", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UP FROM BAR  */
	{ "LeftTeeVector", "\xe2\xa5\x9a", 3 },
	/*  NORMAL SUBGROUP OF  */
	{ "LeftTriangle", "\xe2\x8a\xb2", 3 },
	/*  LEFT TRIANGLE BESIDE VERTICAL BAR  */
	{ "LeftTriangleBar", "\xe2\xa7\x8f", 3 },
	/*  NORMAL SUBGROUP OF OR EQUAL TO  */
	{ "LeftTriangleEqual", "\xe2\x8a\xb4", 3 },
	/*  UP BARB LEFT DOWN BARB LEFT HARPOON  */
	{ "LeftUpDownVector", "\xe2\xa5\x91", 3 },
	/*  UPWARDS HARPOON WITH BARB LEFT FROM BAR  */
	{ "LeftUpTeeVector", "\xe2\xa5\xa0", 3 },
	/*  UPWARDS HARPOON WITH BARB LEFTWARDS  */
	{ "LeftUpVector", "\xe2\x86\xbf", 3 },
	/*  UPWARDS HARPOON WITH BARB LEFT TO BAR  */
	{ "LeftUpVectorBar", "\xe2\xa5\x98", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UPWARDS  */
	{ "LeftVector", "\xe2\x86\xbc", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UP TO BAR  */
	{ "LeftVectorBar", "\xe2\xa5\x92", 3 },
	/*  LEFTWARDS DOUBLE ARROW  */
	{ "Leftarrow", "\xe2\x87\x90", 3 },
	/*  LEFT RIGHT DOUBLE ARROW  */
	{ "Leftrightarrow", "\xe2\x87\x94", 3 },
	/*  LESS-THAN EQUAL TO OR GREATER-THAN  */
	{ "LessEqualGreater", "\xe2\x8b\x9a", 3 },
	/*  LESS-THAN OVER EQUAL TO  */
	{ "LessFullEqual", "\xe2\x89\xa6", 3 },
	/*  LESS-THAN OR GREATER-THAN  */
	{ "LessGreater", "\xe2\x89\xb6", 3 },
	/*  DOUBLE NESTED LESS-THAN  */
	{ "LessLess", "\xe2\xaa\xa1", 3 },
	/*  LESS-THAN OR SLANTED EQUAL TO  */
	{ "LessSlantEqual", "\xe2\xa9\xbd", 3 },
	/*  LESS-THAN OR EQUIVALENT TO  */
	{ "LessTilde", "\xe2\x89\xb2", 3 },
	/*  MATHEMATICAL FRAKTUR CAPITAL L  */
	{ "Lfr", "\xf0\x9d\x94\x8f", 4 },
	/*  GREEK CAPITAL LETTER LAMDA  */
	{ "Lgr", "\xce\x9b", 2 },
	/*  VERY MUCH LESS-THAN  */
	{ "Ll", "\xe2\x8b\x98", 3 },
	/*  LEFTWARDS TRIPLE ARROW  */
	{ "Lleftarrow", "\xe2\x87\x9a", 3 },
	/*  LATIN CAPITAL LETTER L WITH MIDDLE DOT  */
	{ "Lmidot", "\xc4\xbf", 2 },
	/*  LONG LEFTWARDS ARROW  */
	{ "LongLeftArrow", "\xe2\x9f\xb5", 3 },
	/*  LONG LEFT RIGHT ARROW  */
	{ "LongLeftRightArrow", "\xe2\x9f\xb7", 3 },
	/*  LONG RIGHTWARDS ARROW  */
	{ "LongRightArrow", "\xe2\x9f\xb6", 3 },
	/*  LONG LEFTWARDS DOUBLE ARROW  */
	{ "Longleftarrow", "\xe2\x9f\xb8", 3 },
	/*  LONG LEFT RIGHT DOUBLE ARROW  */
	{ "Longleftrightarrow", "\xe2\x9f\xba", 3 },
	/*  LONG RIGHTWARDS DOUBLE ARROW  */
	{ "Longrightarrow", "\xe2\x9f\xb9", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL L  */
	{ "Lopf", "\xf0\x9d\x95\x83", 4 },
	/*  SOUTH WEST ARROW  */
	{ "LowerLeftArrow", "\xe2\x86\x99", 3 },
	/*  SOUTH EAST ARROW  */
	{ "LowerRightArrow", "\xe2\x86\x98", 3 },
	/*  SCRIPT CAPITAL L  */
	{ "Lscr", "\xe2\x84\x92", 3 },
	/*  UPWARDS ARROW WITH TIP LEFTWARDS  */
	{ "Lsh", "\xe2\x86\xb0", 3 },
	/*  LATIN CAPITAL LETTER L WITH STROKE  */
	{ "Lstrok", "\xc5\x81", 2 },
	/*  MUCH LESS-THAN  */
	{ "Lt", "\xe2\x89\xaa", 3 },
	/*  DOUBLE NESTED LESS-THAN WITH UNDERBAR  */
	{ "Ltbar", "\xe2\xaa\xa3", 3 },
	/*  RIGHTWARDS TWO-HEADED ARROW FROM BAR  */
	{ "Map", "\xe2\xa4\x85", 3 },
	/*  LEFTWARDS DOUBLE ARROW FROM BAR  */
	{ "Mapfrom", "\xe2\xa4\x86", 3 },
	/*  RIGHTWARDS DOUBLE ARROW FROM BAR  */
	{ "Mapto", "\xe2\xa4\x87", 3 },
	/*  CYRILLIC CAPITAL LETTER EM  */
	{ "Mcy", "\xd0\x9c", 2 },
	/*  MEDIUM MATHEMATICAL SPACE  */
	{ "MediumSpace", "\xe2\x81\x9f", 3 },
	/*  SCRIPT CAPITAL M  */
	{ "Mellintrf", "\xe2\x84\xb3", 3 },
	/*  MATHEMATICAL FRAKTUR CAPITAL M  */
	{ "Mfr", "\xf0\x9d\x94\x90", 4 },
	/*  GREEK CAPITAL LETTER MU  */
	{ "Mgr", "\xce\x9c", 2 },
	/*  MINUS-OR-PLUS SIGN  */
	{ "MinusPlus", "\xe2\x88\x93", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL M  */
	{ "Mopf", "\xf0\x9d\x95\x84", 4 },
	/*  SCRIPT CAPITAL M  */
	{ "Mscr", "\xe2\x84\xb3", 3 },
	/*  GREEK CAPITAL LETTER MU  */
	{ "Mu", "\xce\x9c", 2 },
	/*  CYRILLIC CAPITAL LETTER NJE  */
	{ "NJcy", "\xd0\x8a", 2 },
	/*  LATIN CAPITAL LETTER N WITH ACUTE  */
	{ "Nacute", "\xc5\x83", 2 },
	/*  LATIN CAPITAL LETTER N WITH CARON  */
	{ "Ncaron", "\xc5\x87", 2 },
	/*  LATIN CAPITAL LETTER N WITH CEDILLA  */
	{ "Ncedil", "\xc5\x85", 2 },
	/*  CYRILLIC CAPITAL LETTER EN  */
	{ "Ncy", "\xd0\x9d", 2 },
	/*  ZERO WIDTH SPACE  */
	{ "NegativeMediumSpace", "\xe2\x80\x8b", 3 },
	/*  ZERO WIDTH SPACE  */
	{ "NegativeThickSpace", "\xe2\x80\x8b", 3 },
	/*  ZERO WIDTH SPACE  */
	{ "NegativeThinSpace", "\xe2\x80\x8b", 3 },
	/*  ZERO WIDTH SPACE  */
	{ "NegativeVeryThinSpace", "\xe2\x80\x8b", 3 },
	/*  MUCH GREATER-THAN  */
	{ "NestedGreaterGreater", "\xe2\x89\xab", 3 },
	/*  MUCH LESS-THAN  */
	{ "NestedLessLess", "\xe2\x89\xaa", 3 },
	/*  LINE FEED (LF)  */
	{ "NewLine", "\x0a", 1 },
	/*  MATHEMATICAL FRAKTUR CAPITAL N  */
	{ "Nfr", "\xf0\x9d\x94\x91", 4 },
	/*  GREEK CAPITAL LETTER NU  */
	{ "Ngr", "\xce\x9d", 2 },
	/*  WORD JOINER  */
	{ "NoBreak", "\xe2\x81\xa0", 3 },
	/*  NO-BREAK SPACE  */
	{ "NonBreakingSpace", "\xc2\xa0", 2 },
	/*  DOUBLE-STRUCK CAPITAL N  */
	{ "Nopf", "\xe2\x84\x95", 3 },
	/*  DOUBLE STROKE NOT SIGN  */
	{ "Not", "\xe2\xab\xac", 3 },
	/*  NOT IDENTICAL TO  */
	{ "NotCongruent", "\xe2\x89\xa2", 3 },
	/*  NOT EQUIVALENT TO  */
	{ "NotCupCap", "\xe2\x89\xad", 3 },
	/*  NOT PARALLEL TO  */
	{ "NotDoubleVerticalBar", "\xe2\x88\xa6", 3 },
	/*  NOT AN ELEMENT OF  */
	{ "NotElement", "\xe2\x88\x89", 3 },
	/*  NOT EQUAL TO  */
	{ "NotEqual", "\xe2\x89\xa0", 3 },
	/*  MINUS TILDE with slash  */
	{ "NotEqualTilde", "\xe2\x89\x82\xcc\xb8", 5 },
	/*  THERE DOES NOT EXIST  */
	{ "NotExists", "\xe2\x88\x84", 3 },
	/*  NOT GREATER-THAN  */
	{ "NotGreater", "\xe2\x89\xaf", 3 },
	/*  NEITHER GREATER-THAN NOR EQUAL TO  */
	{ "NotGreaterEqual", "\xe2\x89\xb1", 3 },
	/*  GREATER-THAN OVER EQUAL TO with slash  */
	{ "NotGreaterFullEqual", "\xe2\x89\xa7\xcc\xb8", 5 },
	/*  MUCH GREATER THAN with slash  */
	{ "NotGreaterGreater", "\xe2\x89\xab\xcc\xb8", 5 },
	/*  NEITHER GREATER-THAN NOR LESS-THAN  */
	{ "NotGreaterLess", "\xe2\x89\xb9", 3 },
	/*  GREATER-THAN OR SLANTED EQUAL TO with slash  */
	{ "NotGreaterSlantEqual", "\xe2\xa9\xbe\xcc\xb8", 5 },
	/*  NEITHER GREATER-THAN NOR EQUIVALENT TO  */
	{ "NotGreaterTilde", "\xe2\x89\xb5", 3 },
	/*  GEOMETRICALLY EQUIVALENT TO with slash  */
	{ "NotHumpDownHump", "\xe2\x89\x8e\xcc\xb8", 5 },
	/*  DIFFERENCE BETWEEN with slash  */
	{ "NotHumpEqual", "\xe2\x89\x8f\xcc\xb8", 5 },
	/*  NOT NORMAL SUBGROUP OF  */
	{ "NotLeftTriangle", "\xe2\x8b\xaa", 3 },
	/*  LEFT TRIANGLE BESIDE VERTICAL BAR with slash  */
	{ "NotLeftTriangleBar", "\xe2\xa7\x8f\xcc\xb8", 5 },
	/*  NOT NORMAL SUBGROUP OF OR EQUAL TO  */
	{ "NotLeftTriangleEqual", "\xe2\x8b\xac", 3 },
	/*  NOT LESS-THAN  */
	{ "NotLess", "\xe2\x89\xae", 3 },
	/*  NEITHER LESS-THAN NOR EQUAL TO  */
	{ "NotLessEqual", "\xe2\x89\xb0", 3 },
	/*  NEITHER LESS-THAN NOR GREATER-THAN  */
	{ "NotLessGreater", "\xe2\x89\xb8", 3 },
	/*  MUCH LESS THAN with slash  */
	{ "NotLessLess", "\xe2\x89\xaa\xcc\xb8", 5 },
	/*  LESS-THAN OR SLANTED EQUAL TO with slash  */
	{ "NotLessSlantEqual", "\xe2\xa9\xbd\xcc\xb8", 5 },
	/*  NEITHER LESS-THAN NOR EQUIVALENT TO  */
	{ "NotLessTilde", "\xe2\x89\xb4", 3 },
	/*  DOUBLE NESTED GREATER-THAN with slash  */
	{ "NotNestedGreaterGreater", "\xe2\xaa\xa2\xcc\xb8", 5 },
	/*  DOUBLE NESTED LESS-THAN with slash  */
	{ "NotNestedLessLess", "\xe2\xaa\xa1\xcc\xb8", 5 },
	/*  DOES NOT PRECEDE  */
	{ "NotPrecedes", "\xe2\x8a\x80", 3 },
	/*  PRECEDES ABOVE SINGLE-LINE EQUALS SIGN with slash  */
	{ "NotPrecedesEqual", "\xe2\xaa\xaf\xcc\xb8", 5 },
	/*  DOES NOT PRECEDE OR EQUAL  */
	{ "NotPrecedesSlantEqual", "\xe2\x8b\xa0", 3 },
	/*  DOES NOT CONTAIN AS MEMBER  */
	{ "NotReverseElement", "\xe2\x88\x8c", 3 },
	/*  DOES NOT CONTAIN AS NORMAL SUBGROUP  */
	{ "NotRightTriangle", "\xe2\x8b\xab", 3 },
	/*  VERTICAL BAR BESIDE RIGHT TRIANGLE with slash  */
	{ "NotRightTriangleBar", "\xe2\xa7\x90\xcc\xb8", 5 },
	/*  DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL  */
	{ "NotRightTriangleEqual", "\xe2\x8b\xad", 3 },
	/*  SQUARE IMAGE OF with slash  */
	{ "NotSquareSubset", "\xe2\x8a\x8f\xcc\xb8", 5 },
	/*  NOT SQUARE IMAGE OF OR EQUAL TO  */
	{ "NotSquareSubsetEqual", "\xe2\x8b\xa2", 3 },
	/*  SQUARE ORIGINAL OF with slash  */
	{ "NotSquareSuperset", "\xe2\x8a\x90\xcc\xb8", 5 },
	/*  NOT SQUARE ORIGINAL OF OR EQUAL TO  */
	{ "NotSquareSupersetEqual", "\xe2\x8b\xa3", 3 },
	/*  SUBSET OF with vertical line  */
	{ "NotSubset", "\xe2\x8a\x82\xe2\x83\x92", 6 },
	/*  NEITHER A SUBSET OF NOR EQUAL TO  */
	{ "NotSubsetEqual", "\xe2\x8a\x88", 3 },
	/*  DOES NOT SUCCEED  */
	{ "NotSucceeds", "\xe2\x8a\x81", 3 },
	/*  SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN with slash  */
	{ "NotSucceedsEqual", "\xe2\xaa\xb0\xcc\xb8", 5 },
	/*  DOES NOT SUCCEED OR EQUAL  */
	{ "NotSucceedsSlantEqual", "\xe2\x8b\xa1", 3 },
	/*  SUCCEEDS OR EQUIVALENT TO with slash  */
	{ "NotSucceedsTilde", "\xe2\x89\xbf\xcc\xb8", 5 },
	/*  SUPERSET OF with vertical line  */
	{ "NotSuperset", "\xe2\x8a\x83\xe2\x83\x92", 6 },
	/*  NEITHER A SUPERSET OF NOR EQUAL TO  */
	{ "NotSupersetEqual", "\xe2\x8a\x89", 3 },
	/*  NOT TILDE  */
	{ "NotTilde", "\xe2\x89\x81", 3 },
	/*  NOT ASYMPTOTICALLY EQUAL TO  */
	{ "NotTildeEqual", "\xe2\x89\x84", 3 },
	/*  NEITHER APPROXIMATELY NOR ACTUALLY EQUAL TO  */
	{ "NotTildeFullEqual", "\xe2\x89\x87", 3 },
	/*  NOT ALMOST EQUAL TO  */
	{ "NotTildeTilde", "\xe2\x89\x89", 3 },
	/*  DOES NOT DIVIDE  */
	{ "NotVerticalBar", "\xe2\x88\xa4", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL N  */
	{ "Nscr", "\xf0\x9d\x92\xa9", 4 },
	/*  LATIN CAPITAL LETTER N WITH TILDE  */
	{ "Ntilde", "\xc3\x91", 2 },
	/*  GREEK CAPITAL LETTER NU  */
	{ "Nu", "\xce\x9d", 2 },
	/*  LATIN CAPITAL LIGATURE OE  */
	{ "OElig", "\xc5\x92", 2 },
	/*  GREEK CAPITAL LETTER OMEGA WITH TONOS  */
	{ "OHacgr", "\xce\x8f", 2 },
	/*  GREEK CAPITAL LETTER OMEGA  */
	{ "OHgr", "\xce\xa9", 2 },
	/*  GREEK CAPITAL LETTER OMICRON WITH TONOS  */
	{ "Oacgr", "\xce\x8c", 2 },
	/*  LATIN CAPITAL LETTER O WITH ACUTE  */
	{ "Oacute", "\xc3\x93", 2 },
	/*  LATIN CAPITAL LETTER O WITH CIRCUMFLEX  */
	{ "Ocirc", "\xc3\x94", 2 },
	/*  CYRILLIC CAPITAL LETTER O  */
	{ "Ocy", "\xd0\x9e", 2 },
	/*  LATIN CAPITAL LETTER O WITH DOUBLE ACUTE  */
	{ "Odblac", "\xc5\x90", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL O  */
	{ "Ofr", "\xf0\x9d\x94\x92", 4 },
	/*  GREEK CAPITAL LETTER OMICRON  */
	{ "Ogr", "\xce\x9f", 2 },
	/*  LATIN CAPITAL LETTER O WITH GRAVE  */
	{ "Ograve", "\xc3\x92", 2 },
	/*  LATIN CAPITAL LETTER O WITH MACRON  */
	{ "Omacr", "\xc5\x8c", 2 },
	/*  GREEK CAPITAL LETTER OMEGA  */
	{ "Omega", "\xce\xa9", 2 },
	/*  GREEK CAPITAL LETTER OMICRON  */
	{ "Omicron", "\xce\x9f", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL O  */
	{ "Oopf", "\xf0\x9d\x95\x86", 4 },
	/*  LEFT DOUBLE QUOTATION MARK  */
	{ "OpenCurlyDoubleQuote", "\xe2\x80\x9c", 3 },
	/*  LEFT SINGLE QUOTATION MARK  */
	{ "OpenCurlyQuote", "\xe2\x80\x98", 3 },
	/*  DOUBLE LOGICAL OR  */
	{ "Or", "\xe2\xa9\x94", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL O  */
	{ "Oscr", "\xf0\x9d\x92\xaa", 4 },
	/*  LATIN CAPITAL LETTER O WITH STROKE  */
	{ "Oslash", "\xc3\x98", 2 },
	/*  LATIN CAPITAL LETTER O WITH TILDE  */
	{ "Otilde", "\xc3\x95", 2 },
	/*  MULTIPLICATION SIGN IN DOUBLE CIRCLE  */
	{ "Otimes", "\xe2\xa8\xb7", 3 },
	/*  LATIN CAPITAL LETTER O WITH DIAERESIS  */
	{ "Ouml", "\xc3\x96", 2 },
	/*  OVERLINE  */
	{ "OverBar", "\xe2\x80\xbe", 3 },
	/*  TOP CURLY BRACKET  */
	{ "OverBrace", "\xe2\x8f\x9e", 3 },
	/*  TOP SQUARE BRACKET  */
	{ "OverBracket", "\xe2\x8e\xb4", 3 },
	/*  TOP PARENTHESIS  */
	{ "OverParenthesis", "\xe2\x8f\x9c", 3 },
	/*  GREEK CAPITAL LETTER PHI  */
	{ "PHgr", "\xce\xa6", 2 },
	/*  GREEK CAPITAL LETTER PSI  */
	{ "PSgr", "\xce\xa8", 2 },
	/*  PARTIAL DIFFERENTIAL  */
	{ "PartialD", "\xe2\x88\x82", 3 },
	/*  CYRILLIC CAPITAL LETTER PE  */
	{ "Pcy", "\xd0\x9f", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL P  */
	{ "Pfr", "\xf0\x9d\x94\x93", 4 },
	/*  GREEK CAPITAL LETTER PI  */
	{ "Pgr", "\xce\xa0", 2 },
	/*  GREEK CAPITAL LETTER PHI  */
	{ "Phi", "\xce\xa6", 2 },
	/*  GREEK CAPITAL LETTER PI  */
	{ "Pi", "\xce\xa0", 2 },
	/*  PLUS-MINUS SIGN  */
	{ "PlusMinus", "\xc2\xb1", 2 },
	/*  BLACK-LETTER CAPITAL H  */
	{ "Poincareplane", "\xe2\x84\x8c", 3 },
	/*  DOUBLE-STRUCK CAPITAL P  */
	{ "Popf", "\xe2\x84\x99", 3 },
	/*  DOUBLE PRECEDES  */
	{ "Pr", "\xe2\xaa\xbb", 3 },
	/*  PRECEDES  */
	{ "Precedes", "\xe2\x89\xba", 3 },
	/*  PRECEDES ABOVE SINGLE-LINE EQUALS SIGN  */
	{ "PrecedesEqual", "\xe2\xaa\xaf", 3 },
	/*  PRECEDES OR EQUAL TO  */
	{ "PrecedesSlantEqual", "\xe2\x89\xbc", 3 },
	/*  PRECEDES OR EQUIVALENT TO  */
	{ "PrecedesTilde", "\xe2\x89\xbe", 3 },
	/*  DOUBLE PRIME  */
	{ "Prime", "\xe2\x80\xb3", 3 },
	/*  N-ARY PRODUCT  */
	{ "Product", "\xe2\x88\x8f", 3 },
	/*  PROPORTION  */
	{ "Proportion", "\xe2\x88\xb7", 3 },
	/*  PROPORTIONAL TO  */
	{ "Proportional", "\xe2\x88\x9d", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL P  */
	{ "Pscr", "\xf0\x9d\x92\xab", 4 },
	/*  GREEK CAPITAL LETTER PSI  */
	{ "Psi", "\xce\xa8", 2 },
	/*  QUOTATION MARK  */
	{ "QUOT", "\x22", 1 },
	/*  MATHEMATICAL FRAKTUR CAPITAL Q  */
	{ "Qfr", "\xf0\x9d\x94\x94", 4 },
	/*  DOUBLE-STRUCK CAPITAL Q  */
	{ "Qopf", "\xe2\x84\x9a", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL Q  */
	{ "Qscr", "\xf0\x9d\x92\xac", 4 },
	/*  RIGHTWARDS TWO-HEADED TRIPLE DASH ARROW  */
	{ "RBarr", "\xe2\xa4\x90", 3 },
	/*  REGISTERED SIGN  */
	{ "REG", "\xc2\xae", 2 },
	/*  LATIN CAPITAL LETTER R WITH ACUTE  */
	{ "Racute", "\xc5\x94", 2 },
	/*  MATHEMATICAL RIGHT DOUBLE ANGLE BRACKET  */
	{ "Rang", "\xe2\x9f\xab", 3 },
	/*  RIGHTWARDS TWO HEADED ARROW  */
	{ "Rarr", "\xe2\x86\xa0", 3 },
	/*  RIGHTWARDS TWO-HEADED ARROW WITH TAIL  */
	{ "Rarrtl", "\xe2\xa4\x96", 3 },
	/*  LATIN CAPITAL LETTER R WITH CARON  */
	{ "Rcaron", "\xc5\x98", 2 },
	/*  LATIN CAPITAL LETTER R WITH CEDILLA  */
	{ "Rcedil", "\xc5\x96", 2 },
	/*  CYRILLIC CAPITAL LETTER ER  */
	{ "Rcy", "\xd0\xa0", 2 },
	/*  BLACK-LETTER CAPITAL R  */
	{ "Re", "\xe2\x84\x9c", 3 },
	/*  CONTAINS AS MEMBER  */
	{ "ReverseElement", "\xe2\x88\x8b", 3 },
	/*  LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON  */
	{ "ReverseEquilibrium", "\xe2\x87\x8b", 3 },
	/*  DOWNWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT  */
	{ "ReverseUpEquilibrium", "\xe2\xa5\xaf", 3 },
	/*  BLACK-LETTER CAPITAL R  */
	{ "Rfr", "\xe2\x84\x9c", 3 },
	/*  GREEK CAPITAL LETTER RHO  */
	{ "Rgr", "\xce\xa1", 2 },
	/*  GREEK CAPITAL LETTER RHO  */
	{ "Rho", "\xce\xa1", 2 },
	/*  MATHEMATICAL RIGHT ANGLE BRACKET  */
	{ "RightAngleBracket", "\xe2\x9f\xa9", 3 },
	/*  RIGHTWARDS ARROW  */
	{ "RightArrow", "\xe2\x86\x92", 3 },
	/*  RIGHTWARDS ARROW TO BAR  */
	{ "RightArrowBar", "\xe2\x87\xa5", 3 },
	/*  RIGHTWARDS ARROW OVER LEFTWARDS ARROW  */
	{ "RightArrowLeftArrow", "\xe2\x87\x84", 3 },
	/*  RIGHT CEILING  */
	{ "RightCeiling", "\xe2\x8c\x89", 3 },
	/*  MATHEMATICAL RIGHT WHITE SQUARE BRACKET  */
	{ "RightDoubleBracket", "\xe2\x9f\xa7", 3 },
	/*  DOWNWARDS HARPOON WITH BARB RIGHT FROM BAR  */
	{ "RightDownTeeVector", "\xe2\xa5\x9d", 3 },
	/*  DOWNWARDS HARPOON WITH BARB RIGHTWARDS  */
	{ "RightDownVector", "\xe2\x87\x82", 3 },
	/*  DOWNWARDS HARPOON WITH BARB RIGHT TO BAR  */
	{ "RightDownVectorBar", "\xe2\xa5\x95", 3 },
	/*  RIGHT FLOOR  */
	{ "RightFloor", "\xe2\x8c\x8b", 3 },
	/*  RIGHT TACK  */
	{ "RightTee", "\xe2\x8a\xa2", 3 },
	/*  RIGHTWARDS ARROW FROM BAR  */
	{ "RightTeeArrow", "\xe2\x86\xa6", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UP FROM BAR  */
	{ "RightTeeVector", "\xe2\xa5\x9b", 3 },
	/*  CONTAINS AS NORMAL SUBGROUP  */
	{ "RightTriangle", "\xe2\x8a\xb3", 3 },
	/*  VERTICAL BAR BESIDE RIGHT TRIANGLE  */
	{ "RightTriangleBar", "\xe2\xa7\x90", 3 },
	/*  CONTAINS AS NORMAL SUBGROUP OR EQUAL TO  */
	{ "RightTriangleEqual", "\xe2\x8a\xb5", 3 },
	/*  UP BARB RIGHT DOWN BARB RIGHT HARPOON  */
	{ "RightUpDownVector", "\xe2\xa5\x8f", 3 },
	/*  UPWARDS HARPOON WITH BARB RIGHT FROM BAR  */
	{ "RightUpTeeVector", "\xe2\xa5\x9c", 3 },
	/*  UPWARDS HARPOON WITH BARB RIGHTWARDS  */
	{ "RightUpVector", "\xe2\x86\xbe", 3 },
	/*  UPWARDS HARPOON WITH BARB RIGHT TO BAR  */
	{ "RightUpVectorBar", "\xe2\xa5\x94", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UPWARDS  */
	{ "RightVector", "\xe2\x87\x80", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UP TO BAR  */
	{ "RightVectorBar", "\xe2\xa5\x93", 3 },
	/*  RIGHTWARDS DOUBLE ARROW  */
	{ "Rightarrow", "\xe2\x87\x92", 3 },
	/*  DOUBLE-STRUCK CAPITAL R  */
	{ "Ropf", "\xe2\x84\x9d", 3 },
	/*  RIGHT DOUBLE ARROW WITH ROUNDED HEAD  */
	{ "RoundImplies", "\xe2\xa5\xb0", 3 },
	/*  RIGHTWARDS TRIPLE ARROW  */
	{ "Rrightarrow", "\xe2\x87\x9b", 3 },
	/*  SCRIPT CAPITAL R  */
	{ "Rscr", "\xe2\x84\x9b", 3 },
	/*  UPWARDS ARROW WITH TIP RIGHTWARDS  */
	{ "Rsh", "\xe2\x86\xb1", 3 },
	/*  RULE-DELAYED  */
	{ "RuleDelayed", "\xe2\xa7\xb4", 3 },
	/*  CYRILLIC CAPITAL LETTER SHCHA  */
	{ "SHCHcy", "\xd0\xa9", 2 },
	/*  CYRILLIC CAPITAL LETTER SHA  */
	{ "SHcy", "\xd0\xa8", 2 },
	/*  CYRILLIC CAPITAL LETTER SOFT SIGN  */
	{ "SOFTcy", "\xd0\xac", 2 },
	/*  LATIN CAPITAL LETTER S WITH ACUTE  */
	{ "Sacute", "\xc5\x9a", 2 },
	/*  DOUBLE SUCCEEDS  */
	{ "Sc", "\xe2\xaa\xbc", 3 },
	/*  LATIN CAPITAL LETTER S WITH CARON  */
	{ "Scaron", "\xc5\xa0", 2 },
	/*  LATIN CAPITAL LETTER S WITH CEDILLA  */
	{ "Scedil", "\xc5\x9e", 2 },
	/*  LATIN CAPITAL LETTER S WITH CIRCUMFLEX  */
	{ "Scirc", "\xc5\x9c", 2 },
	/*  CYRILLIC CAPITAL LETTER ES  */
	{ "Scy", "\xd0\xa1", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL S  */
	{ "Sfr", "\xf0\x9d\x94\x96", 4 },
	/*  GREEK CAPITAL LETTER SIGMA  */
	{ "Sgr", "\xce\xa3", 2 },
	/*  DOWNWARDS ARROW  */
	{ "ShortDownArrow", "\xe2\x86\x93", 3 },
	/*  LEFTWARDS ARROW  */
	{ "ShortLeftArrow", "\xe2\x86\x90", 3 },
	/*  RIGHTWARDS ARROW  */
	{ "ShortRightArrow", "\xe2\x86\x92", 3 },
	/*  UPWARDS ARROW  */
	{ "ShortUpArrow", "\xe2\x86\x91", 3 },
	/*  GREEK CAPITAL LETTER SIGMA  */
	{ "Sigma", "\xce\xa3", 2 },
	/*  RING OPERATOR  */
	{ "SmallCircle", "\xe2\x88\x98", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL S  */
	{ "Sopf", "\xf0\x9d\x95\x8a", 4 },
	/*  SQUARE ROOT  */
	{ "Sqrt", "\xe2\x88\x9a", 3 },
	/*  WHITE SQUARE  */
	{ "Square", "\xe2\x96\xa1", 3 },
	/*  SQUARE CAP  */
	{ "SquareIntersection", "\xe2\x8a\x93", 3 },
	/*  SQUARE IMAGE OF  */
	{ "SquareSubset", "\xe2\x8a\x8f", 3 },
	/*  SQUARE IMAGE OF OR EQUAL TO  */
	{ "SquareSubsetEqual", "\xe2\x8a\x91", 3 },
	/*  SQUARE ORIGINAL OF  */
	{ "SquareSuperset", "\xe2\x8a\x90", 3 },
	/*  SQUARE ORIGINAL OF OR EQUAL TO  */
	{ "SquareSupersetEqual", "\xe2\x8a\x92", 3 },
	/*  SQUARE CUP  */
	{ "SquareUnion", "\xe2\x8a\x94", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL S  */
	{ "Sscr", "\xf0\x9d\x92\xae", 4 },
	/*  STAR OPERATOR  */
	{ "Star", "\xe2\x8b\x86", 3 },
	/*  DOUBLE SUBSET  */
	{ "Sub", "\xe2\x8b\x90", 3 },
	/*  DOUBLE SUBSET  */
	{ "Subset", "\xe2\x8b\x90", 3 },
	/*  SUBSET OF OR EQUAL TO  */
	{ "SubsetEqual", "\xe2\x8a\x86", 3 },
	/*  SUCCEEDS  */
	{ "Succeeds", "\xe2\x89\xbb", 3 },
	/*  SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN  */
	{ "SucceedsEqual", "\xe2\xaa\xb0", 3 },
	/*  SUCCEEDS OR EQUAL TO  */
	{ "SucceedsSlantEqual", "\xe2\x89\xbd", 3 },
	/*  SUCCEEDS OR EQUIVALENT TO  */
	{ "SucceedsTilde", "\xe2\x89\xbf", 3 },
	/*  CONTAINS AS MEMBER  */
	{ "SuchThat", "\xe2\x88\x8b", 3 },
	/*  N-ARY SUMMATION  */
	{ "Sum", "\xe2\x88\x91", 3 },
	/*  DOUBLE SUPERSET  */
	{ "Sup", "\xe2\x8b\x91", 3 },
	/*  SUPERSET OF  */
	{ "Superset", "\xe2\x8a\x83", 3 },
	/*  SUPERSET OF OR EQUAL TO  */
	{ "SupersetEqual", "\xe2\x8a\x87", 3 },
	/*  DOUBLE SUPERSET  */
	{ "Supset", "\xe2\x8b\x91", 3 },
	/*  LATIN CAPITAL LETTER THORN  */
	{ "THORN", "\xc3\x9e", 2 },
	/*  GREEK CAPITAL LETTER THETA  */
	{ "THgr", "\xce\x98", 2 },
	/*  TRADE MARK SIGN  */
	{ "TRADE", "\xe2\x84\xa2", 3 },
	/*  CYRILLIC CAPITAL LETTER TSHE  */
	{ "TSHcy", "\xd0\x8b", 2 },
	/*  CYRILLIC CAPITAL LETTER TSE  */
	{ "TScy", "\xd0\xa6", 2 },
	/*  CHARACTER TABULATION  */
	{ "Tab", "\x09", 1 },
	/*  GREEK CAPITAL LETTER TAU  */
	{ "Tau", "\xce\xa4", 2 },
	/*  LATIN CAPITAL LETTER T WITH CARON  */
	{ "Tcaron", "\xc5\xa4", 2 },
	/*  LATIN CAPITAL LETTER T WITH CEDILLA  */
	{ "Tcedil", "\xc5\xa2", 2 },
	/*  CYRILLIC CAPITAL LETTER TE  */
	{ "Tcy", "\xd0\xa2", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL T  */
	{ "Tfr", "\xf0\x9d\x94\x97", 4 },
	/*  GREEK CAPITAL LETTER TAU  */
	{ "Tgr", "\xce\xa4", 2 },
	/*  THEREFORE  */
	{ "Therefore", "\xe2\x88\xb4", 3 },
	/*  GREEK CAPITAL LETTER THETA  */
	{ "Theta", "\xce\x98", 2 },
	/*  GREEK CAPITAL THETA SYMBOL  */
	{ "Thetav", "\xcf\xb4", 2 },
	/*  space of width 5/18 em  */
	{ "ThickSpace", "\xe2\x81\x9f\xe2\x80\x8a", 6 },
	/*  THIN SPACE  */
	{ "ThinSpace", "\xe2\x80\x89", 3 },
	/*  TILDE OPERATOR  */
	{ "Tilde", "\xe2\x88\xbc", 3 },
	/*  ASYMPTOTICALLY EQUAL TO  */
	{ "TildeEqual", "\xe2\x89\x83", 3 },
	/*  APPROXIMATELY EQUAL TO  */
	{ "TildeFullEqual", "\xe2\x89\x85", 3 },
	/*  ALMOST EQUAL TO  */
	{ "TildeTilde", "\xe2\x89\x88", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL T  */
	{ "Topf", "\xf0\x9d\x95\x8b", 4 },
	/*  COMBINING THREE DOTS ABOVE  */
	{ "TripleDot", "\xe2\x83\x9b", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL T  */
	{ "Tscr", "\xf0\x9d\x92\xaf", 4 },
	/*  LATIN CAPITAL LETTER T WITH STROKE  */
	{ "Tstrok", "\xc5\xa6", 2 },
	/*  GREEK CAPITAL LETTER UPSILON WITH TONOS  */
	{ "Uacgr", "\xce\x8e", 2 },
	/*  LATIN CAPITAL LETTER U WITH ACUTE  */
	{ "Uacute", "\xc3\x9a", 2 },
	/*  UPWARDS TWO HEADED ARROW  */
	{ "Uarr", "\xe2\x86\x9f", 3 },
	/*  UPWARDS TWO-HEADED ARROW FROM SMALL CIRCLE  */
	{ "Uarrocir", "\xe2\xa5\x89", 3 },
	/*  CYRILLIC CAPITAL LETTER SHORT U  */
	{ "Ubrcy", "\xd0\x8e", 2 },
	/*  LATIN CAPITAL LETTER U WITH BREVE  */
	{ "Ubreve", "\xc5\xac", 2 },
	/*  LATIN CAPITAL LETTER U WITH CIRCUMFLEX  */
	{ "Ucirc", "\xc3\x9b", 2 },
	/*  CYRILLIC CAPITAL LETTER U  */
	{ "Ucy", "\xd0\xa3", 2 },
	/*  LATIN CAPITAL LETTER U WITH DOUBLE ACUTE  */
	{ "Udblac", "\xc5\xb0", 2 },
	/*  GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA  */
	{ "Udigr", "\xce\xab", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL U  */
	{ "Ufr", "\xf0\x9d\x94\x98", 4 },
	/*  GREEK CAPITAL LETTER UPSILON  */
	{ "Ugr", "\xce\xa5", 2 },
	/*  LATIN CAPITAL LETTER U WITH GRAVE  */
	{ "Ugrave", "\xc3\x99", 2 },
	/*  LATIN CAPITAL LETTER U WITH MACRON  */
	{ "Umacr", "\xc5\xaa", 2 },
	/*  LOW LINE  */
	{ "UnderBar", "\x5f", 1 },
	/*  BOTTOM CURLY BRACKET  */
	{ "UnderBrace", "\xe2\x8f\x9f", 3 },
	/*  BOTTOM SQUARE BRACKET  */
	{ "UnderBracket", "\xe2\x8e\xb5", 3 },
	/*  BOTTOM PARENTHESIS  */
	{ "UnderParenthesis", "\xe2\x8f\x9d", 3 },
	/*  N-ARY UNION  */
	{ "Union", "\xe2\x8b\x83", 3 },
	/*  MULTISET UNION  */
	{ "UnionPlus", "\xe2\x8a\x8e", 3 },
	/*  LATIN CAPITAL LETTER U WITH OGONEK  */
	{ "Uogon", "\xc5\xb2", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL U  */
	{ "Uopf", "\xf0\x9d\x95\x8c", 4 },
	/*  UPWARDS ARROW  */
	{ "UpArrow", "\xe2\x86\x91", 3 },
	/*  UPWARDS ARROW TO BAR  */
	{ "UpArrowBar", "\xe2\xa4\x92", 3 },
	/*  UPWARDS ARROW LEFTWARDS OF DOWNWARDS ARROW  */
	{ "UpArrowDownArrow", "\xe2\x87\x85", 3 },
	/*  UP DOWN ARROW  */
	{ "UpDownArrow", "\xe2\x86\x95", 3 },
	/*  UPWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT  */
	{ "UpEquilibrium", "\xe2\xa5\xae", 3 },
	/*  UP TACK  */
	{ "UpTee", "\xe2\x8a\xa5", 3 },
	/*  UPWARDS ARROW FROM BAR  */
	{ "UpTeeArrow", "\xe2\x86\xa5", 3 },
	/*  UPWARDS DOUBLE ARROW  */
	{ "Uparrow", "\xe2\x87\x91", 3 },
	/*  UP DOWN DOUBLE ARROW  */
	{ "Updownarrow", "\xe2\x87\x95", 3 },
	/*  NORTH WEST ARROW  */
	{ "UpperLeftArrow", "\xe2\x86\x96", 3 },
	/*  NORTH EAST ARROW  */
	{ "UpperRightArrow", "\xe2\x86\x97", 3 },
	/*  GREEK UPSILON WITH HOOK SYMBOL  */
	{ "Upsi", "\xcf\x92", 2 },
	/*  GREEK CAPITAL LETTER UPSILON  */
	{ "Upsilon", "\xce\xa5", 2 },
	/*  LATIN CAPITAL LETTER U WITH RING ABOVE  */
	{ "Uring", "\xc5\xae", 2 },
	/*  MATHEMATICAL SCRIPT CAPITAL U  */
	{ "Uscr", "\xf0\x9d\x92\xb0", 4 },
	/*  LATIN CAPITAL LETTER U WITH TILDE  */
	{ "Utilde", "\xc5\xa8", 2 },
	/*  LATIN CAPITAL LETTER U WITH DIAERESIS  */
	{ "Uuml", "\xc3\x9c", 2 },
	/*  DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE  */
	{ "VDash", "\xe2\x8a\xab", 3 },
	/*  DOUBLE UP TACK  */
	{ "Vbar", "\xe2\xab\xab", 3 },
	/*  CYRILLIC CAPITAL LETTER VE  */
	{ "Vcy", "\xd0\x92", 2 },
	/*  FORCES  */
	{ "Vdash", "\xe2\x8a\xa9", 3 },
	/*  LONG DASH FROM LEFT MEMBER OF DOUBLE VERTICAL  */
	{ "Vdashl", "\xe2\xab\xa6", 3 },
	/*  N-ARY LOGICAL OR  */
	{ "Vee", "\xe2\x8b\x81", 3 },
	/*  DOUBLE VERTICAL LINE  */
	{ "Verbar", "\xe2\x80\x96", 3 },
	/*  DOUBLE VERTICAL LINE  */
	{ "Vert", "\xe2\x80\x96", 3 },
	/*  DIVIDES  */
	{ "VerticalBar", "\xe2\x88\xa3", 3 },
	/*  VERTICAL LINE  */
	{ "VerticalLine", "\x7c", 1 },
	/*  LIGHT VERTICAL BAR  */
	{ "VerticalSeparator", "\xe2\x9d\x98", 3 },
	/*  WREATH PRODUCT  */
	{ "VerticalTilde", "\xe2\x89\x80", 3 },
	/*  HAIR SPACE  */
	{ "VeryThinSpace", "\xe2\x80\x8a", 3 },
	/*  MATHEMATICAL FRAKTUR CAPITAL V  */
	{ "Vfr", "\xf0\x9d\x94\x99", 4 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL V  */
	{ "Vopf", "\xf0\x9d\x95\x8d", 4 },
	/*  MATHEMATICAL SCRIPT CAPITAL V  */
	{ "Vscr", "\xf0\x9d\x92\xb1", 4 },
	/*  TRIPLE VERTICAL BAR RIGHT TURNSTILE  */
	{ "Vvdash", "\xe2\x8a\xaa", 3 },
	/*  LATIN CAPITAL LETTER W WITH CIRCUMFLEX  */
	{ "Wcirc", "\xc5\xb4", 2 },
	/*  N-ARY LOGICAL AND  */
	{ "Wedge", "\xe2\x8b\x80", 3 },
	/*  MATHEMATICAL FRAKTUR CAPITAL W  */
	{ "Wfr", "\xf0\x9d\x94\x9a", 4 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL W  */
	{ "Wopf", "\xf0\x9d\x95\x8e", 4 },
	/*  MATHEMATICAL SCRIPT CAPITAL W  */
	{ "Wscr", "\xf0\x9d\x92\xb2", 4 },
	/*  MATHEMATICAL FRAKTUR CAPITAL X  */
	{ "Xfr", "\xf0\x9d\x94\x9b", 4 },
	/*  GREEK CAPITAL LETTER XI  */
	{ "Xgr", "\xce\x9e", 2 },
	/*  GREEK CAPITAL LETTER XI  */
	{ "Xi", "\xce\x9e", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL X  */
	{ "Xopf", "\xf0\x9d\x95\x8f", 4 },
	/*  MATHEMATICAL SCRIPT CAPITAL X  */
	{ "Xscr", "\xf0\x9d\x92\xb3", 4 },
	/*  CYRILLIC CAPITAL LETTER YA  */
	{ "YAcy", "\xd0\xaf", 2 },
	/*  CYRILLIC CAPITAL LETTER YI  */
	{ "YIcy", "\xd0\x87", 2 },
	/*  CYRILLIC CAPITAL LETTER YU  */
	{ "YUcy", "\xd0\xae", 2 },
	/*  LATIN CAPITAL LETTER Y WITH ACUTE  */
	{ "Yacute", "\xc3\x9d", 2 },
	/*  LATIN CAPITAL LETTER Y WITH CIRCUMFLEX  */
	{ "Ycirc", "\xc5\xb6", 2 },
	/*  CYRILLIC CAPITAL LETTER YERU  */
	{ "Ycy", "\xd0\xab", 2 },
	/*  MATHEMATICAL FRAKTUR CAPITAL Y  */
	{ "Yfr", "\xf0\x9d\x94\x9c", 4 },
	/*  MATHEMATICAL DOUBLE-STRUCK CAPITAL Y  */
	{ "Yopf", "\xf0\x9d\x95\x90", 4 },
	/*  MATHEMATICAL SCRIPT CAPITAL Y  */
	{ "Yscr", "\xf0\x9d\x92\xb4", 4 },
	/*  LATIN CAPITAL LETTER Y WITH DIAERESIS  */
	{ "Yuml", "\xc5\xb8", 2 },
	/*  CYRILLIC CAPITAL LETTER ZHE  */
	{ "ZHcy", "\xd0\x96", 2 },
	/*  LATIN CAPITAL LETTER Z WITH ACUTE  */
	{ "Zacute", "\xc5\xb9", 2 },
	/*  LATIN CAPITAL LETTER Z WITH CARON  */
	{ "Zcaron", "\xc5\xbd", 2 },
	/*  CYRILLIC CAPITAL LETTER ZE  */
	{ "Zcy", "\xd0\x97", 2 },
	/*  LATIN CAPITAL LETTER Z WITH DOT ABOVE  */
	{ "Zdot", "\xc5\xbb", 2 },
	/*  ZERO WIDTH SPACE  */
	{ "ZeroWidthSpace", "\xe2\x80\x8b", 3 },
	/*  GREEK CAPITAL LETTER ZETA  */
	{ "Zeta", "\xce\x96", 2 },
	/*  BLACK-LETTER CAPITAL Z  */
	{ "Zfr", "\xe2\x84\xa8", 3 },
	/*  GREEK CAPITAL LETTER ZETA  */
	{ "Zgr", "\xce\x96", 2 },
	/*  DOUBLE-STRUCK CAPITAL Z  */
	{ "Zopf", "\xe2\x84\xa4", 3 },
	/*  MATHEMATICAL SCRIPT CAPITAL Z  */
	{ "Zscr", "\xf0\x9d\x92\xb5", 4 },
	/*  GREEK SMALL LETTER ALPHA WITH TONOS  */
	{ "aacgr", "\xce\xac", 2 },
	/*  LATIN SMALL LETTER A WITH ACUTE  */
	{ "aacute", "\xc3\xa1", 2 },
	/*  LATIN SMALL LETTER A WITH BREVE  */
	{ "abreve", "\xc4\x83", 2 },
	/*  INVERTED LAZY S  */
	{ "ac", "\xe2\x88\xbe", 3 },
	/*  INVERTED LAZY S with double underline  */
	{ "acE", "\xe2\x88\xbe\xcc\xb3", 5 },
	/*  SINE WAVE  */
	{ "acd", "\xe2\x88\xbf", 3 },
	/*  LATIN SMALL LETTER A WITH CIRCUMFLEX  */
	{ "acirc", "\xc3\xa2", 2 },
	/*  COMBINING ANNUITY SYMBOL  */
	{ "actuary", "\xe2\x83\xa7", 3 },
	/*  ACUTE ACCENT  */
	{ "acute", "\xc2\xb4", 2 },
	/*  CYRILLIC SMALL LETTER A  */
	{ "acy", "\xd0\xb0", 2 },
	/*  LATIN SMALL LETTER AE  */
	{ "aelig", "\xc3\xa6", 2 },
	/*  FUNCTION APPLICATION  */
	{ "af", "\xe2\x81\xa1", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL A  */
	{ "afr", "\xf0\x9d\x94\x9e", 4 },
	/*  GREEK SMALL LETTER ALPHA  */
	{ "agr", "\xce\xb1", 2 },
	/*  LATIN SMALL LETTER A WITH GRAVE  */
	{ "agrave", "\xc3\xa0", 2 },
	/*  ALEF SYMBOL  */
	{ "alefsym", "\xe2\x84\xb5", 3 },
	/*  ALEF SYMBOL  */
	{ "aleph", "\xe2\x84\xb5", 3 },
	/*  GREEK SMALL LETTER ALPHA  */
	{ "alpha", "\xce\xb1", 2 },
	/*  LATIN SMALL LETTER A WITH MACRON  */
	{ "amacr", "\xc4\x81", 2 },
	/*  AMALGAMATION OR COPRODUCT  */
	{ "amalg", "\xe2\xa8\xbf", 3 },
	/*  AMPERSAND  */
	{ "amp", "\x26", 1 },
	/*  LOGICAL AND  */
	{ "and", "\xe2\x88\xa7", 3 },
	/*  TWO INTERSECTING LOGICAL AND  */
	{ "andand", "\xe2\xa9\x95", 3 },
	/*  LOGICAL AND WITH HORIZONTAL DASH  */
	{ "andd", "\xe2\xa9\x9c", 3 },
	/*  SLOPING LARGE AND  */
	{ "andslope", "\xe2\xa9\x98", 3 },
	/*  LOGICAL AND WITH MIDDLE STEM  */
	{ "andv", "\xe2\xa9\x9a", 3 },
	/*  ANGLE  */
	{ "ang", "\xe2\x88\xa0", 3 },
	/*  RIGHT ANGLE  */
	{ "ang90", "\xe2\x88\x9f", 3 },
	/*  TURNED ANGLE  */
	{ "angdnl", "\xe2\xa6\xa2", 3 },
	/*  ACUTE ANGLE  */
	{ "angdnr", "\xe2\xa6\x9f", 3 },
	/*  ANGLE WITH UNDERBAR  */
	{ "ange", "\xe2\xa6\xa4", 3 },
	/*  ANGLE  */
	{ "angle", "\xe2\x88\xa0", 3 },
	/*  ANGLE WITH S INSIDE  */
	{ "angles", "\xe2\xa6\x9e", 3 },
	/*  MEASURED ANGLE  */
	{ "angmsd", "\xe2\x88\xa1", 3 },
	/*  MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND RIGHT  */
	{ "angmsdaa", "\xe2\xa6\xa8", 3 },
	/*  MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND LEFT  */
	{ "angmsdab", "\xe2\xa6\xa9", 3 },
	/*  MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND RIGHT  */
	{ "angmsdac", "\xe2\xa6\xaa", 3 },
	/*  MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND LEFT  */
	{ "angmsdad", "\xe2\xa6\xab", 3 },
	/*  MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND UP  */
	{ "angmsdae", "\xe2\xa6\xac", 3 },
	/*  MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND UP  */
	{ "angmsdaf", "\xe2\xa6\xad", 3 },
	/*  MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND DOWN  */
	{ "angmsdag", "\xe2\xa6\xae", 3 },
	/*  MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND DOWN  */
	{ "angmsdah", "\xe2\xa6\xaf", 3 },
	/*  RIGHT ANGLE  */
	{ "angrt", "\xe2\x88\x9f", 3 },
	/*  RIGHT ANGLE WITH ARC  */
	{ "angrtvb", "\xe2\x8a\xbe", 3 },
	/*  MEASURED RIGHT ANGLE WITH DOT  */
	{ "angrtvbd", "\xe2\xa6\x9d", 3 },
	/*  SPHERICAL ANGLE  */
	{ "angsph", "\xe2\x88\xa2", 3 },
	/*  LATIN CAPITAL LETTER A WITH RING ABOVE  */
	{ "angst", "\xc3\x85", 2 },
	/*  REVERSED ANGLE  */
	{ "angupl", "\xe2\xa6\xa3", 3 },
	/*  RIGHT ANGLE WITH DOWNWARDS ZIGZAG ARROW  */
	{ "angzarr", "\xe2\x8d\xbc", 3 },
	/*  LATIN SMALL LETTER A WITH OGONEK  */
	{ "aogon", "\xc4\x85", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL A  */
	{ "aopf", "\xf0\x9d\x95\x92", 4 },
	/*  ALMOST EQUAL TO  */
	{ "ap", "\xe2\x89\x88", 3 },
	/*  APPROXIMATELY EQUAL OR EQUAL TO  */
	{ "apE", "\xe2\xa9\xb0", 3 },
	/*  ALMOST EQUAL TO WITH CIRCUMFLEX ACCENT  */
	{ "apacir", "\xe2\xa9\xaf", 3 },
	/*  ALMOST EQUAL OR EQUAL TO  */
	{ "ape", "\xe2\x89\x8a", 3 },
	/*  TRIPLE TILDE  */
	{ "apid", "\xe2\x89\x8b", 3 },
	/*  APOSTROPHE  */
	{ "apos", "\x27", 1 },
	/*  ALMOST EQUAL TO  */
	{ "approx", "\xe2\x89\x88", 3 },
	/*  ALMOST EQUAL OR EQUAL TO  */
	{ "approxeq", "\xe2\x89\x8a", 3 },
	/*  LATIN SMALL LETTER A WITH RING ABOVE  */
	{ "aring", "\xc3\xa5", 2 },
	/*  LEFTWARDS ARROW ABOVE SHORT RIGHTWARDS ARROW  */
	{ "arrllsr", "\xe2\xa5\x83", 3 },
	/*  RIGHTWARDS ARROW ABOVE SHORT LEFTWARDS ARROW  */
	{ "arrlrsl", "\xe2\xa5\x82", 3 },
	/*  SHORT RIGHTWARDS ARROW ABOVE LEFTWARDS ARROW  */
	{ "arrsrll", "\xe2\xa5\x84", 3 },
	/*  MATHEMATICAL SCRIPT SMALL A  */
	{ "ascr", "\xf0\x9d\x92\xb6", 4 },
	/*  ASTERISK  */
	{ "ast", "\x2a", 1 },
	/*  SQUARED ASTERISK  */
	{ "astb", "\xe2\xa7\x86", 3 },
	/*  ALMOST EQUAL TO  */
	{ "asymp", "\xe2\x89\x88", 3 },
	/*  EQUIVALENT TO  */
	{ "asympeq", "\xe2\x89\x8d", 3 },
	/*  LATIN SMALL LETTER A WITH TILDE  */
	{ "atilde", "\xc3\xa3", 2 },
	/*  LATIN SMALL LETTER A WITH DIAERESIS  */
	{ "auml", "\xc3\xa4", 2 },
	/*  ANTICLOCKWISE CONTOUR INTEGRAL  */
	{ "awconint", "\xe2\x88\xb3", 3 },
	/*  ANTICLOCKWISE INTEGRATION  */
	{ "awint", "\xe2\xa8\x91", 3 },
	/*  MATHEMATICAL BOLD CAPITAL DELTA  */
	{ "b.Delta", "\xf0\x9d\x9a\xab", 4 },
	/*  MATHEMATICAL BOLD CAPITAL GAMMA  */
	{ "b.Gamma", "\xf0\x9d\x9a\xaa", 4 },
	/*  MATHEMATICAL BOLD CAPITAL DIGAMMA  */
	{ "b.Gammad", "\xf0\x9d\x9f\x8a", 4 },
	/*  MATHEMATICAL BOLD CAPITAL LAMDA  */
	{ "b.Lambda", "\xf0\x9d\x9a\xb2", 4 },
	/*  MATHEMATICAL BOLD CAPITAL OMEGA  */
	{ "b.Omega", "\xf0\x9d\x9b\x80", 4 },
	/*  MATHEMATICAL BOLD CAPITAL PHI  */
	{ "b.Phi", "\xf0\x9d\x9a\xbd", 4 },
	/*  MATHEMATICAL BOLD CAPITAL PI  */
	{ "b.Pi", "\xf0\x9d\x9a\xb7", 4 },
	/*  MATHEMATICAL BOLD CAPITAL PSI  */
	{ "b.Psi", "\xf0\x9d\x9a\xbf", 4 },
	/*  MATHEMATICAL BOLD CAPITAL SIGMA  */
	{ "b.Sigma", "\xf0\x9d\x9a\xba", 4 },
	/*  MATHEMATICAL BOLD CAPITAL THETA  */
	{ "b.Theta", "\xf0\x9d\x9a\xaf", 4 },
	/*  MATHEMATICAL BOLD CAPITAL UPSILON  */
	{ "b.Upsi", "\xf0\x9d\x9a\xbc", 4 },
	/*  MATHEMATICAL BOLD CAPITAL XI  */
	{ "b.Xi", "\xf0\x9d\x9a\xb5", 4 },
	/*  MATHEMATICAL BOLD SMALL ALPHA  */
	{ "b.alpha", "\xf0\x9d\x9b\x82", 4 },
	/*  MATHEMATICAL BOLD SMALL BETA  */
	{ "b.beta", "\xf0\x9d\x9b\x83", 4 },
	/*  MATHEMATICAL BOLD SMALL CHI  */
	{ "b.chi", "\xf0\x9d\x9b\x98", 4 },
	/*  MATHEMATICAL BOLD SMALL DELTA  */
	{ "b.delta", "\xf0\x9d\x9b\x85", 4 },
	/*  MATHEMATICAL BOLD SMALL EPSILON  */
	{ "b.epsi", "\xf0\x9d\x9b\x86", 4 },
	/*  MATHEMATICAL BOLD EPSILON SYMBOL  */
	{ "b.epsiv", "\xf0\x9d\x9b\x9c", 4 },
	/*  MATHEMATICAL BOLD SMALL ETA  */
	{ "b.eta", "\xf0\x9d\x9b\x88", 4 },
	/*  MATHEMATICAL BOLD SMALL GAMMA  */
	{ "b.gamma", "\xf0\x9d\x9b\x84", 4 },
	/*  MATHEMATICAL BOLD SMALL DIGAMMA  */
	{ "b.gammad", "\xf0\x9d\x9f\x8b", 4 },
	/*  MATHEMATICAL BOLD SMALL IOTA  */
	{ "b.iota", "\xf0\x9d\x9b\x8a", 4 },
	/*  MATHEMATICAL BOLD SMALL KAPPA  */
	{ "b.kappa", "\xf0\x9d\x9b\x8b", 4 },
	/*  MATHEMATICAL BOLD KAPPA SYMBOL  */
	{ "b.kappav", "\xf0\x9d\x9b\x9e", 4 },
	/*  MATHEMATICAL BOLD SMALL LAMDA  */
	{ "b.lambda", "\xf0\x9d\x9b\x8c", 4 },
	/*  MATHEMATICAL BOLD SMALL MU  */
	{ "b.mu", "\xf0\x9d\x9b\x8d", 4 },
	/*  MATHEMATICAL BOLD SMALL NU  */
	{ "b.nu", "\xf0\x9d\x9b\x8e", 4 },
	/*  MATHEMATICAL BOLD SMALL OMEGA  */
	{ "b.omega", "\xf0\x9d\x9b\x9a", 4 },
	/*  MATHEMATICAL BOLD SMALL PHI  */
	{ "b.phi", "\xf0\x9d\x9b\x97", 4 },
	/*  MATHEMATICAL BOLD PHI SYMBOL  */
	{ "b.phiv", "\xf0\x9d\x9b\x9f", 4 },
	/*  MATHEMATICAL BOLD SMALL PI  */
	{ "b.pi", "\xf0\x9d\x9b\x91", 4 },
	/*  MATHEMATICAL BOLD PI SYMBOL  */
	{ "b.piv", "\xf0\x9d\x9b\xa1", 4 },
	/*  MATHEMATICAL BOLD SMALL PSI  */
	{ "b.psi", "\xf0\x9d\x9b\x99", 4 },
	/*  MATHEMATICAL BOLD SMALL RHO  */
	{ "b.rho", "\xf0\x9d\x9b\x92", 4 },
	/*  MATHEMATICAL BOLD RHO SYMBOL  */
	{ "b.rhov", "\xf0\x9d\x9b\xa0", 4 },
	/*  MATHEMATICAL BOLD SMALL SIGMA  */
	{ "b.sigma", "\xf0\x9d\x9b\x94", 4 },
	/*  MATHEMATICAL BOLD SMALL FINAL SIGMA  */
	{ "b.sigmav", "\xf0\x9d\x9b\x93", 4 },
	/*  MATHEMATICAL BOLD SMALL TAU  */
	{ "b.tau", "\xf0\x9d\x9b\x95", 4 },
	/*  MATHEMATICAL BOLD SMALL THETA  */
	{ "b.thetas", "\xf0\x9d\x9b\x89", 4 },
	/*  MATHEMATICAL BOLD THETA SYMBOL  */
	{ "b.thetav", "\xf0\x9d\x9b\x9d", 4 },
	/*  MATHEMATICAL BOLD SMALL UPSILON  */
	{ "b.upsi", "\xf0\x9d\x9b\x96", 4 },
	/*  MATHEMATICAL BOLD SMALL XI  */
	{ "b.xi", "\xf0\x9d\x9b\x8f", 4 },
	/*  MATHEMATICAL BOLD SMALL ZETA  */
	{ "b.zeta", "\xf0\x9d\x9b\x87", 4 },
	/*  REVERSED DOUBLE STROKE NOT SIGN  */
	{ "bNot", "\xe2\xab\xad", 3 },
	/*  ALL EQUAL TO  */
	{ "backcong", "\xe2\x89\x8c", 3 },
	/*  GREEK REVERSED LUNATE EPSILON SYMBOL  */
	{ "backepsilon", "\xcf\xb6", 2 },
	/*  REVERSED PRIME  */
	{ "backprime", "\xe2\x80\xb5", 3 },
	/*  REVERSED TILDE  */
	{ "backsim", "\xe2\x88\xbd", 3 },
	/*  REVERSED TILDE EQUALS  */
	{ "backsimeq", "\xe2\x8b\x8d", 3 },
	/*  DOUBLE DOWN TACK  */
	{ "barV", "\xe2\xab\xaa", 3 },
	/*  NOR  */
	{ "barvee", "\xe2\x8a\xbd", 3 },
	/*  PROJECTIVE  */
	{ "barwed", "\xe2\x8c\x85", 3 },
	/*  PROJECTIVE  */
	{ "barwedge", "\xe2\x8c\x85", 3 },
	/*  BOTTOM SQUARE BRACKET  */
	{ "bbrk", "\xe2\x8e\xb5", 3 },
	/*  BOTTOM SQUARE BRACKET OVER TOP SQUARE BRACKET  */
	{ "bbrktbrk", "\xe2\x8e\xb6", 3 },
	/*  ALL EQUAL TO  */
	{ "bcong", "\xe2\x89\x8c", 3 },
	/*  CYRILLIC SMALL LETTER BE  */
	{ "bcy", "\xd0\xb1", 2 },
	/*  DOWNWARDS HARPOON WITH BARB LEFT FROM BAR  */
	{ "bdlhar", "\xe2\xa5\xa1", 3 },
	/*  DOUBLE LOW-9 QUOTATION MARK  */
	{ "bdquo", "\xe2\x80\x9e", 3 },
	/*  DOWNWARDS HARPOON WITH BARB RIGHT FROM BAR  */
	{ "bdrhar", "\xe2\xa5\x9d", 3 },
	/*  BECAUSE  */
	{ "becaus", "\xe2\x88\xb5", 3 },
	/*  BECAUSE  */
	{ "because", "\xe2\x88\xb5", 3 },
	/*  REVERSED EMPTY SET  */
	{ "bemptyv", "\xe2\xa6\xb0", 3 },
	/*  GREEK REVERSED LUNATE EPSILON SYMBOL  */
	{ "bepsi", "\xcf\xb6", 2 },
	/*  SCRIPT CAPITAL B  */
	{ "bernou", "\xe2\x84\xac", 3 },
	/*  GREEK SMALL LETTER BETA  */
	{ "beta", "\xce\xb2", 2 },
	/*  BET SYMBOL  */
	{ "beth", "\xe2\x84\xb6", 3 },
	/*  BETWEEN  */
	{ "between", "\xe2\x89\xac", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL B  */
	{ "bfr", "\xf0\x9d\x94\x9f", 4 },
	/*  GREEK SMALL LETTER BETA  */
	{ "bgr", "\xce\xb2", 2 },
	/*  N-ARY INTERSECTION  */
	{ "bigcap", "\xe2\x8b\x82", 3 },
	/*  LARGE CIRCLE  */
	{ "bigcirc", "\xe2\x97\xaf", 3 },
	/*  N-ARY UNION  */
	{ "bigcup", "\xe2\x8b\x83", 3 },
	/*  N-ARY CIRCLED DOT OPERATOR  */
	{ "bigodot", "\xe2\xa8\x80", 3 },
	/*  N-ARY CIRCLED PLUS OPERATOR  */
	{ "bigoplus", "\xe2\xa8\x81", 3 },
	/*  N-ARY CIRCLED TIMES OPERATOR  */
	{ "bigotimes", "\xe2\xa8\x82", 3 },
	/*  N-ARY SQUARE UNION OPERATOR  */
	{ "bigsqcup", "\xe2\xa8\x86", 3 },
	/*  BLACK STAR  */
	{ "bigstar", "\xe2\x98\x85", 3 },
	/*  WHITE DOWN-POINTING TRIANGLE  */
	{ "bigtriangledown", "\xe2\x96\xbd", 3 },
	/*  WHITE UP-POINTING TRIANGLE  */
	{ "bigtriangleup", "\xe2\x96\xb3", 3 },
	/*  N-ARY UNION OPERATOR WITH PLUS  */
	{ "biguplus", "\xe2\xa8\x84", 3 },
	/*  N-ARY LOGICAL OR  */
	{ "bigvee", "\xe2\x8b\x81", 3 },
	/*  N-ARY LOGICAL AND  */
	{ "bigwedge", "\xe2\x8b\x80", 3 },
	/*  RIGHTWARDS DOUBLE DASH ARROW  */
	{ "bkarow", "\xe2\xa4\x8d", 3 },
	/*  BLACK LOZENGE  */
	{ "blacklozenge", "\xe2\xa7\xab", 3 },
	/*  BLACK SMALL SQUARE  */
	{ "blacksquare", "\xe2\x96\xaa", 3 },
	/*  BLACK UP-POINTING SMALL TRIANGLE  */
	{ "blacktriangle", "\xe2\x96\xb4", 3 },
	/*  BLACK DOWN-POINTING SMALL TRIANGLE  */
	{ "blacktriangledown", "\xe2\x96\xbe", 3 },
	/*  BLACK LEFT-POINTING SMALL TRIANGLE  */
	{ "blacktriangleleft", "\xe2\x97\x82", 3 },
	/*  BLACK RIGHT-POINTING SMALL TRIANGLE  */
	{ "blacktriangleright", "\xe2\x96\xb8", 3 },
	/*  OPEN BOX  */
	{ "blank", "\xe2\x90\xa3", 3 },
	/*  LEFTWARDS HARPOON WITH BARB DOWN FROM BAR  */
	{ "bldhar", "\xe2\xa5\x9e", 3 },
	/*  MEDIUM SHADE  */
	{ "blk12", "\xe2\x96\x92", 3 },
	/*  LIGHT SHADE  */
	{ "blk14", "\xe2\x96\x91", 3 },
	/*  DARK SHADE  */
	{ "blk34", "\xe2\x96\x93", 3 },
	/*  FULL BLOCK  */
	{ "block", "\xe2\x96\x88", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UP FROM BAR  */
	{ "bluhar", "\xe2\xa5\x9a", 3 },
	/*  EQUALS SIGN with reverse slash  */
	{ "bne", "\x3d\xe2\x83\xa5", 4 },
	/*  IDENTICAL TO with reverse slash  */
	{ "bnequiv", "\xe2\x89\xa1\xe2\x83\xa5", 6 },
	/*  REVERSED NOT SIGN  */
	{ "bnot", "\xe2\x8c\x90", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL B  */
	{ "bopf", "\xf0\x9d\x95\x93", 4 },
	/*  UP TACK  */
	{ "bot", "\xe2\x8a\xa5", 3 },
	/*  UP TACK  */
	{ "bottom", "\xe2\x8a\xa5", 3 },
	/*  BOWTIE  */
	{ "bowtie", "\xe2\x8b\x88", 3 },
	/*  BOX DRAWINGS DOUBLE DOWN AND LEFT  */
	{ "boxDL", "\xe2\x95\x97", 3 },
	/*  BOX DRAWINGS DOUBLE DOWN AND RIGHT  */
	{ "boxDR", "\xe2\x95\x94", 3 },
	/*  BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE  */
	{ "boxDl", "\xe2\x95\x96", 3 },
	/*  BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE  */
	{ "boxDr", "\xe2\x95\x93", 3 },
	/*  BOX DRAWINGS DOUBLE HORIZONTAL  */
	{ "boxH", "\xe2\x95\x90", 3 },
	/*  BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL  */
	{ "boxHD", "\xe2\x95\xa6", 3 },
	/*  BOX DRAWINGS DOUBLE UP AND HORIZONTAL  */
	{ "boxHU", "\xe2\x95\xa9", 3 },
	/*  BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE  */
	{ "boxHd", "\xe2\x95\xa4", 3 },
	/*  BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE  */
	{ "boxHu", "\xe2\x95\xa7", 3 },
	/*  BOX DRAWINGS DOUBLE UP AND LEFT  */
	{ "boxUL", "\xe2\x95\x9d", 3 },
	/*  BOX DRAWINGS DOUBLE UP AND RIGHT  */
	{ "boxUR", "\xe2\x95\x9a", 3 },
	/*  BOX DRAWINGS UP DOUBLE AND LEFT SINGLE  */
	{ "boxUl", "\xe2\x95\x9c", 3 },
	/*  BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE  */
	{ "boxUr", "\xe2\x95\x99", 3 },
	/*  BOX DRAWINGS DOUBLE VERTICAL  */
	{ "boxV", "\xe2\x95\x91", 3 },
	/*  BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL  */
	{ "boxVH", "\xe2\x95\xac", 3 },
	/*  BOX DRAWINGS DOUBLE VERTICAL AND LEFT  */
	{ "boxVL", "\xe2\x95\xa3", 3 },
	/*  BOX DRAWINGS DOUBLE VERTICAL AND RIGHT  */
	{ "boxVR", "\xe2\x95\xa0", 3 },
	/*  BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE  */
	{ "boxVh", "\xe2\x95\xab", 3 },
	/*  BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE  */
	{ "boxVl", "\xe2\x95\xa2", 3 },
	/*  BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE  */
	{ "boxVr", "\xe2\x95\x9f", 3 },
	/*  TWO JOINED SQUARES  */
	{ "boxbox", "\xe2\xa7\x89", 3 },
	/*  BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE  */
	{ "boxdL", "\xe2\x95\x95", 3 },
	/*  BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE  */
	{ "boxdR", "\xe2\x95\x92", 3 },
	/*  BOX DRAWINGS LIGHT DOWN AND LEFT  */
	{ "boxdl", "\xe2\x94\x90", 3 },
	/*  BOX DRAWINGS LIGHT DOWN AND RIGHT  */
	{ "boxdr", "\xe2\x94\x8c", 3 },
	/*  BOX DRAWINGS LIGHT HORIZONTAL  */
	{ "boxh", "\xe2\x94\x80", 3 },
	/*  BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE  */
	{ "boxhD", "\xe2\x95\xa5", 3 },
	/*  BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE  */
	{ "boxhU", "\xe2\x95\xa8", 3 },
	/*  BOX DRAWINGS LIGHT DOWN AND HORIZONTAL  */
	{ "boxhd", "\xe2\x94\xac", 3 },
	/*  BOX DRAWINGS LIGHT UP AND HORIZONTAL  */
	{ "boxhu", "\xe2\x94\xb4", 3 },
	/*  SQUARED MINUS  */
	{ "boxminus", "\xe2\x8a\x9f", 3 },
	/*  SQUARED PLUS  */
	{ "boxplus", "\xe2\x8a\x9e", 3 },
	/*  SQUARED TIMES  */
	{ "boxtimes", "\xe2\x8a\xa0", 3 },
	/*  BOX DRAWINGS UP SINGLE AND LEFT DOUBLE  */
	{ "boxuL", "\xe2\x95\x9b", 3 },
	/*  BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE  */
	{ "boxuR", "\xe2\x95\x98", 3 },
	/*  BOX DRAWINGS LIGHT UP AND LEFT  */
	{ "boxul", "\xe2\x94\x98", 3 },
	/*  BOX DRAWINGS LIGHT UP AND RIGHT  */
	{ "boxur", "\xe2\x94\x94", 3 },
	/*  BOX DRAWINGS LIGHT VERTICAL  */
	{ "boxv", "\xe2\x94\x82", 3 },
	/*  BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE  */
	{ "boxvH", "\xe2\x95\xaa", 3 },
	/*  BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE  */
	{ "boxvL", "\xe2\x95\xa1", 3 },
	/*  BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE  */
	{ "boxvR", "\xe2\x95\x9e", 3 },
	/*  BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL  */
	{ "boxvh", "\xe2\x94\xbc", 3 },
	/*  BOX DRAWINGS LIGHT VERTICAL AND LEFT  */
	{ "boxvl", "\xe2\x94\xa4", 3 },
	/*  BOX DRAWINGS LIGHT VERTICAL AND RIGHT  */
	{ "boxvr", "\xe2\x94\x9c", 3 },
	/*  REVERSED PRIME  */
	{ "bprime", "\xe2\x80\xb5", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWN FROM BAR  */
	{ "brdhar", "\xe2\xa5\x9f", 3 },
	/*  BREVE  */
	{ "breve", "\xcb\x98", 2 },
	/*  RIGHTWARDS HARPOON WITH BARB UP FROM BAR  */
	{ "bruhar", "\xe2\xa5\x9b", 3 },
	/*  BROKEN BAR  */
	{ "brvbar", "\xc2\xa6", 2 },
	/*  MATHEMATICAL SCRIPT SMALL B  */
	{ "bscr", "\xf0\x9d\x92\xb7", 4 },
	/*  REVERSED SEMICOLON  */
	{ "bsemi", "\xe2\x81\x8f", 3 },
	/*  REVERSED TILDE  */
	{ "bsim", "\xe2\x88\xbd", 3 },
	/*  REVERSED TILDE EQUALS  */
	{ "bsime", "\xe2\x8b\x8d", 3 },
	/*  REVERSE SOLIDUS  */
	{ "bsol", "\x5c", 1 },
	/*  SQUARED FALLING DIAGONAL SLASH  */
	{ "bsolb", "\xe2\xa7\x85", 3 },
	/*  REVERSE SOLIDUS PRECEDING SUBSET  */
	{ "bsolhsub", "\xe2\x9f\x88", 3 },
	/*  SEMIDIRECT PRODUCT WITH BOTTOM CLOSED  */
	{ "btimes", "\xe2\xa8\xb2", 3 },
	/*  UPWARDS HARPOON WITH BARB LEFT FROM BAR  */
	{ "bulhar", "\xe2\xa5\xa0", 3 },
	/*  BULLET  */
	{ "bull", "\xe2\x80\xa2", 3 },
	/*  BULLET  */
	{ "bullet", "\xe2\x80\xa2", 3 },
	/*  GEOMETRICALLY EQUIVALENT TO  */
	{ "bump", "\xe2\x89\x8e", 3 },
	/*  EQUALS SIGN WITH BUMPY ABOVE  */
	{ "bumpE", "\xe2\xaa\xae", 3 },
	/*  DIFFERENCE BETWEEN  */
	{ "bumpe", "\xe2\x89\x8f", 3 },
	/*  DIFFERENCE BETWEEN  */
	{ "bumpeq", "\xe2\x89\x8f", 3 },
	/*  UPWARDS HARPOON WITH BARB RIGHT FROM BAR  */
	{ "burhar", "\xe2\xa5\x9c", 3 },
	/*  LATIN SMALL LETTER C WITH ACUTE  */
	{ "cacute", "\xc4\x87", 2 },
	/*  INTERSECTION  */
	{ "cap", "\xe2\x88\xa9", 3 },
	/*  INTERSECTION WITH LOGICAL AND  */
	{ "capand", "\xe2\xa9\x84", 3 },
	/*  INTERSECTION ABOVE BAR ABOVE UNION  */
	{ "capbrcup", "\xe2\xa9\x89", 3 },
	/*  INTERSECTION BESIDE AND JOINED WITH INTERSECTION  */
	{ "capcap", "\xe2\xa9\x8b", 3 },
	/*  INTERSECTION ABOVE UNION  */
	{ "capcup", "\xe2\xa9\x87", 3 },
	/*  INTERSECTION WITH DOT  */
	{ "capdot", "\xe2\xa9\x80", 3 },
	/*  INTEGRAL WITH INTERSECTION  */
	{ "capint", "\xe2\xa8\x99", 3 },
	/*  INTERSECTION with serifs  */
	{ "caps", "\xe2\x88\xa9\xef\xb8\x80", 6 },
	/*  CARET INSERTION POINT  */
	{ "caret", "\xe2\x81\x81", 3 },
	/*  CARON  */
	{ "caron", "\xcb\x87", 2 },
	/*  CLOSED INTERSECTION WITH SERIFS  */
	{ "ccaps", "\xe2\xa9\x8d", 3 },
	/*  LATIN SMALL LETTER C WITH CARON  */
	{ "ccaron", "\xc4\x8d", 2 },
	/*  LATIN SMALL LETTER C WITH CEDILLA  */
	{ "ccedil", "\xc3\xa7", 2 },
	/*  LATIN SMALL LETTER C WITH CIRCUMFLEX  */
	{ "ccirc", "\xc4\x89", 2 },
	/*  CLOSED UNION WITH SERIFS  */
	{ "ccups", "\xe2\xa9\x8c", 3 },
	/*  CLOSED UNION WITH SERIFS AND SMASH PRODUCT  */
	{ "ccupssm", "\xe2\xa9\x90", 3 },
	/*  LATIN SMALL LETTER C WITH DOT ABOVE  */
	{ "cdot", "\xc4\x8b", 2 },
	/*  CEDILLA  */
	{ "cedil", "\xc2\xb8", 2 },
	/*  EMPTY SET WITH SMALL CIRCLE ABOVE  */
	{ "cemptyv", "\xe2\xa6\xb2", 3 },
	/*  CENT SIGN  */
	{ "cent", "\xc2\xa2", 2 },
	/*  MIDDLE DOT  */
	{ "centerdot", "\xc2\xb7", 2 },
	/*  MATHEMATICAL FRAKTUR SMALL C  */
	{ "cfr", "\xf0\x9d\x94\xa0", 4 },
	/*  CYRILLIC SMALL LETTER CHE  */
	{ "chcy", "\xd1\x87", 2 },
	/*  CHECK MARK  */
	{ "check", "\xe2\x9c\x93", 3 },
	/*  CHECK MARK  */
	{ "checkmark", "\xe2\x9c\x93", 3 },
	/*  GREEK SMALL LETTER CHI  */
	{ "chi", "\xcf\x87", 2 },
	/*  WHITE CIRCLE  */
	{ "cir", "\xe2\x97\x8b", 3 },
	/*  CIRCLE WITH TWO HORIZONTAL STROKES TO THE RIGHT  */
	{ "cirE", "\xe2\xa7\x83", 3 },
	/*  SQUARED SMALL CIRCLE  */
	{ "cirb", "\xe2\xa7\x87", 3 },
	/*  MODIFIER LETTER CIRCUMFLEX ACCENT  */
	{ "circ", "\xcb\x86", 2 },
	/*  RING EQUAL TO  */
	{ "circeq", "\xe2\x89\x97", 3 },
	/*  ANTICLOCKWISE OPEN CIRCLE ARROW  */
	{ "circlearrowleft", "\xe2\x86\xba", 3 },
	/*  CLOCKWISE OPEN CIRCLE ARROW  */
	{ "circlearrowright", "\xe2\x86\xbb", 3 },
	/*  REGISTERED SIGN  */
	{ "circledR", "\xc2\xae", 2 },
	/*  CIRCLED LATIN CAPITAL LETTER S  */
	{ "circledS", "\xe2\x93\x88", 3 },
	/*  CIRCLED ASTERISK OPERATOR  */
	{ "circledast", "\xe2\x8a\x9b", 3 },
	/*  CIRCLED RING OPERATOR  */
	{ "circledcirc", "\xe2\x8a\x9a", 3 },
	/*  CIRCLED DASH  */
	{ "circleddash", "\xe2\x8a\x9d", 3 },
	/*  WHITE CIRCLE WITH DOWN ARROW  */
	{ "cirdarr", "\xe2\xa7\xac", 3 },
	/*  RING EQUAL TO  */
	{ "cire", "\xe2\x89\x97", 3 },
	/*  ERROR-BARRED WHITE CIRCLE  */
	{ "cirerr", "\xe2\xa7\xb2", 3 },
	/*  BLACK CIRCLE WITH DOWN ARROW  */
	{ "cirfdarr", "\xe2\xa7\xad", 3 },
	/*  ERROR-BARRED BLACK CIRCLE  */
	{ "cirferr", "\xe2\xa7\xb3", 3 },
	/*  CIRCULATION FUNCTION  */
	{ "cirfnint", "\xe2\xa8\x90", 3 },
	/*  VERTICAL LINE WITH CIRCLE ABOVE  */
	{ "cirmid", "\xe2\xab\xaf", 3 },
	/*  CIRCLE WITH SMALL CIRCLE TO THE RIGHT  */
	{ "cirscir", "\xe2\xa7\x82", 3 },
	/*  CLOSE UP  */
	{ "closur", "\xe2\x81\x90", 3 },
	/*  BLACK CLUB SUIT  */
	{ "clubs", "\xe2\x99\xa3", 3 },
	/*  BLACK CLUB SUIT  */
	{ "clubsuit", "\xe2\x99\xa3", 3 },
	/*  COLON  */
	{ "colon", "\x3a", 1 },
	/*  COLON EQUALS  */
	{ "colone", "\xe2\x89\x94", 3 },
	/*  COLON EQUALS  */
	{ "coloneq", "\xe2\x89\x94", 3 },
	/*  COMMA  */
	{ "comma", "\x2c", 1 },
	/*  COMMERCIAL AT  */
	{ "commat", "\x40", 1 },
	/*  COMPLEMENT  */
	{ "comp", "\xe2\x88\x81", 3 },
	/*  RING OPERATOR  */
	{ "compfn", "\xe2\x88\x98", 3 },
	/*  COMPLEMENT  */
	{ "complement", "\xe2\x88\x81", 3 },
	/*  DOUBLE-STRUCK CAPITAL C  */
	{ "complexes", "\xe2\x84\x82", 3 },
	/*  APPROXIMATELY EQUAL TO  */
	{ "cong", "\xe2\x89\x85", 3 },
	/*  CONGRUENT WITH DOT ABOVE  */
	{ "congdot", "\xe2\xa9\xad", 3 },
	/*  CONTOUR INTEGRAL  */
	{ "conint", "\xe2\x88\xae", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL C  */
	{ "copf", "\xf0\x9d\x95\x94", 4 },
	/*  N-ARY COPRODUCT  */
	{ "coprod", "\xe2\x88\x90", 3 },
	/*  COPYRIGHT SIGN  */
	{ "copy", "\xc2\xa9", 2 },
	/*  SOUND RECORDING COPYRIGHT  */
	{ "copysr", "\xe2\x84\x97", 3 },
	/*  DOWNWARDS ARROW WITH CORNER LEFTWARDS  */
	{ "crarr", "\xe2\x86\xb5", 3 },
	/*  BALLOT X  */
	{ "cross", "\xe2\x9c\x97", 3 },
	/*  MATHEMATICAL SCRIPT SMALL C  */
	{ "cscr", "\xf0\x9d\x92\xb8", 4 },
	/*  CLOSED SUBSET  */
	{ "csub", "\xe2\xab\x8f", 3 },
	/*  CLOSED SUBSET OR EQUAL TO  */
	{ "csube", "\xe2\xab\x91", 3 },
	/*  CLOSED SUPERSET  */
	{ "csup", "\xe2\xab\x90", 3 },
	/*  CLOSED SUPERSET OR EQUAL TO  */
	{ "csupe", "\xe2\xab\x92", 3 },
	/*  MIDLINE HORIZONTAL ELLIPSIS  */
	{ "ctdot", "\xe2\x8b\xaf", 3 },
	/*  RIGHT-SIDE ARC CLOCKWISE ARROW  */
	{ "cudarrl", "\xe2\xa4\xb8", 3 },
	/*  ARROW POINTING RIGHTWARDS THEN CURVING DOWNWARDS  */
	{ "cudarrr", "\xe2\xa4\xb5", 3 },
	/*  EQUAL TO OR PRECEDES  */
	{ "cuepr", "\xe2\x8b\x9e", 3 },
	/*  EQUAL TO OR SUCCEEDS  */
	{ "cuesc", "\xe2\x8b\x9f", 3 },
	/*  ANTICLOCKWISE TOP SEMICIRCLE ARROW  */
	{ "cularr", "\xe2\x86\xb6", 3 },
	/*  TOP ARC ANTICLOCKWISE ARROW WITH PLUS  */
	{ "cularrp", "\xe2\xa4\xbd", 3 },
	/*  UNION  */
	{ "cup", "\xe2\x88\xaa", 3 },
	/*  UNION ABOVE BAR ABOVE INTERSECTION  */
	{ "cupbrcap", "\xe2\xa9\x88", 3 },
	/*  UNION ABOVE INTERSECTION  */
	{ "cupcap", "\xe2\xa9\x86", 3 },
	/*  UNION BESIDE AND JOINED WITH UNION  */
	{ "cupcup", "\xe2\xa9\x8a", 3 },
	/*  MULTISET MULTIPLICATION  */
	{ "cupdot", "\xe2\x8a\x8d", 3 },
	/*  INTEGRAL WITH UNION  */
	{ "cupint", "\xe2\xa8\x9a", 3 },
	/*  UNION WITH LOGICAL OR  */
	{ "cupor", "\xe2\xa9\x85", 3 },
	/*  PRECEDES OR EQUAL TO  */
	{ "cupre", "\xe2\x89\xbc", 3 },
	/*  UNION with serifs  */
	{ "cups", "\xe2\x88\xaa\xef\xb8\x80", 6 },
	/*  CLOCKWISE TOP SEMICIRCLE ARROW  */
	{ "curarr", "\xe2\x86\xb7", 3 },
	/*  TOP ARC CLOCKWISE ARROW WITH MINUS  */
	{ "curarrm", "\xe2\xa4\xbc", 3 },
	/*  EQUAL TO OR PRECEDES  */
	{ "curlyeqprec", "\xe2\x8b\x9e", 3 },
	/*  EQUAL TO OR SUCCEEDS  */
	{ "curlyeqsucc", "\xe2\x8b\x9f", 3 },
	/*  CURLY LOGICAL OR  */
	{ "curlyvee", "\xe2\x8b\x8e", 3 },
	/*  CURLY LOGICAL AND  */
	{ "curlywedge", "\xe2\x8b\x8f", 3 },
	/*  CURRENCY SIGN  */
	{ "curren", "\xc2\xa4", 2 },
	/*  ANTICLOCKWISE TOP SEMICIRCLE ARROW  */
	{ "curvearrowleft", "\xe2\x86\xb6", 3 },
	/*  CLOCKWISE TOP SEMICIRCLE ARROW  */
	{ "curvearrowright", "\xe2\x86\xb7", 3 },
	/*  CURLY LOGICAL OR  */
	{ "cuvee", "\xe2\x8b\x8e", 3 },
	/*  CURLY LOGICAL AND  */
	{ "cuwed", "\xe2\x8b\x8f", 3 },
	/*  CLOCKWISE CONTOUR INTEGRAL  */
	{ "cwconint", "\xe2\x88\xb2", 3 },
	/*  CLOCKWISE INTEGRAL  */
	{ "cwint", "\xe2\x88\xb1", 3 },
	/*  CYLINDRICITY  */
	{ "cylcty", "\xe2\x8c\xad", 3 },
	/*  DOWNWARDS TRIPLE ARROW  */
	{ "dAarr", "\xe2\xa4\x8b", 3 },
	/*  DOWNWARDS DOUBLE ARROW  */
	{ "dArr", "\xe2\x87\x93", 3 },
	/*  DOWNWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT  */
	{ "dHar", "\xe2\xa5\xa5", 3 },
	/*  DAGGER  */
	{ "dagger", "\xe2\x80\xa0", 3 },
	/*  SQUARE WITH CONTOURED OUTLINE  */
	{ "dalembrt", "\xe2\xa7\xa0", 3 },
	/*  DALET SYMBOL  */
	{ "daleth", "\xe2\x84\xb8", 3 },
	/*  DOWNWARDS ARROW  */
	{ "darr", "\xe2\x86\x93", 3 },
	/*  DOWNWARDS PAIRED ARROWS  */
	{ "darr2", "\xe2\x87\x8a", 3 },
	/*  DOWNWARDS ARROW TO BAR  */
	{ "darrb", "\xe2\xa4\x93", 3 },
	/*  DOWNWARDS ARROW WITH HORIZONTAL STROKE  */
	{ "darrln", "\xe2\xa4\x88", 3 },
	/*  HYPHEN  */
	{ "dash", "\xe2\x80\x90", 3 },
	/*  DOUBLE VERTICAL BAR LEFT TURNSTILE  */
	{ "dashV", "\xe2\xab\xa3", 3 },
	/*  LEFT TACK  */
	{ "dashv", "\xe2\x8a\xa3", 3 },
	/*  RIGHTWARDS TRIPLE DASH ARROW  */
	{ "dbkarow", "\xe2\xa4\x8f", 3 },
	/*  DOUBLE ACUTE ACCENT  */
	{ "dblac", "\xcb\x9d", 2 },
	/*  LATIN SMALL LETTER D WITH CARON  */
	{ "dcaron", "\xc4\x8f", 2 },
	/*  CYRILLIC SMALL LETTER DE  */
	{ "dcy", "\xd0\xb4", 2 },
	/*  DOUBLE-STRUCK ITALIC SMALL D  */
	{ "dd", "\xe2\x85\x86", 3 },
	/*  DOUBLE DAGGER  */
	{ "ddagger", "\xe2\x80\xa1", 3 },
	/*  DOWNWARDS PAIRED ARROWS  */
	{ "ddarr", "\xe2\x87\x8a", 3 },
	/*  EQUALS SIGN WITH TWO DOTS ABOVE AND TWO DOTS BELOW  */
	{ "ddotseq", "\xe2\xa9\xb7", 3 },
	/*  DEGREE SIGN  */
	{ "deg", "\xc2\xb0", 2 },
	/*  GREEK SMALL LETTER DELTA  */
	{ "delta", "\xce\xb4", 2 },
	/*  EMPTY SET WITH OVERBAR  */
	{ "demptyv", "\xe2\xa6\xb1", 3 },
	/*  DOWN FISH TAIL  */
	{ "dfisht", "\xe2\xa5\xbf", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL D  */
	{ "dfr", "\xf0\x9d\x94\xa1", 4 },
	/*  GREEK SMALL LETTER DELTA  */
	{ "dgr", "\xce\xb4", 2 },
	/*  DOWNWARDS HARPOON WITH BARB LEFTWARDS  */
	{ "dharl", "\xe2\x87\x83", 3 },
	/*  DOWNWARDS HARPOON WITH BARB RIGHTWARDS  */
	{ "dharr", "\xe2\x87\x82", 3 },
	/*  DIAMOND OPERATOR  */
	{ "diam", "\xe2\x8b\x84", 3 },
	/*  BLACK DIAMOND WITH DOWN ARROW  */
	{ "diamdarr", "\xe2\xa7\xaa", 3 },
	/*  ERROR-BARRED WHITE DIAMOND  */
	{ "diamerr", "\xe2\xa7\xb0", 3 },
	/*  ERROR-BARRED BLACK DIAMOND  */
	{ "diamerrf", "\xe2\xa7\xb1", 3 },
	/*  DIAMOND OPERATOR  */
	{ "diamond", "\xe2\x8b\x84", 3 },
	/*  BLACK DIAMOND SUIT  */
	{ "diamondsuit", "\xe2\x99\xa6", 3 },
	/*  BLACK DIAMOND SUIT  */
	{ "diams", "\xe2\x99\xa6", 3 },
	/*  DIAERESIS  */
	{ "die", "\xc2\xa8", 2 },
	/*  GREEK SMALL LETTER DIGAMMA  */
	{ "digamma", "\xcf\x9d", 2 },
	/*  ELEMENT OF WITH LONG HORIZONTAL STROKE  */
	{ "disin", "\xe2\x8b\xb2", 3 },
	/*  DIVISION SIGN  */
	{ "div", "\xc3\xb7", 2 },
	/*  DIVISION SIGN  */
	{ "divide", "\xc3\xb7", 2 },
	/*  DIVISION TIMES  */
	{ "divideontimes", "\xe2\x8b\x87", 3 },
	/*  DIVISION TIMES  */
	{ "divonx", "\xe2\x8b\x87", 3 },
	/*  CYRILLIC SMALL LETTER DJE  */
	{ "djcy", "\xd1\x92", 2 },
	/*  SOUTH WEST ARROW  */
	{ "dlarr", "\xe2\x86\x99", 3 },
	/*  BOTTOM LEFT CORNER  */
	{ "dlcorn", "\xe2\x8c\x9e", 3 },
	/*  BOTTOM LEFT CROP  */
	{ "dlcrop", "\xe2\x8c\x8d", 3 },
	/*  DOWNWARDS HARPOON WITH BARB LEFT TO BAR  */
	{ "dlharb", "\xe2\xa5\x99", 3 },
	/*  DOLLAR SIGN  */
	{ "dollar", "\x24", 1 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL D  */
	{ "dopf", "\xf0\x9d\x95\x95", 4 },
	/*  DOT ABOVE  */
	{ "dot", "\xcb\x99", 2 },
	/*  APPROACHES THE LIMIT  */
	{ "doteq", "\xe2\x89\x90", 3 },
	/*  GEOMETRICALLY EQUAL TO  */
	{ "doteqdot", "\xe2\x89\x91", 3 },
	/*  DOT MINUS  */
	{ "dotminus", "\xe2\x88\xb8", 3 },
	/*  DOT PLUS  */
	{ "dotplus", "\xe2\x88\x94", 3 },
	/*  SQUARED DOT OPERATOR  */
	{ "dotsquare", "\xe2\x8a\xa1", 3 },
	/*  PERSPECTIVE  */
	{ "doublebarwedge", "\xe2\x8c\x86", 3 },
	/*  DOWNWARDS ARROW  */
	{ "downarrow", "\xe2\x86\x93", 3 },
	/*  DOWNWARDS PAIRED ARROWS  */
	{ "downdownarrows", "\xe2\x87\x8a", 3 },
	/*  DOWNWARDS HARPOON WITH BARB LEFTWARDS  */
	{ "downharpoonleft", "\xe2\x87\x83", 3 },
	/*  DOWNWARDS HARPOON WITH BARB RIGHTWARDS  */
	{ "downharpoonright", "\xe2\x87\x82", 3 },
	/*  SOUTH EAST ARROW  */
	{ "drarr", "\xe2\x86\x98", 3 },
	/*  RIGHTWARDS TWO-HEADED TRIPLE DASH ARROW  */
	{ "drbkarow", "\xe2\xa4\x90", 3 },
	/*  BOTTOM RIGHT CORNER  */
	{ "drcorn", "\xe2\x8c\x9f", 3 },
	/*  BOTTOM RIGHT CROP  */
	{ "drcrop", "\xe2\x8c\x8c", 3 },
	/*  DOWNWARDS HARPOON WITH BARB RIGHT TO BAR  */
	{ "drharb", "\xe2\xa5\x95", 3 },
	/*  MATHEMATICAL SCRIPT SMALL D  */
	{ "dscr", "\xf0\x9d\x92\xb9", 4 },
	/*  CYRILLIC SMALL LETTER DZE  */
	{ "dscy", "\xd1\x95", 2 },
	/*  SOLIDUS WITH OVERBAR  */
	{ "dsol", "\xe2\xa7\xb6", 3 },
	/*  LATIN SMALL LETTER D WITH STROKE  */
	{ "dstrok", "\xc4\x91", 2 },
	/*  DOWN RIGHT DIAGONAL ELLIPSIS  */
	{ "dtdot", "\xe2\x8b\xb1", 3 },
	/*  WHITE DOWN-POINTING SMALL TRIANGLE  */
	{ "dtri", "\xe2\x96\xbf", 3 },
	/*  BLACK DOWN-POINTING SMALL TRIANGLE  */
	{ "dtrif", "\xe2\x96\xbe", 3 },
	/*  DOWN-POINTING TRIANGLE WITH LEFT HALF BLACK  */
	{ "dtrilf", "\xe2\xa7\xa8", 3 },
	/*  DOWN-POINTING TRIANGLE WITH RIGHT HALF BLACK  */
	{ "dtrirf", "\xe2\xa7\xa9", 3 },
	/*  DOWNWARDS ARROW LEFTWARDS OF UPWARDS ARROW  */
	{ "duarr", "\xe2\x87\xb5", 3 },
	/*  DOWNWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT  */
	{ "duhar", "\xe2\xa5\xaf", 3 },
	/*  DOUBLE-ENDED MULTIMAP  */
	{ "dumap", "\xe2\xa7\x9f", 3 },
	/*  OBLIQUE ANGLE OPENING UP  */
	{ "dwangle", "\xe2\xa6\xa6", 3 },
	/*  CYRILLIC SMALL LETTER DZHE  */
	{ "dzcy", "\xd1\x9f", 2 },
	/*  LONG RIGHTWARDS SQUIGGLE ARROW  */
	{ "dzigrarr", "\xe2\x9f\xbf", 3 },
	/*  EQUALS SIGN WITH TWO DOTS ABOVE AND TWO DOTS BELOW  */
	{ "eDDot", "\xe2\xa9\xb7", 3 },
	/*  GEOMETRICALLY EQUAL TO  */
	{ "eDot", "\xe2\x89\x91", 3 },
	/*  GREEK SMALL LETTER EPSILON WITH TONOS  */
	{ "eacgr", "\xce\xad", 2 },
	/*  LATIN SMALL LETTER E WITH ACUTE  */
	{ "eacute", "\xc3\xa9", 2 },
	/*  EQUALS WITH ASTERISK  */
	{ "easter", "\xe2\xa9\xae", 3 },
	/*  LATIN SMALL LETTER E WITH CARON  */
	{ "ecaron", "\xc4\x9b", 2 },
	/*  RING IN EQUAL TO  */
	{ "ecir", "\xe2\x89\x96", 3 },
	/*  LATIN SMALL LETTER E WITH CIRCUMFLEX  */
	{ "ecirc", "\xc3\xaa", 2 },
	/*  EQUALS COLON  */
	{ "ecolon", "\xe2\x89\x95", 3 },
	/*  CYRILLIC SMALL LETTER E  */
	{ "ecy", "\xd1\x8d", 2 },
	/*  LATIN SMALL LETTER E WITH DOT ABOVE  */
	{ "edot", "\xc4\x97", 2 },
	/*  DOUBLE-STRUCK ITALIC SMALL E  */
	{ "ee", "\xe2\x85\x87", 3 },
	/*  GREEK SMALL LETTER ETA WITH TONOS  */
	{ "eeacgr", "\xce\xae", 2 },
	/*  GREEK SMALL LETTER ETA  */
	{ "eegr", "\xce\xb7", 2 },
	/*  APPROXIMATELY EQUAL TO OR THE IMAGE OF  */
	{ "efDot", "\xe2\x89\x92", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL E  */
	{ "efr", "\xf0\x9d\x94\xa2", 4 },
	/*  DOUBLE-LINE EQUAL TO OR GREATER-THAN  */
	{ "eg", "\xe2\xaa\x9a", 3 },
	/*  GREEK SMALL LETTER EPSILON  */
	{ "egr", "\xce\xb5", 2 },
	/*  LATIN SMALL LETTER E WITH GRAVE  */
	{ "egrave", "\xc3\xa8", 2 },
	/*  SLANTED EQUAL TO OR GREATER-THAN  */
	{ "egs", "\xe2\xaa\x96", 3 },
	/*  SLANTED EQUAL TO OR GREATER-THAN WITH DOT INSIDE  */
	{ "egsdot", "\xe2\xaa\x98", 3 },
	/*  DOUBLE-LINE EQUAL TO OR LESS-THAN  */
	{ "el", "\xe2\xaa\x99", 3 },
	/*  ELECTRICAL INTERSECTION  */
	{ "elinters", "\xe2\x8f\xa7", 3 },
	/*  SCRIPT SMALL L  */
	{ "ell", "\xe2\x84\x93", 3 },
	/*  SLANTED EQUAL TO OR LESS-THAN  */
	{ "els", "\xe2\xaa\x95", 3 },
	/*  SLANTED EQUAL TO OR LESS-THAN WITH DOT INSIDE  */
	{ "elsdot", "\xe2\xaa\x97", 3 },
	/*  LATIN SMALL LETTER E WITH MACRON  */
	{ "emacr", "\xc4\x93", 2 },
	/*  EMPTY SET  */
	{ "empty", "\xe2\x88\x85", 3 },
	/*  EMPTY SET  */
	{ "emptyset", "\xe2\x88\x85", 3 },
	/*  EMPTY SET  */
	{ "emptyv", "\xe2\x88\x85", 3 },
	/*  EM SPACE  */
	{ "emsp", "\xe2\x80\x83", 3 },
	/*  THREE-PER-EM SPACE  */
	{ "emsp13", "\xe2\x80\x84", 3 },
	/*  FOUR-PER-EM SPACE  */
	{ "emsp14", "\xe2\x80\x85", 3 },
	/*  LATIN SMALL LETTER ENG  */
	{ "eng", "\xc5\x8b", 2 },
	/*  EN SPACE  */
	{ "ensp", "\xe2\x80\x82", 3 },
	/*  LATIN SMALL LETTER E WITH OGONEK  */
	{ "eogon", "\xc4\x99", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL E  */
	{ "eopf", "\xf0\x9d\x95\x96", 4 },
	/*  EQUAL AND PARALLEL TO  */
	{ "epar", "\xe2\x8b\x95", 3 },
	/*  EQUALS SIGN AND SLANTED PARALLEL  */
	{ "eparsl", "\xe2\xa7\xa3", 3 },
	/*  EQUALS SIGN ABOVE PLUS SIGN  */
	{ "eplus", "\xe2\xa9\xb1", 3 },
	/*  GREEK SMALL LETTER EPSILON  */
	{ "epsi", "\xce\xb5", 2 },
	/*  GREEK SMALL LETTER EPSILON  */
	{ "epsilon", "\xce\xb5", 2 },
	/*  GREEK LUNATE EPSILON SYMBOL  */
	{ "epsis", "\xcf\xb5", 2 },
	/*  GREEK LUNATE EPSILON SYMBOL  */
	{ "epsiv", "\xcf\xb5", 2 },
	/*  RING IN EQUAL TO  */
	{ "eqcirc", "\xe2\x89\x96", 3 },
	/*  EQUALS COLON  */
	{ "eqcolon", "\xe2\x89\x95", 3 },
	/*  TWO CONSECUTIVE EQUALS SIGNS  */
	{ "eqeq", "\xe2\xa9\xb5", 3 },
	/*  MINUS TILDE  */
	{ "eqsim", "\xe2\x89\x82", 3 },
	/*  SLANTED EQUAL TO OR GREATER-THAN  */
	{ "eqslantgtr", "\xe2\xaa\x96", 3 },
	/*  SLANTED EQUAL TO OR LESS-THAN  */
	{ "eqslantless", "\xe2\xaa\x95", 3 },
	/*  EQUALS SIGN  */
	{ "equals", "\x3d", 1 },
	/*  QUESTIONED EQUAL TO  */
	{ "equest", "\xe2\x89\x9f", 3 },
	/*  IDENTICAL TO  */
	{ "equiv", "\xe2\x89\xa1", 3 },
	/*  EQUIVALENT WITH FOUR DOTS ABOVE  */
	{ "equivDD", "\xe2\xa9\xb8", 3 },
	/*  IDENTICAL TO AND SLANTED PARALLEL  */
	{ "eqvparsl", "\xe2\xa7\xa5", 3 },
	/*  IMAGE OF OR APPROXIMATELY EQUAL TO  */
	{ "erDot", "\xe2\x89\x93", 3 },
	/*  EQUALS SIGN ABOVE RIGHTWARDS ARROW  */
	{ "erarr", "\xe2\xa5\xb1", 3 },
	/*  SCRIPT SMALL E  */
	{ "escr", "\xe2\x84\xaf", 3 },
	/*  APPROACHES THE LIMIT  */
	{ "esdot", "\xe2\x89\x90", 3 },
	/*  MINUS TILDE  */
	{ "esim", "\xe2\x89\x82", 3 },
	/*  GREEK SMALL LETTER ETA  */
	{ "eta", "\xce\xb7", 2 },
	/*  LATIN SMALL LETTER ETH  */
	{ "eth", "\xc3\xb0", 2 },
	/*  LATIN SMALL LETTER E WITH DIAERESIS  */
	{ "euml", "\xc3\xab", 2 },
	/*  EURO SIGN  */
	{ "euro", "\xe2\x82\xac", 3 },
	/*  EXCLAMATION MARK  */
	{ "excl", "\x21", 1 },
	/*  THERE EXISTS  */
	{ "exist", "\xe2\x88\x83", 3 },
	/*  SCRIPT CAPITAL E  */
	{ "expectation", "\xe2\x84\xb0", 3 },
	/*  DOUBLE-STRUCK ITALIC SMALL E  */
	{ "exponentiale", "\xe2\x85\x87", 3 },
	/*  APPROXIMATELY EQUAL TO OR THE IMAGE OF  */
	{ "fallingdotseq", "\xe2\x89\x92", 3 },
	/*  BLACK BOWTIE  */
	{ "fbowtie", "\xe2\xa7\x93", 3 },
	/*  CYRILLIC SMALL LETTER EF  */
	{ "fcy", "\xd1\x84", 2 },
	/*  BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT  */
	{ "fdiag", "\xe2\x95\xb2", 3 },
	/*  FALLING DIAGONAL CROSSING RISING DIAGONAL  */
	{ "fdiordi", "\xe2\xa4\xac", 3 },
	/*  FALLING DIAGONAL CROSSING NORTH EAST ARROW  */
	{ "fdonearr", "\xe2\xa4\xaf", 3 },
	/*  FEMALE SIGN  */
	{ "female", "\xe2\x99\x80", 3 },
	/*  LATIN SMALL LIGATURE FFI  */
	{ "ffilig", "\xef\xac\x83", 3 },
	/*  LATIN SMALL LIGATURE FF  */
	{ "fflig", "\xef\xac\x80", 3 },
	/*  LATIN SMALL LIGATURE FFL  */
	{ "ffllig", "\xef\xac\x84", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL F  */
	{ "ffr", "\xf0\x9d\x94\xa3", 4 },
	/*  BLACK HOURGLASS  */
	{ "fhrglass", "\xe2\xa7\x97", 3 },
	/*  LATIN SMALL LIGATURE FI  */
	{ "filig", "\xef\xac\x81", 3 },
	/*  fj ligature  */
	{ "fjlig", "\x66\x6a", 2 },
	/*  MUSIC FLAT SIGN  */
	{ "flat", "\xe2\x99\xad", 3 },
	/*  LATIN SMALL LIGATURE FL  */
	{ "fllig", "\xef\xac\x82", 3 },
	/*  WHITE PARALLELOGRAM  */
	{ "fltns", "\xe2\x96\xb1", 3 },
	/*  LATIN SMALL LETTER F WITH HOOK  */
	{ "fnof", "\xc6\x92", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL F  */
	{ "fopf", "\xf0\x9d\x95\x97", 4 },
	/*  FOR ALL  */
	{ "forall", "\xe2\x88\x80", 3 },
	/*  PITCHFORK  */
	{ "fork", "\xe2\x8b\x94", 3 },
	/*  ELEMENT OF OPENING DOWNWARDS  */
	{ "forkv", "\xe2\xab\x99", 3 },
	/*  FINITE PART INTEGRAL  */
	{ "fpartint", "\xe2\xa8\x8d", 3 },
	/*  VULGAR FRACTION ONE HALF  */
	{ "frac12", "\xc2\xbd", 2 },
	/*  VULGAR FRACTION ONE THIRD  */
	{ "frac13", "\xe2\x85\x93", 3 },
	/*  VULGAR FRACTION ONE QUARTER  */
	{ "frac14", "\xc2\xbc", 2 },
	/*  VULGAR FRACTION ONE FIFTH  */
	{ "frac15", "\xe2\x85\x95", 3 },
	/*  VULGAR FRACTION ONE SIXTH  */
	{ "frac16", "\xe2\x85\x99", 3 },
	/*  VULGAR FRACTION ONE EIGHTH  */
	{ "frac18", "\xe2\x85\x9b", 3 },
	/*  VULGAR FRACTION TWO THIRDS  */
	{ "frac23", "\xe2\x85\x94", 3 },
	/*  VULGAR FRACTION TWO FIFTHS  */
	{ "frac25", "\xe2\x85\x96", 3 },
	/*  VULGAR FRACTION THREE QUARTERS  */
	{ "frac34", "\xc2\xbe", 2 },
	/*  VULGAR FRACTION THREE FIFTHS  */
	{ "frac35", "\xe2\x85\x97", 3 },
	/*  VULGAR FRACTION THREE EIGHTHS  */
	{ "frac38", "\xe2\x85\x9c", 3 },
	/*  VULGAR FRACTION FOUR FIFTHS  */
	{ "frac45", "\xe2\x85\x98", 3 },
	/*  VULGAR FRACTION FIVE SIXTHS  */
	{ "frac56", "\xe2\x85\x9a", 3 },
	/*  VULGAR FRACTION FIVE EIGHTHS  */
	{ "frac58", "\xe2\x85\x9d", 3 },
	/*  VULGAR FRACTION SEVEN EIGHTHS  */
	{ "frac78", "\xe2\x85\x9e", 3 },
	/*  FRACTION SLASH  */
	{ "frasl", "\xe2\x81\x84", 3 },
	/*  FROWN  */
	{ "frown", "\xe2\x8c\xa2", 3 },
	/*  MATHEMATICAL SCRIPT SMALL F  */
	{ "fscr", "\xf0\x9d\x92\xbb", 4 },
	/*  GREATER-THAN OVER EQUAL TO  */
	{ "gE", "\xe2\x89\xa7", 3 },
	/*  GREATER-THAN ABOVE DOUBLE-LINE EQUAL ABOVE LESS-THAN  */
	{ "gEl", "\xe2\xaa\x8c", 3 },
	/*  LATIN SMALL LETTER G WITH ACUTE  */
	{ "gacute", "\xc7\xb5", 2 },
	/*  GREEK SMALL LETTER GAMMA  */
	{ "gamma", "\xce\xb3", 2 },
	/*  GREEK SMALL LETTER DIGAMMA  */
	{ "gammad", "\xcf\x9d", 2 },
	/*  GREATER-THAN OR APPROXIMATE  */
	{ "gap", "\xe2\xaa\x86", 3 },
	/*  LATIN SMALL LETTER G WITH BREVE  */
	{ "gbreve", "\xc4\x9f", 2 },
	/*  LATIN SMALL LETTER G WITH CEDILLA  */
	{ "gcedil", "\xc4\xa3", 2 },
	/*  LATIN SMALL LETTER G WITH CIRCUMFLEX  */
	{ "gcirc", "\xc4\x9d", 2 },
	/*  CYRILLIC SMALL LETTER GHE  */
	{ "gcy", "\xd0\xb3", 2 },
	/*  LATIN SMALL LETTER G WITH DOT ABOVE  */
	{ "gdot", "\xc4\xa1", 2 },
	/*  GREATER-THAN OR EQUAL TO  */
	{ "ge", "\xe2\x89\xa5", 3 },
	/*  GREATER-THAN EQUAL TO OR LESS-THAN  */
	{ "gel", "\xe2\x8b\x9b", 3 },
	/*  GREATER-THAN OR EQUAL TO  */
	{ "geq", "\xe2\x89\xa5", 3 },
	/*  GREATER-THAN OVER EQUAL TO  */
	{ "geqq", "\xe2\x89\xa7", 3 },
	/*  GREATER-THAN OR SLANTED EQUAL TO  */
	{ "geqslant", "\xe2\xa9\xbe", 3 },
	/*  GREATER-THAN OR SLANTED EQUAL TO  */
	{ "ges", "\xe2\xa9\xbe", 3 },
	/*  GREATER-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL  */
	{ "gescc", "\xe2\xaa\xa9", 3 },
	/*  GREATER-THAN OR SLANTED EQUAL TO WITH DOT INSIDE  */
	{ "gesdot", "\xe2\xaa\x80", 3 },
	/*  GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE  */
	{ "gesdoto", "\xe2\xaa\x82", 3 },
	/*  GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE LEFT  */
	{ "gesdotol", "\xe2\xaa\x84", 3 },
	/*  GREATER-THAN slanted EQUAL TO OR LESS-THAN  */
	{ "gesl", "\xe2\x8b\x9b\xef\xb8\x80", 6 },
	/*  GREATER-THAN ABOVE SLANTED EQUAL ABOVE LESS-THAN ABOVE SLANTED EQUAL  */
	{ "gesles", "\xe2\xaa\x94", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL G  */
	{ "gfr", "\xf0\x9d\x94\xa4", 4 },
	/*  MUCH GREATER-THAN  */
	{ "gg", "\xe2\x89\xab", 3 },
	/*  VERY MUCH GREATER-THAN  */
	{ "ggg", "\xe2\x8b\x99", 3 },
	/*  GREEK SMALL LETTER GAMMA  */
	{ "ggr", "\xce\xb3", 2 },
	/*  GIMEL SYMBOL  */
	{ "gimel", "\xe2\x84\xb7", 3 },
	/*  CYRILLIC SMALL LETTER GJE  */
	{ "gjcy", "\xd1\x93", 2 },
	/*  GREATER-THAN OR LESS-THAN  */
	{ "gl", "\xe2\x89\xb7", 3 },
	/*  GREATER-THAN ABOVE LESS-THAN ABOVE DOUBLE-LINE EQUAL  */
	{ "glE", "\xe2\xaa\x92", 3 },
	/*  GREATER-THAN BESIDE LESS-THAN  */
	{ "gla", "\xe2\xaa\xa5", 3 },
	/*  GREATER-THAN OVERLAPPING LESS-THAN  */
	{ "glj", "\xe2\xaa\xa4", 3 },
	/*  GREATER-THAN BUT NOT EQUAL TO  */
	{ "gnE", "\xe2\x89\xa9", 3 },
	/*  GREATER-THAN AND NOT APPROXIMATE  */
	{ "gnap", "\xe2\xaa\x8a", 3 },
	/*  GREATER-THAN AND NOT APPROXIMATE  */
	{ "gnapprox", "\xe2\xaa\x8a", 3 },
	/*  GREATER-THAN AND SINGLE-LINE NOT EQUAL TO  */
	{ "gne", "\xe2\xaa\x88", 3 },
	/*  GREATER-THAN AND SINGLE-LINE NOT EQUAL TO  */
	{ "gneq", "\xe2\xaa\x88", 3 },
	/*  GREATER-THAN BUT NOT EQUAL TO  */
	{ "gneqq", "\xe2\x89\xa9", 3 },
	/*  GREATER-THAN BUT NOT EQUIVALENT TO  */
	{ "gnsim", "\xe2\x8b\xa7", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL G  */
	{ "gopf", "\xf0\x9d\x95\x98", 4 },
	/*  GRAVE ACCENT  */
	{ "grave", "\x60", 1 },
	/*  SCRIPT SMALL G  */
	{ "gscr", "\xe2\x84\x8a", 3 },
	/*  GREATER-THAN WITH DOT  */
	{ "gsdot", "\xe2\x8b\x97", 3 },
	/*  GREATER-THAN OR EQUIVALENT TO  */
	{ "gsim", "\xe2\x89\xb3", 3 },
	/*  GREATER-THAN ABOVE SIMILAR OR EQUAL  */
	{ "gsime", "\xe2\xaa\x8e", 3 },
	/*  GREATER-THAN ABOVE SIMILAR ABOVE LESS-THAN  */
	{ "gsiml", "\xe2\xaa\x90", 3 },
	/*  GREATER-THAN SIGN  */
	{ "gt", "\x3e", 1 },
	/*  GREATER-THAN CLOSED BY CURVE  */
	{ "gtcc", "\xe2\xaa\xa7", 3 },
	/*  GREATER-THAN WITH CIRCLE INSIDE  */
	{ "gtcir", "\xe2\xa9\xba", 3 },
	/*  GREATER-THAN WITH DOT  */
	{ "gtdot", "\xe2\x8b\x97", 3 },
	/*  DOUBLE LEFT ARC GREATER-THAN BRACKET  */
	{ "gtlPar", "\xe2\xa6\x95", 3 },
	/*  GREATER-THAN WITH QUESTION MARK ABOVE  */
	{ "gtquest", "\xe2\xa9\xbc", 3 },
	/*  GREATER-THAN OR APPROXIMATE  */
	{ "gtrapprox", "\xe2\xaa\x86", 3 },
	/*  GREATER-THAN ABOVE RIGHTWARDS ARROW  */
	{ "gtrarr", "\xe2\xa5\xb8", 3 },
	/*  GREATER-THAN WITH DOT  */
	{ "gtrdot", "\xe2\x8b\x97", 3 },
	/*  GREATER-THAN EQUAL TO OR LESS-THAN  */
	{ "gtreqless", "\xe2\x8b\x9b", 3 },
	/*  GREATER-THAN ABOVE DOUBLE-LINE EQUAL ABOVE LESS-THAN  */
	{ "gtreqqless", "\xe2\xaa\x8c", 3 },
	/*  GREATER-THAN OR LESS-THAN  */
	{ "gtrless", "\xe2\x89\xb7", 3 },
	/*  SPHERICAL ANGLE OPENING LEFT  */
	{ "gtrpar", "\xe2\xa6\xa0", 3 },
	/*  GREATER-THAN OR EQUIVALENT TO  */
	{ "gtrsim", "\xe2\x89\xb3", 3 },
	/*  GREATER-THAN BUT NOT EQUAL TO - with vertical stroke  */
	{ "gvertneqq", "\xe2\x89\xa9\xef\xb8\x80", 6 },
	/*  GREATER-THAN BUT NOT EQUAL TO - with vertical stroke  */
	{ "gvnE", "\xe2\x89\xa9\xef\xb8\x80", 6 },
	/*  LEFT RIGHT DOUBLE ARROW  */
	{ "hArr", "\xe2\x87\x94", 3 },
	/*  HAIR SPACE  */
	{ "hairsp", "\xe2\x80\x8a", 3 },
	/*  VULGAR FRACTION ONE HALF  */
	{ "half", "\xc2\xbd", 2 },
	/*  SCRIPT CAPITAL H  */
	{ "hamilt", "\xe2\x84\x8b", 3 },
	/*  CYRILLIC SMALL LETTER HARD SIGN  */
	{ "hardcy", "\xd1\x8a", 2 },
	/*  LEFT RIGHT ARROW  */
	{ "harr", "\xe2\x86\x94", 3 },
	/*  LEFT RIGHT ARROW THROUGH SMALL CIRCLE  */
	{ "harrcir", "\xe2\xa5\x88", 3 },
	/*  LEFT RIGHT WAVE ARROW  */
	{ "harrw", "\xe2\x86\xad", 3 },
	/*  PLANCK CONSTANT OVER TWO PI  */
	{ "hbar", "\xe2\x84\x8f", 3 },
	/*  LATIN SMALL LETTER H WITH CIRCUMFLEX  */
	{ "hcirc", "\xc4\xa5", 2 },
	/*  BLACK HEART SUIT  */
	{ "hearts", "\xe2\x99\xa5", 3 },
	/*  BLACK HEART SUIT  */
	{ "heartsuit", "\xe2\x99\xa5", 3 },
	/*  HORIZONTAL ELLIPSIS  */
	{ "hellip", "\xe2\x80\xa6", 3 },
	/*  HERMITIAN CONJUGATE MATRIX  */
	{ "hercon", "\xe2\x8a\xb9", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL H  */
	{ "hfr", "\xf0\x9d\x94\xa5", 4 },
	/*  SOUTH EAST ARROW WITH HOOK  */
	{ "hksearow", "\xe2\xa4\xa5", 3 },
	/*  SOUTH WEST ARROW WITH HOOK  */
	{ "hkswarow", "\xe2\xa4\xa6", 3 },
	/*  LEFT RIGHT OPEN-HEADED ARROW  */
	{ "hoarr", "\xe2\x87\xbf", 3 },
	/*  HOMOTHETIC  */
	{ "homtht", "\xe2\x88\xbb", 3 },
	/*  LEFTWARDS ARROW WITH HOOK  */
	{ "hookleftarrow", "\xe2\x86\xa9", 3 },
	/*  RIGHTWARDS ARROW WITH HOOK  */
	{ "hookrightarrow", "\xe2\x86\xaa", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL H  */
	{ "hopf", "\xf0\x9d\x95\x99", 4 },
	/*  HORIZONTAL BAR  */
	{ "horbar", "\xe2\x80\x95", 3 },
	/*  WHITE HOURGLASS  */
	{ "hrglass", "\xe2\xa7\x96", 3 },
	/*  MATHEMATICAL SCRIPT SMALL H  */
	{ "hscr", "\xf0\x9d\x92\xbd", 4 },
	/*  PLANCK CONSTANT OVER TWO PI  */
	{ "hslash", "\xe2\x84\x8f", 3 },
	/*  LATIN SMALL LETTER H WITH STROKE  */
	{ "hstrok", "\xc4\xa7", 2 },
	/*  VECTOR OR CROSS PRODUCT  */
	{ "htimes", "\xe2\xa8\xaf", 3 },
	/*  HYPHEN BULLET  */
	{ "hybull", "\xe2\x81\x83", 3 },
	/*  HYPHEN  */
	{ "hyphen", "\xe2\x80\x90", 3 },
	/*  GREEK SMALL LETTER IOTA WITH TONOS  */
	{ "iacgr", "\xce\xaf", 2 },
	/*  LATIN SMALL LETTER I WITH ACUTE  */
	{ "iacute", "\xc3\xad", 2 },
	/*  INVISIBLE SEPARATOR  */
	{ "ic", "\xe2\x81\xa3", 3 },
	/*  LATIN SMALL LETTER I WITH CIRCUMFLEX  */
	{ "icirc", "\xc3\xae", 2 },
	/*  CYRILLIC SMALL LETTER I  */
	{ "icy", "\xd0\xb8", 2 },
	/*  GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS  */
	{ "idiagr", "\xce\x90", 2 },
	/*  GREEK SMALL LETTER IOTA WITH DIALYTIKA  */
	{ "idigr", "\xcf\x8a", 2 },
	/*  CYRILLIC SMALL LETTER IE  */
	{ "iecy", "\xd0\xb5", 2 },
	/*  INVERTED EXCLAMATION MARK  */
	{ "iexcl", "\xc2\xa1", 2 },
	/*  LEFT RIGHT DOUBLE ARROW  */
	{ "iff", "\xe2\x87\x94", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL I  */
	{ "ifr", "\xf0\x9d\x94\xa6", 4 },
	/*  GREEK SMALL LETTER IOTA  */
	{ "igr", "\xce\xb9", 2 },
	/*  LATIN SMALL LETTER I WITH GRAVE  */
	{ "igrave", "\xc3\xac", 2 },
	/*  DOUBLE-STRUCK ITALIC SMALL I  */
	{ "ii", "\xe2\x85\x88", 3 },
	/*  QUADRUPLE INTEGRAL OPERATOR  */
	{ "iiiint", "\xe2\xa8\x8c", 3 },
	/*  TRIPLE INTEGRAL  */
	{ "iiint", "\xe2\x88\xad", 3 },
	/*  INCOMPLETE INFINITY  */
	{ "iinfin", "\xe2\xa7\x9c", 3 },
	/*  TURNED GREEK SMALL LETTER IOTA  */
	{ "iiota", "\xe2\x84\xa9", 3 },
	/*  LATIN SMALL LIGATURE IJ  */
	{ "ijlig", "\xc4\xb3", 2 },
	/*  LATIN SMALL LETTER I WITH MACRON  */
	{ "imacr", "\xc4\xab", 2 },
	/*  BLACK-LETTER CAPITAL I  */
	{ "image", "\xe2\x84\x91", 3 },
	/*  SCRIPT CAPITAL I  */
	{ "imagline", "\xe2\x84\x90", 3 },
	/*  BLACK-LETTER CAPITAL I  */
	{ "imagpart", "\xe2\x84\x91", 3 },
	/*  LATIN SMALL LETTER DOTLESS I  */
	{ "imath", "\xc4\xb1", 2 },
	/*  IMAGE OF  */
	{ "imof", "\xe2\x8a\xb7", 3 },
	/*  LATIN CAPITAL LETTER Z WITH STROKE  */
	{ "imped", "\xc6\xb5", 2 },
	/*  ELEMENT OF  */
	{ "in", "\xe2\x88\x88", 3 },
	/*  CARE OF  */
	{ "incare", "\xe2\x84\x85", 3 },
	/*  INFINITY  */
	{ "infin", "\xe2\x88\x9e", 3 },
	/*  TIE OVER INFINITY  */
	{ "infintie", "\xe2\xa7\x9d", 3 },
	/*  LATIN SMALL LETTER DOTLESS I  */
	{ "inodot", "\xc4\xb1", 2 },
	/*  INTEGRAL  */
	{ "int", "\xe2\x88\xab", 3 },
	/*  INTERCALATE  */
	{ "intcal", "\xe2\x8a\xba", 3 },
	/*  DOUBLE-STRUCK CAPITAL Z  */
	{ "integers", "\xe2\x84\xa4", 3 },
	/*  INTERCALATE  */
	{ "intercal", "\xe2\x8a\xba", 3 },
	/*  INTEGRAL WITH LEFTWARDS ARROW WITH HOOK  */
	{ "intlarhk", "\xe2\xa8\x97", 3 },
	/*  INTERIOR PRODUCT  */
	{ "intprod", "\xe2\xa8\xbc", 3 },
	/*  CYRILLIC SMALL LETTER IO  */
	{ "iocy", "\xd1\x91", 2 },
	/*  LATIN SMALL LETTER I WITH OGONEK  */
	{ "iogon", "\xc4\xaf", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL I  */
	{ "iopf", "\xf0\x9d\x95\x9a", 4 },
	/*  GREEK SMALL LETTER IOTA  */
	{ "iota", "\xce\xb9", 2 },
	/*  INTERIOR PRODUCT  */
	{ "iprod", "\xe2\xa8\xbc", 3 },
	/*  RIGHTHAND INTERIOR PRODUCT  */
	{ "iprodr", "\xe2\xa8\xbd", 3 },
	/*  INVERTED QUESTION MARK  */
	{ "iquest", "\xc2\xbf", 2 },
	/*  MATHEMATICAL SCRIPT SMALL I  */
	{ "iscr", "\xf0\x9d\x92\xbe", 4 },
	/*  ELEMENT OF  */
	{ "isin", "\xe2\x88\x88", 3 },
	/*  ELEMENT OF WITH TWO HORIZONTAL STROKES  */
	{ "isinE", "\xe2\x8b\xb9", 3 },
	/*  ELEMENT OF WITH DOT ABOVE  */
	{ "isindot", "\xe2\x8b\xb5", 3 },
	/*  SMALL ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE  */
	{ "isins", "\xe2\x8b\xb4", 3 },
	/*  ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE  */
	{ "isinsv", "\xe2\x8b\xb3", 3 },
	/*  ELEMENT OF  */
	{ "isinv", "\xe2\x88\x88", 3 },
	/*  ELEMENT OF WITH UNDERBAR  */
	{ "isinvb", "\xe2\x8b\xb8", 3 },
	/*  INVISIBLE TIMES  */
	{ "it", "\xe2\x81\xa2", 3 },
	/*  LATIN SMALL LETTER I WITH TILDE  */
	{ "itilde", "\xc4\xa9", 2 },
	/*  CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I  */
	{ "iukcy", "\xd1\x96", 2 },
	/*  LATIN SMALL LETTER I WITH DIAERESIS  */
	{ "iuml", "\xc3\xaf", 2 },
	/*  LATIN SMALL LETTER J WITH CIRCUMFLEX  */
	{ "jcirc", "\xc4\xb5", 2 },
	/*  CYRILLIC SMALL LETTER SHORT I  */
	{ "jcy", "\xd0\xb9", 2 },
	/*  MATHEMATICAL FRAKTUR SMALL J  */
	{ "jfr", "\xf0\x9d\x94\xa7", 4 },
	/*  LATIN SMALL LETTER DOTLESS J  */
	{ "jmath", "\xc8\xb7", 2 },
	/*  LATIN SMALL LETTER DOTLESS J  */
	{ "jnodot", "\xc8\xb7", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL J  */
	{ "jopf", "\xf0\x9d\x95\x9b", 4 },
	/*  MATHEMATICAL SCRIPT SMALL J  */
	{ "jscr", "\xf0\x9d\x92\xbf", 4 },
	/*  CYRILLIC SMALL LETTER JE  */
	{ "jsercy", "\xd1\x98", 2 },
	/*  CYRILLIC SMALL LETTER UKRAINIAN IE  */
	{ "jukcy", "\xd1\x94", 2 },
	/*  GREEK SMALL LETTER KAPPA  */
	{ "kappa", "\xce\xba", 2 },
	/*  GREEK KAPPA SYMBOL  */
	{ "kappav", "\xcf\xb0", 2 },
	/*  LATIN SMALL LETTER K WITH CEDILLA  */
	{ "kcedil", "\xc4\xb7", 2 },
	/*  CYRILLIC SMALL LETTER KA  */
	{ "kcy", "\xd0\xba", 2 },
	/*  MATHEMATICAL FRAKTUR SMALL K  */
	{ "kfr", "\xf0\x9d\x94\xa8", 4 },
	/*  GREEK SMALL LETTER KAPPA  */
	{ "kgr", "\xce\xba", 2 },
	/*  LATIN SMALL LETTER KRA  */
	{ "kgreen", "\xc4\xb8", 2 },
	/*  CYRILLIC SMALL LETTER HA  */
	{ "khcy", "\xd1\x85", 2 },
	/*  GREEK SMALL LETTER CHI  */
	{ "khgr", "\xcf\x87", 2 },
	/*  CYRILLIC SMALL LETTER KJE  */
	{ "kjcy", "\xd1\x9c", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL K  */
	{ "kopf", "\xf0\x9d\x95\x9c", 4 },
	/*  GREEK LETTER KOPPA  */
	{ "koppa", "\xcf\x9e", 2 },
	/*  MATHEMATICAL SCRIPT SMALL K  */
	{ "kscr", "\xf0\x9d\x93\x80", 4 },
	/*  LEFTWARDS TRIPLE ARROW  */
	{ "lAarr", "\xe2\x87\x9a", 3 },
	/*  LEFTWARDS DOUBLE ARROW  */
	{ "lArr", "\xe2\x87\x90", 3 },
	/*  LEFTWARDS DOUBLE ARROW-TAIL  */
	{ "lAtail", "\xe2\xa4\x9b", 3 },
	/*  LEFTWARDS TRIPLE DASH ARROW  */
	{ "lBarr", "\xe2\xa4\x8e", 3 },
	/*  LESS-THAN OVER EQUAL TO  */
	{ "lE", "\xe2\x89\xa6", 3 },
	/*  LESS-THAN ABOVE DOUBLE-LINE EQUAL ABOVE GREATER-THAN  */
	{ "lEg", "\xe2\xaa\x8b", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB DOWN  */
	{ "lHar", "\xe2\xa5\xa2", 3 },
	/*  LATIN SMALL LETTER L WITH ACUTE  */
	{ "lacute", "\xc4\xba", 2 },
	/*  EMPTY SET WITH LEFT ARROW ABOVE  */
	{ "laemptyv", "\xe2\xa6\xb4", 3 },
	/*  SCRIPT CAPITAL L  */
	{ "lagran", "\xe2\x84\x92", 3 },
	/*  GREEK SMALL LETTER LAMDA  */
	{ "lambda", "\xce\xbb", 2 },
	/*  MATHEMATICAL LEFT ANGLE BRACKET  */
	{ "lang", "\xe2\x9f\xa8", 3 },
	/*  LEFT ANGLE BRACKET WITH DOT  */
	{ "langd", "\xe2\xa6\x91", 3 },
	/*  MATHEMATICAL LEFT ANGLE BRACKET  */
	{ "langle", "\xe2\x9f\xa8", 3 },
	/*  LESS-THAN OR APPROXIMATE  */
	{ "lap", "\xe2\xaa\x85", 3 },
	/*  LEFT-POINTING DOUBLE ANGLE QUOTATION MARK  */
	{ "laquo", "\xc2\xab", 2 },
	/*  LEFTWARDS ARROW  */
	{ "larr", "\xe2\x86\x90", 3 },
	/*  LEFTWARDS PAIRED ARROWS  */
	{ "larr2", "\xe2\x87\x87", 3 },
	/*  LEFTWARDS ARROW TO BAR  */
	{ "larrb", "\xe2\x87\xa4", 3 },
	/*  LEFTWARDS ARROW FROM BAR TO BLACK DIAMOND  */
	{ "larrbfs", "\xe2\xa4\x9f", 3 },
	/*  LEFTWARDS ARROW TO BLACK DIAMOND  */
	{ "larrfs", "\xe2\xa4\x9d", 3 },
	/*  LEFTWARDS ARROW WITH HOOK  */
	{ "larrhk", "\xe2\x86\xa9", 3 },
	/*  LEFTWARDS ARROW WITH LOOP  */
	{ "larrlp", "\xe2\x86\xab", 3 },
	/*  LEFT-SIDE ARC ANTICLOCKWISE ARROW  */
	{ "larrpl", "\xe2\xa4\xb9", 3 },
	/*  LEFTWARDS ARROW ABOVE TILDE OPERATOR  */
	{ "larrsim", "\xe2\xa5\xb3", 3 },
	/*  LEFTWARDS ARROW WITH TAIL  */
	{ "larrtl", "\xe2\x86\xa2", 3 },
	/*  LARGER THAN  */
	{ "lat", "\xe2\xaa\xab", 3 },
	/*  LEFTWARDS ARROW-TAIL  */
	{ "latail", "\xe2\xa4\x99", 3 },
	/*  LARGER THAN OR EQUAL TO  */
	{ "late", "\xe2\xaa\xad", 3 },
	/*  LARGER THAN OR slanted EQUAL  */
	{ "lates", "\xe2\xaa\xad\xef\xb8\x80", 6 },
	/*  LEFTWARDS DOUBLE DASH ARROW  */
	{ "lbarr", "\xe2\xa4\x8c", 3 },
	/*  LIGHT LEFT TORTOISE SHELL BRACKET ORNAMENT  */
	{ "lbbrk", "\xe2\x9d\xb2", 3 },
	/*  LEFT CURLY BRACKET  */
	{ "lbrace", "\x7b", 1 },
	/*  LEFT SQUARE BRACKET  */
	{ "lbrack", "\x5b", 1 },
	/*  LEFT SQUARE BRACKET WITH UNDERBAR  */
	{ "lbrke", "\xe2\xa6\x8b", 3 },
	/*  LEFT SQUARE BRACKET WITH TICK IN BOTTOM CORNER  */
	{ "lbrksld", "\xe2\xa6\x8f", 3 },
	/*  LEFT SQUARE BRACKET WITH TICK IN TOP CORNER  */
	{ "lbrkslu", "\xe2\xa6\x8d", 3 },
	/*  LATIN SMALL LETTER L WITH CARON  */
	{ "lcaron", "\xc4\xbe", 2 },
	/*  LATIN SMALL LETTER L WITH CEDILLA  */
	{ "lcedil", "\xc4\xbc", 2 },
	/*  LEFT CEILING  */
	{ "lceil", "\xe2\x8c\x88", 3 },
	/*  LEFT CURLY BRACKET  */
	{ "lcub", "\x7b", 1 },
	/*  CYRILLIC SMALL LETTER EL  */
	{ "lcy", "\xd0\xbb", 2 },
	/*  ARROW POINTING DOWNWARDS THEN CURVING LEFTWARDS  */
	{ "ldca", "\xe2\xa4\xb6", 3 },
	/*  LEFTWARDS HARPOON WITH BARB DOWN TO BAR  */
	{ "ldharb", "\xe2\xa5\x96", 3 },
	/*  LESS-THAN WITH DOT  */
	{ "ldot", "\xe2\x8b\x96", 3 },
	/*  LEFT DOUBLE QUOTATION MARK  */
	{ "ldquo", "\xe2\x80\x9c", 3 },
	/*  DOUBLE LOW-9 QUOTATION MARK  */
	{ "ldquor", "\xe2\x80\x9e", 3 },
	/*  LEFTWARDS HARPOON WITH BARB DOWN ABOVE RIGHTWARDS HARPOON WITH BARB DOWN  */
	{ "ldrdhar", "\xe2\xa5\xa7", 3 },
	/*  LEFT BARB DOWN RIGHT BARB DOWN HARPOON  */
	{ "ldrdshar", "\xe2\xa5\x90", 3 },
	/*  LEFT BARB DOWN RIGHT BARB UP HARPOON  */
	{ "ldrushar", "\xe2\xa5\x8b", 3 },
	/*  DOWNWARDS ARROW WITH TIP LEFTWARDS  */
	{ "ldsh", "\xe2\x86\xb2", 3 },
	/*  LESS-THAN OR EQUAL TO  */
	{ "le", "\xe2\x89\xa4", 3 },
	/*  LEFTWARDS ARROW  */
	{ "leftarrow", "\xe2\x86\x90", 3 },
	/*  LEFTWARDS ARROW WITH TAIL  */
	{ "leftarrowtail", "\xe2\x86\xa2", 3 },
	/*  LEFTWARDS HARPOON WITH BARB DOWNWARDS  */
	{ "leftharpoondown", "\xe2\x86\xbd", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UPWARDS  */
	{ "leftharpoonup", "\xe2\x86\xbc", 3 },
	/*  LEFTWARDS PAIRED ARROWS  */
	{ "leftleftarrows", "\xe2\x87\x87", 3 },
	/*  LEFT RIGHT ARROW  */
	{ "leftrightarrow", "\xe2\x86\x94", 3 },
	/*  LEFTWARDS ARROW OVER RIGHTWARDS ARROW  */
	{ "leftrightarrows", "\xe2\x87\x86", 3 },
	/*  LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON  */
	{ "leftrightharpoons", "\xe2\x87\x8b", 3 },
	/*  LEFT RIGHT WAVE ARROW  */
	{ "leftrightsquigarrow", "\xe2\x86\xad", 3 },
	/*  LEFT SEMIDIRECT PRODUCT  */
	{ "leftthreetimes", "\xe2\x8b\x8b", 3 },
	/*  LESS-THAN EQUAL TO OR GREATER-THAN  */
	{ "leg", "\xe2\x8b\x9a", 3 },
	/*  LESS-THAN OR EQUAL TO  */
	{ "leq", "\xe2\x89\xa4", 3 },
	/*  LESS-THAN OVER EQUAL TO  */
	{ "leqq", "\xe2\x89\xa6", 3 },
	/*  LESS-THAN OR SLANTED EQUAL TO  */
	{ "leqslant", "\xe2\xa9\xbd", 3 },
	/*  LESS-THAN OR SLANTED EQUAL TO  */
	{ "les", "\xe2\xa9\xbd", 3 },
	/*  LESS-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL  */
	{ "lescc", "\xe2\xaa\xa8", 3 },
	/*  LESS-THAN OR SLANTED EQUAL TO WITH DOT INSIDE  */
	{ "lesdot", "\xe2\xa9\xbf", 3 },
	/*  LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE  */
	{ "lesdoto", "\xe2\xaa\x81", 3 },
	/*  LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE RIGHT  */
	{ "lesdotor", "\xe2\xaa\x83", 3 },
	/*  LESS-THAN slanted EQUAL TO OR GREATER-THAN  */
	{ "lesg", "\xe2\x8b\x9a\xef\xb8\x80", 6 },
	/*  LESS-THAN ABOVE SLANTED EQUAL ABOVE GREATER-THAN ABOVE SLANTED EQUAL  */
	{ "lesges", "\xe2\xaa\x93", 3 },
	/*  LESS-THAN OR APPROXIMATE  */
	{ "lessapprox", "\xe2\xaa\x85", 3 },
	/*  LESS-THAN WITH DOT  */
	{ "lessdot", "\xe2\x8b\x96", 3 },
	/*  LESS-THAN EQUAL TO OR GREATER-THAN  */
	{ "lesseqgtr", "\xe2\x8b\x9a", 3 },
	/*  LESS-THAN ABOVE DOUBLE-LINE EQUAL ABOVE GREATER-THAN  */
	{ "lesseqqgtr", "\xe2\xaa\x8b", 3 },
	/*  LESS-THAN OR GREATER-THAN  */
	{ "lessgtr", "\xe2\x89\xb6", 3 },
	/*  LESS-THAN OR EQUIVALENT TO  */
	{ "lesssim", "\xe2\x89\xb2", 3 },
	/*  BOWTIE WITH LEFT HALF BLACK  */
	{ "lfbowtie", "\xe2\xa7\x91", 3 },
	/*  LEFT FISH TAIL  */
	{ "lfisht", "\xe2\xa5\xbc", 3 },
	/*  LEFT FLOOR  */
	{ "lfloor", "\xe2\x8c\x8a", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL L  */
	{ "lfr", "\xf0\x9d\x94\xa9", 4 },
	/*  TIMES WITH LEFT HALF BLACK  */
	{ "lftimes", "\xe2\xa7\x94", 3 },
	/*  LESS-THAN OR GREATER-THAN  */
	{ "lg", "\xe2\x89\xb6", 3 },
	/*  LESS-THAN ABOVE GREATER-THAN ABOVE DOUBLE-LINE EQUAL  */
	{ "lgE", "\xe2\xaa\x91", 3 },
	/*  GREEK SMALL LETTER LAMDA  */
	{ "lgr", "\xce\xbb", 2 },
	/*  LEFTWARDS HARPOON WITH BARB DOWNWARDS  */
	{ "lhard", "\xe2\x86\xbd", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UPWARDS  */
	{ "lharu", "\xe2\x86\xbc", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UP ABOVE LONG DASH  */
	{ "lharul", "\xe2\xa5\xaa", 3 },
	/*  LOWER HALF BLOCK  */
	{ "lhblk", "\xe2\x96\x84", 3 },
	/*  CYRILLIC SMALL LETTER LJE  */
	{ "ljcy", "\xd1\x99", 2 },
	/*  MUCH LESS-THAN  */
	{ "ll", "\xe2\x89\xaa", 3 },
	/*  LEFTWARDS PAIRED ARROWS  */
	{ "llarr", "\xe2\x87\x87", 3 },
	/*  BOTTOM LEFT CORNER  */
	{ "llcorner", "\xe2\x8c\x9e", 3 },
	/*  LEFTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH  */
	{ "llhard", "\xe2\xa5\xab", 3 },
	/*  LOWER LEFT TRIANGLE  */
	{ "lltri", "\xe2\x97\xba", 3 },
	/*  BLACK LOWER LEFT TRIANGLE  */
	{ "lltrif", "\xe2\x97\xa3", 3 },
	/*  LATIN SMALL LETTER L WITH MIDDLE DOT  */
	{ "lmidot", "\xc5\x80", 2 },
	/*  UPPER LEFT OR LOWER RIGHT CURLY BRACKET SECTION  */
	{ "lmoust", "\xe2\x8e\xb0", 3 },
	/*  UPPER LEFT OR LOWER RIGHT CURLY BRACKET SECTION  */
	{ "lmoustache", "\xe2\x8e\xb0", 3 },
	/*  LESS-THAN BUT NOT EQUAL TO  */
	{ "lnE", "\xe2\x89\xa8", 3 },
	/*  LESS-THAN AND NOT APPROXIMATE  */
	{ "lnap", "\xe2\xaa\x89", 3 },
	/*  LESS-THAN AND NOT APPROXIMATE  */
	{ "lnapprox", "\xe2\xaa\x89", 3 },
	/*  LESS-THAN AND SINGLE-LINE NOT EQUAL TO  */
	{ "lne", "\xe2\xaa\x87", 3 },
	/*  LESS-THAN AND SINGLE-LINE NOT EQUAL TO  */
	{ "lneq", "\xe2\xaa\x87", 3 },
	/*  LESS-THAN BUT NOT EQUAL TO  */
	{ "lneqq", "\xe2\x89\xa8", 3 },
	/*  LESS-THAN BUT NOT EQUIVALENT TO  */
	{ "lnsim", "\xe2\x8b\xa6", 3 },
	/*  MATHEMATICAL LEFT WHITE TORTOISE SHELL BRACKET  */
	{ "loang", "\xe2\x9f\xac", 3 },
	/*  LEFTWARDS OPEN-HEADED ARROW  */
	{ "loarr", "\xe2\x87\xbd", 3 },
	/*  MATHEMATICAL LEFT WHITE SQUARE BRACKET  */
	{ "lobrk", "\xe2\x9f\xa6", 3 },
	/*  LEFT WHITE CURLY BRACKET  */
	{ "locub", "\xe2\xa6\x83", 3 },
	/*  LONG LEFTWARDS ARROW  */
	{ "longleftarrow", "\xe2\x9f\xb5", 3 },
	/*  LONG LEFT RIGHT ARROW  */
	{ "longleftrightarrow", "\xe2\x9f\xb7", 3 },
	/*  LONG RIGHTWARDS ARROW FROM BAR  */
	{ "longmapsto", "\xe2\x9f\xbc", 3 },
	/*  LONG RIGHTWARDS ARROW  */
	{ "longrightarrow", "\xe2\x9f\xb6", 3 },
	/*  LEFTWARDS ARROW WITH LOOP  */
	{ "looparrowleft", "\xe2\x86\xab", 3 },
	/*  RIGHTWARDS ARROW WITH LOOP  */
	{ "looparrowright", "\xe2\x86\xac", 3 },
	/*  LEFT WHITE PARENTHESIS  */
	{ "lopar", "\xe2\xa6\x85", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL L  */
	{ "lopf", "\xf0\x9d\x95\x9d", 4 },
	/*  PLUS SIGN IN LEFT HALF CIRCLE  */
	{ "loplus", "\xe2\xa8\xad", 3 },
	/*  MULTIPLICATION SIGN IN LEFT HALF CIRCLE  */
	{ "lotimes", "\xe2\xa8\xb4", 3 },
	/*  ASTERISK OPERATOR  */
	{ "lowast", "\xe2\x88\x97", 3 },
	/*  LOW LINE  */
	{ "lowbar", "\x5f", 1 },
	/*  INTEGRAL WITH UNDERBAR  */
	{ "lowint", "\xe2\xa8\x9c", 3 },
	/*  LOZENGE  */
	{ "loz", "\xe2\x97\x8a", 3 },
	/*  LOZENGE  */
	{ "lozenge", "\xe2\x97\x8a", 3 },
	/*  BLACK LOZENGE  */
	{ "lozf", "\xe2\xa7\xab", 3 },
	/*  LEFT PARENTHESIS  */
	{ "lpar", "\x28", 1 },
	/*  SPHERICAL ANGLE OPENING LEFT  */
	{ "lpargt", "\xe2\xa6\xa0", 3 },
	/*  LEFT ARC LESS-THAN BRACKET  */
	{ "lparlt", "\xe2\xa6\x93", 3 },
	/*  LEFTWARDS ARROW OVER RIGHTWARDS ARROW  */
	{ "lrarr", "\xe2\x87\x86", 3 },
	/*  LEFTWARDS ARROW OVER RIGHTWARDS ARROW  */
	{ "lrarr2", "\xe2\x87\x86", 3 },
	/*  BOTTOM RIGHT CORNER  */
	{ "lrcorner", "\xe2\x8c\x9f", 3 },
	/*  LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON  */
	{ "lrhar", "\xe2\x87\x8b", 3 },
	/*  LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON  */
	{ "lrhar2", "\xe2\x87\x8b", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH  */
	{ "lrhard", "\xe2\xa5\xad", 3 },
	/*  LEFT-TO-RIGHT MARK  */
	{ "lrm", "\xe2\x80\x8e", 3 },
	/*  RIGHT TRIANGLE  */
	{ "lrtri", "\xe2\x8a\xbf", 3 },
	/*  SINGLE LEFT-POINTING ANGLE QUOTATION MARK  */
	{ "lsaquo", "\xe2\x80\xb9", 3 },
	/*  MATHEMATICAL SCRIPT SMALL L  */
	{ "lscr", "\xf0\x9d\x93\x81", 4 },
	/*  UPWARDS ARROW WITH TIP LEFTWARDS  */
	{ "lsh", "\xe2\x86\xb0", 3 },
	/*  LESS-THAN OR EQUIVALENT TO  */
	{ "lsim", "\xe2\x89\xb2", 3 },
	/*  LESS-THAN ABOVE SIMILAR OR EQUAL  */
	{ "lsime", "\xe2\xaa\x8d", 3 },
	/*  LESS-THAN ABOVE SIMILAR ABOVE GREATER-THAN  */
	{ "lsimg", "\xe2\xaa\x8f", 3 },
	/*  LEFT SQUARE BRACKET  */
	{ "lsqb", "\x5b", 1 },
	/*  LEFT SINGLE QUOTATION MARK  */
	{ "lsquo", "\xe2\x80\x98", 3 },
	/*  SINGLE LOW-9 QUOTATION MARK  */
	{ "lsquor", "\xe2\x80\x9a", 3 },
	/*  LATIN SMALL LETTER L WITH STROKE  */
	{ "lstrok", "\xc5\x82", 2 },
	/*  LESS-THAN SIGN  */
	{ "lt", "\x3c", 1 },
	/*  LESS-THAN CLOSED BY CURVE  */
	{ "ltcc", "\xe2\xaa\xa6", 3 },
	/*  LESS-THAN WITH CIRCLE INSIDE  */
	{ "ltcir", "\xe2\xa9\xb9", 3 },
	/*  LESS-THAN WITH DOT  */
	{ "ltdot", "\xe2\x8b\x96", 3 },
	/*  LEFT SEMIDIRECT PRODUCT  */
	{ "lthree", "\xe2\x8b\x8b", 3 },
	/*  LEFT NORMAL FACTOR SEMIDIRECT PRODUCT  */
	{ "ltimes", "\xe2\x8b\x89", 3 },
	/*  LESS-THAN ABOVE LEFTWARDS ARROW  */
	{ "ltlarr", "\xe2\xa5\xb6", 3 },
	/*  LESS-THAN WITH QUESTION MARK ABOVE  */
	{ "ltquest", "\xe2\xa9\xbb", 3 },
	/*  DOUBLE RIGHT ARC LESS-THAN BRACKET  */
	{ "ltrPar", "\xe2\xa6\x96", 3 },
	/*  WHITE LEFT-POINTING SMALL TRIANGLE  */
	{ "ltri", "\xe2\x97\x83", 3 },
	/*  NORMAL SUBGROUP OF OR EQUAL TO  */
	{ "ltrie", "\xe2\x8a\xb4", 3 },
	/*  BLACK LEFT-POINTING SMALL TRIANGLE  */
	{ "ltrif", "\xe2\x97\x82", 3 },
	/*  LEFT TRIANGLE BESIDE VERTICAL BAR  */
	{ "ltrivb", "\xe2\xa7\x8f", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UP TO BAR  */
	{ "luharb", "\xe2\xa5\x92", 3 },
	/*  LEFT BARB UP RIGHT BARB DOWN HARPOON  */
	{ "lurdshar", "\xe2\xa5\x8a", 3 },
	/*  LEFTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB UP  */
	{ "luruhar", "\xe2\xa5\xa6", 3 },
	/*  LEFT BARB UP RIGHT BARB UP HARPOON  */
	{ "lurushar", "\xe2\xa5\x8e", 3 },
	/*  LESS-THAN BUT NOT EQUAL TO - with vertical stroke  */
	{ "lvertneqq", "\xe2\x89\xa8\xef\xb8\x80", 6 },
	/*  LESS-THAN BUT NOT EQUAL TO - with vertical stroke  */
	{ "lvnE", "\xe2\x89\xa8\xef\xb8\x80", 6 },
	/*  GEOMETRIC PROPORTION  */
	{ "mDDot", "\xe2\x88\xba", 3 },
	/*  MACRON  */
	{ "macr", "\xc2\xaf", 2 },
	/*  MALE SIGN  */
	{ "male", "\xe2\x99\x82", 3 },
	/*  MALTESE CROSS  */
	{ "malt", "\xe2\x9c\xa0", 3 },
	/*  MALTESE CROSS  */
	{ "maltese", "\xe2\x9c\xa0", 3 },
	/*  RIGHTWARDS ARROW FROM BAR  */
	{ "map", "\xe2\x86\xa6", 3 },
	/*  RIGHTWARDS ARROW FROM BAR  */
	{ "mapsto", "\xe2\x86\xa6", 3 },
	/*  DOWNWARDS ARROW FROM BAR  */
	{ "mapstodown", "\xe2\x86\xa7", 3 },
	/*  LEFTWARDS ARROW FROM BAR  */
	{ "mapstoleft", "\xe2\x86\xa4", 3 },
	/*  UPWARDS ARROW FROM BAR  */
	{ "mapstoup", "\xe2\x86\xa5", 3 },
	/*  BLACK VERTICAL RECTANGLE  */
	{ "marker", "\xe2\x96\xae", 3 },
	/*  MINUS SIGN WITH COMMA ABOVE  */
	{ "mcomma", "\xe2\xa8\xa9", 3 },
	/*  CYRILLIC SMALL LETTER EM  */
	{ "mcy", "\xd0\xbc", 2 },
	/*  EM DASH  */
	{ "mdash", "\xe2\x80\x94", 3 },
	/*  MEASURED ANGLE  */
	{ "measuredangle", "\xe2\x88\xa1", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL M  */
	{ "mfr", "\xf0\x9d\x94\xaa", 4 },
	/*  GREEK SMALL LETTER MU  */
	{ "mgr", "\xce\xbc", 2 },
	/*  INVERTED OHM SIGN  */
	{ "mho", "\xe2\x84\xa7", 3 },
	/*  MICRO SIGN  */
	{ "micro", "\xc2\xb5", 2 },
	/*  DIVIDES  */
	{ "mid", "\xe2\x88\xa3", 3 },
	/*  ASTERISK  */
	{ "midast", "\x2a", 1 },
	/*  VERTICAL LINE WITH CIRCLE BELOW  */
	{ "midcir", "\xe2\xab\xb0", 3 },
	/*  MIDDLE DOT  */
	{ "middot", "\xc2\xb7", 2 },
	/*  MINUS SIGN  */
	{ "minus", "\xe2\x88\x92", 3 },
	/*  SQUARED MINUS  */
	{ "minusb", "\xe2\x8a\x9f", 3 },
	/*  DOT MINUS  */
	{ "minusd", "\xe2\x88\xb8", 3 },
	/*  MINUS SIGN WITH DOT BELOW  */
	{ "minusdu", "\xe2\xa8\xaa", 3 },
	/*  TRANSVERSAL INTERSECTION  */
	{ "mlcp", "\xe2\xab\x9b", 3 },
	/*  HORIZONTAL ELLIPSIS  */
	{ "mldr", "\xe2\x80\xa6", 3 },
	/*  MINUS-OR-PLUS SIGN  */
	{ "mnplus", "\xe2\x88\x93", 3 },
	/*  MODELS  */
	{ "models", "\xe2\x8a\xa7", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL M  */
	{ "mopf", "\xf0\x9d\x95\x9e", 4 },
	/*  MINUS-OR-PLUS SIGN  */
	{ "mp", "\xe2\x88\x93", 3 },
	/*  MATHEMATICAL SCRIPT SMALL M  */
	{ "mscr", "\xf0\x9d\x93\x82", 4 },
	/*  INVERTED LAZY S  */
	{ "mstpos", "\xe2\x88\xbe", 3 },
	/*  GREEK SMALL LETTER MU  */
	{ "mu", "\xce\xbc", 2 },
	/*  MULTIMAP  */
	{ "multimap", "\xe2\x8a\xb8", 3 },
	/*  MULTIMAP  */
	{ "mumap", "\xe2\x8a\xb8", 3 },
	/*  VERY MUCH GREATER-THAN with slash  */
	{ "nGg", "\xe2\x8b\x99\xcc\xb8", 5 },
	/*  MUCH GREATER THAN with vertical line  */
	{ "nGt", "\xe2\x89\xab\xe2\x83\x92", 6 },
	/*  MUCH GREATER THAN with slash  */
	{ "nGtv", "\xe2\x89\xab\xcc\xb8", 5 },
	/*  LEFTWARDS DOUBLE ARROW WITH STROKE  */
	{ "nLeftarrow", "\xe2\x87\x8d", 3 },
	/*  LEFT RIGHT DOUBLE ARROW WITH STROKE  */
	{ "nLeftrightarrow", "\xe2\x87\x8e", 3 },
	/*  VERY MUCH LESS-THAN with slash  */
	{ "nLl", "\xe2\x8b\x98\xcc\xb8", 5 },
	/*  MUCH LESS THAN with vertical line  */
	{ "nLt", "\xe2\x89\xaa\xe2\x83\x92", 6 },
	/*  MUCH LESS THAN with slash  */
	{ "nLtv", "\xe2\x89\xaa\xcc\xb8", 5 },
	/*  RIGHTWARDS DOUBLE ARROW WITH STROKE  */
	{ "nRightarrow", "\xe2\x87\x8f", 3 },
	/*  NEGATED DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE  */
	{ "nVDash", "\xe2\x8a\xaf", 3 },
	/*  DOES NOT FORCE  */
	{ "nVdash", "\xe2\x8a\xae", 3 },
	/*  NABLA  */
	{ "nabla", "\xe2\x88\x87", 3 },
	/*  LATIN SMALL LETTER N WITH ACUTE  */
	{ "nacute", "\xc5\x84", 2 },
	/*  ANGLE with vertical line  */
	{ "nang", "\xe2\x88\xa0\xe2\x83\x92", 6 },
	/*  NOT ALMOST EQUAL TO  */
	{ "nap", "\xe2\x89\x89", 3 },
	/*  APPROXIMATELY EQUAL OR EQUAL TO with slash  */
	{ "napE", "\xe2\xa9\xb0\xcc\xb8", 5 },
	/*  TRIPLE TILDE with slash  */
	{ "napid", "\xe2\x89\x8b\xcc\xb8", 5 },
	/*  LATIN SMALL LETTER N PRECEDED BY APOSTROPHE  */
	{ "napos", "\xc5\x89", 2 },
	/*  NOT ALMOST EQUAL TO  */
	{ "napprox", "\xe2\x89\x89", 3 },
	/*  MUSIC NATURAL SIGN  */
	{ "natur", "\xe2\x99\xae", 3 },
	/*  MUSIC NATURAL SIGN  */
	{ "natural", "\xe2\x99\xae", 3 },
	/*  DOUBLE-STRUCK CAPITAL N  */
	{ "naturals", "\xe2\x84\x95", 3 },
	/*  NO-BREAK SPACE  */
	{ "nbsp", "\xc2\xa0", 2 },
	/*  GEOMETRICALLY EQUIVALENT TO with slash  */
	{ "nbump", "\xe2\x89\x8e\xcc\xb8", 5 },
	/*  DIFFERENCE BETWEEN with slash  */
	{ "nbumpe", "\xe2\x89\x8f\xcc\xb8", 5 },
	/*  INTERSECTION WITH OVERBAR  */
	{ "ncap", "\xe2\xa9\x83", 3 },
	/*  LATIN SMALL LETTER N WITH CARON  */
	{ "ncaron", "\xc5\x88", 2 },
	/*  LATIN SMALL LETTER N WITH CEDILLA  */
	{ "ncedil", "\xc5\x86", 2 },
	/*  NEITHER APPROXIMATELY NOR ACTUALLY EQUAL TO  */
	{ "ncong", "\xe2\x89\x87", 3 },
	/*  CONGRUENT WITH DOT ABOVE with slash  */
	{ "ncongdot", "\xe2\xa9\xad\xcc\xb8", 5 },
	/*  UNION WITH OVERBAR  */
	{ "ncup", "\xe2\xa9\x82", 3 },
	/*  CYRILLIC SMALL LETTER EN  */
	{ "ncy", "\xd0\xbd", 2 },
	/*  EN DASH  */
	{ "ndash", "\xe2\x80\x93", 3 },
	/*  NOT EQUAL TO  */
	{ "ne", "\xe2\x89\xa0", 3 },
	/*  NORTH EAST DOUBLE ARROW  */
	{ "neArr", "\xe2\x87\x97", 3 },
	/*  NORTH EAST ARROW WITH HOOK  */
	{ "nearhk", "\xe2\xa4\xa4", 3 },
	/*  NORTH EAST ARROW  */
	{ "nearr", "\xe2\x86\x97", 3 },
	/*  NORTH EAST ARROW  */
	{ "nearrow", "\xe2\x86\x97", 3 },
	/*  APPROACHES THE LIMIT with slash  */
	{ "nedot", "\xe2\x89\x90\xcc\xb8", 5 },
	/*  NORTH EAST ARROW CROSSING NORTH WEST ARROW  */
	{ "neonwarr", "\xe2\xa4\xb1", 3 },
	/*  NORTH EAST ARROW CROSSING SOUTH EAST ARROW  */
	{ "neosearr", "\xe2\xa4\xae", 3 },
	/*  NOT IDENTICAL TO  */
	{ "nequiv", "\xe2\x89\xa2", 3 },
	/*  NORTH EAST ARROW AND SOUTH EAST ARROW  */
	{ "nesear", "\xe2\xa4\xa8", 3 },
	/*  MINUS TILDE with slash  */
	{ "nesim", "\xe2\x89\x82\xcc\xb8", 5 },
	/*  NORTH EAST AND SOUTH WEST ARROW  */
	{ "neswsarr", "\xe2\xa4\xa2", 3 },
	/*  THERE DOES NOT EXIST  */
	{ "nexist", "\xe2\x88\x84", 3 },
	/*  THERE DOES NOT EXIST  */
	{ "nexists", "\xe2\x88\x84", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL N  */
	{ "nfr", "\xf0\x9d\x94\xab", 4 },
	/*  GREATER-THAN OVER EQUAL TO with slash  */
	{ "ngE", "\xe2\x89\xa7\xcc\xb8", 5 },
	/*  NEITHER GREATER-THAN NOR EQUAL TO  */
	{ "nge", "\xe2\x89\xb1", 3 },
	/*  NEITHER GREATER-THAN NOR EQUAL TO  */
	{ "ngeq", "\xe2\x89\xb1", 3 },
	/*  GREATER-THAN OVER EQUAL TO with slash  */
	{ "ngeqq", "\xe2\x89\xa7\xcc\xb8", 5 },
	/*  GREATER-THAN OR SLANTED EQUAL TO with slash  */
	{ "ngeqslant", "\xe2\xa9\xbe\xcc\xb8", 5 },
	/*  GREATER-THAN OR SLANTED EQUAL TO with slash  */
	{ "nges", "\xe2\xa9\xbe\xcc\xb8", 5 },
	/*  GREEK SMALL LETTER NU  */
	{ "ngr", "\xce\xbd", 2 },
	/*  NEITHER GREATER-THAN NOR EQUIVALENT TO  */
	{ "ngsim", "\xe2\x89\xb5", 3 },
	/*  NOT GREATER-THAN  */
	{ "ngt", "\xe2\x89\xaf", 3 },
	/*  NOT GREATER-THAN  */
	{ "ngtr", "\xe2\x89\xaf", 3 },
	/*  LEFT RIGHT DOUBLE ARROW WITH STROKE  */
	{ "nhArr", "\xe2\x87\x8e", 3 },
	/*  LEFT RIGHT ARROW WITH STROKE  */
	{ "nharr", "\xe2\x86\xae", 3 },
	/*  PARALLEL WITH HORIZONTAL STROKE  */
	{ "nhpar", "\xe2\xab\xb2", 3 },
	/*  CONTAINS AS MEMBER  */
	{ "ni", "\xe2\x88\x8b", 3 },
	/*  SMALL CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE  */
	{ "nis", "\xe2\x8b\xbc", 3 },
	/*  CONTAINS WITH LONG HORIZONTAL STROKE  */
	{ "nisd", "\xe2\x8b\xba", 3 },
	/*  CONTAINS AS MEMBER  */
	{ "niv", "\xe2\x88\x8b", 3 },
	/*  CYRILLIC SMALL LETTER NJE  */
	{ "njcy", "\xd1\x9a", 2 },
	/*  LEFTWARDS DOUBLE ARROW WITH STROKE  */
	{ "nlArr", "\xe2\x87\x8d", 3 },
	/*  LESS-THAN OVER EQUAL TO with slash  */
	{ "nlE", "\xe2\x89\xa6\xcc\xb8", 5 },
	/*  LEFTWARDS ARROW WITH STROKE  */
	{ "nlarr", "\xe2\x86\x9a", 3 },
	/*  TWO DOT LEADER  */
	{ "nldr", "\xe2\x80\xa5", 3 },
	/*  NEITHER LESS-THAN NOR EQUAL TO  */
	{ "nle", "\xe2\x89\xb0", 3 },
	/*  LEFTWARDS ARROW WITH STROKE  */
	{ "nleftarrow", "\xe2\x86\x9a", 3 },
	/*  LEFT RIGHT ARROW WITH STROKE  */
	{ "nleftrightarrow", "\xe2\x86\xae", 3 },
	/*  NEITHER LESS-THAN NOR EQUAL TO  */
	{ "nleq", "\xe2\x89\xb0", 3 },
	/*  LESS-THAN OVER EQUAL TO with slash  */
	{ "nleqq", "\xe2\x89\xa6\xcc\xb8", 5 },
	/*  LESS-THAN OR SLANTED EQUAL TO with slash  */
	{ "nleqslant", "\xe2\xa9\xbd\xcc\xb8", 5 },
	/*  LESS-THAN OR SLANTED EQUAL TO with slash  */
	{ "nles", "\xe2\xa9\xbd\xcc\xb8", 5 },
	/*  NOT LESS-THAN  */
	{ "nless", "\xe2\x89\xae", 3 },
	/*  NEITHER LESS-THAN NOR EQUIVALENT TO  */
	{ "nlsim", "\xe2\x89\xb4", 3 },
	/*  NOT LESS-THAN  */
	{ "nlt", "\xe2\x89\xae", 3 },
	/*  NOT NORMAL SUBGROUP OF  */
	{ "nltri", "\xe2\x8b\xaa", 3 },
	/*  NOT NORMAL SUBGROUP OF OR EQUAL TO  */
	{ "nltrie", "\xe2\x8b\xac", 3 },
	/*  LEFT TRIANGLE BESIDE VERTICAL BAR with slash  */
	{ "nltrivb", "\xe2\xa7\x8f\xcc\xb8", 5 },
	/*  DOES NOT DIVIDE  */
	{ "nmid", "\xe2\x88\xa4", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL N  */
	{ "nopf", "\xf0\x9d\x95\x9f", 4 },
	/*  NOT SIGN  */
	{ "not", "\xc2\xac", 2 },
	/*  NOT AN ELEMENT OF  */
	{ "notin", "\xe2\x88\x89", 3 },
	/*  ELEMENT OF WITH TWO HORIZONTAL STROKES with slash  */
	{ "notinE", "\xe2\x8b\xb9\xcc\xb8", 5 },
	/*  ELEMENT OF WITH DOT ABOVE with slash  */
	{ "notindot", "\xe2\x8b\xb5\xcc\xb8", 5 },
	/*  NOT AN ELEMENT OF  */
	{ "notinva", "\xe2\x88\x89", 3 },
	/*  SMALL ELEMENT OF WITH OVERBAR  */
	{ "notinvb", "\xe2\x8b\xb7", 3 },
	/*  ELEMENT OF WITH OVERBAR  */
	{ "notinvc", "\xe2\x8b\xb6", 3 },
	/*  DOES NOT CONTAIN AS MEMBER  */
	{ "notni", "\xe2\x88\x8c", 3 },
	/*  DOES NOT CONTAIN AS MEMBER  */
	{ "notniva", "\xe2\x88\x8c", 3 },
	/*  SMALL CONTAINS WITH OVERBAR  */
	{ "notnivb", "\xe2\x8b\xbe", 3 },
	/*  CONTAINS WITH OVERBAR  */
	{ "notnivc", "\xe2\x8b\xbd", 3 },
	/*  NOT PARALLEL TO  */
	{ "npar", "\xe2\x88\xa6", 3 },
	/*  NOT PARALLEL TO  */
	{ "nparallel", "\xe2\x88\xa6", 3 },
	/*  DOUBLE SOLIDUS OPERATOR with reverse slash  */
	{ "nparsl", "\xe2\xab\xbd\xe2\x83\xa5", 6 },
	/*  PARTIAL DIFFERENTIAL with slash  */
	{ "npart", "\xe2\x88\x82\xcc\xb8", 5 },
	/*  LINE INTEGRATION NOT INCLUDING THE POLE  */
	{ "npolint", "\xe2\xa8\x94", 3 },
	/*  DOES NOT PRECEDE  */
	{ "npr", "\xe2\x8a\x80", 3 },
	/*  DOES NOT PRECEDE OR EQUAL  */
	{ "nprcue", "\xe2\x8b\xa0", 3 },
	/*  PRECEDES ABOVE SINGLE-LINE EQUALS SIGN with slash  */
	{ "npre", "\xe2\xaa\xaf\xcc\xb8", 5 },
	/*  DOES NOT PRECEDE  */
	{ "nprec", "\xe2\x8a\x80", 3 },
	/*  PRECEDES ABOVE SINGLE-LINE EQUALS SIGN with slash  */
	{ "npreceq", "\xe2\xaa\xaf\xcc\xb8", 5 },
	/*  PRECEDES OR EQUIVALENT TO with slash  */
	{ "nprsim", "\xe2\x89\xbe\xcc\xb8", 5 },
	/*  RIGHTWARDS DOUBLE ARROW WITH STROKE  */
	{ "nrArr", "\xe2\x87\x8f", 3 },
	/*  RIGHTWARDS ARROW WITH STROKE  */
	{ "nrarr", "\xe2\x86\x9b", 3 },
	/*  WAVE ARROW POINTING DIRECTLY RIGHT with slash  */
	{ "nrarrc", "\xe2\xa4\xb3\xcc\xb8", 5 },
	/*  RIGHTWARDS WAVE ARROW with slash  */
	{ "nrarrw", "\xe2\x86\x9d\xcc\xb8", 5 },
	/*  RIGHTWARDS ARROW WITH STROKE  */
	{ "nrightarrow", "\xe2\x86\x9b", 3 },
	/*  DOES NOT CONTAIN AS NORMAL SUBGROUP  */
	{ "nrtri", "\xe2\x8b\xab", 3 },
	/*  DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL  */
	{ "nrtrie", "\xe2\x8b\xad", 3 },
	/*  DOUBLE NESTED GREATER-THAN with slash  */
	{ "nsGt", "\xe2\xaa\xa2\xcc\xb8", 5 },
	/*  DOUBLE NESTED LESS-THAN with slash  */
	{ "nsLt", "\xe2\xaa\xa1\xcc\xb8", 5 },
	/*  DOES NOT SUCCEED  */
	{ "nsc", "\xe2\x8a\x81", 3 },
	/*  DOES NOT SUCCEED OR EQUAL  */
	{ "nsccue", "\xe2\x8b\xa1", 3 },
	/*  SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN with slash  */
	{ "nsce", "\xe2\xaa\xb0\xcc\xb8", 5 },
	/*  MATHEMATICAL SCRIPT SMALL N  */
	{ "nscr", "\xf0\x9d\x93\x83", 4 },
	/*  SUCCEEDS OR EQUIVALENT TO with slash  */
	{ "nscsim", "\xe2\x89\xbf\xcc\xb8", 5 },
	/*  DOES NOT DIVIDE  */
	{ "nshortmid", "\xe2\x88\xa4", 3 },
	/*  NOT PARALLEL TO  */
	{ "nshortparallel", "\xe2\x88\xa6", 3 },
	/*  NOT TILDE  */
	{ "nsim", "\xe2\x89\x81", 3 },
	/*  NOT ASYMPTOTICALLY EQUAL TO  */
	{ "nsime", "\xe2\x89\x84", 3 },
	/*  NOT ASYMPTOTICALLY EQUAL TO  */
	{ "nsimeq", "\xe2\x89\x84", 3 },
	/*  DOES NOT DIVIDE  */
	{ "nsmid", "\xe2\x88\xa4", 3 },
	/*  NOT PARALLEL TO  */
	{ "nspar", "\xe2\x88\xa6", 3 },
	/*  SQUARE IMAGE OF with slash  */
	{ "nsqsub", "\xe2\x8a\x8f\xcc\xb8", 5 },
	/*  NOT SQUARE IMAGE OF OR EQUAL TO  */
	{ "nsqsube", "\xe2\x8b\xa2", 3 },
	/*  SQUARE ORIGINAL OF with slash  */
	{ "nsqsup", "\xe2\x8a\x90\xcc\xb8", 5 },
	/*  NOT SQUARE ORIGINAL OF OR EQUAL TO  */
	{ "nsqsupe", "\xe2\x8b\xa3", 3 },
	/*  NOT A SUBSET OF  */
	{ "nsub", "\xe2\x8a\x84", 3 },
	/*  SUBSET OF ABOVE EQUALS SIGN with slash  */
	{ "nsubE", "\xe2\xab\x85\xcc\xb8", 5 },
	/*  NEITHER A SUBSET OF NOR EQUAL TO  */
	{ "nsube", "\xe2\x8a\x88", 3 },
	/*  SUBSET OF with vertical line  */
	{ "nsubset", "\xe2\x8a\x82\xe2\x83\x92", 6 },
	/*  NEITHER A SUBSET OF NOR EQUAL TO  */
	{ "nsubseteq", "\xe2\x8a\x88", 3 },
	/*  SUBSET OF ABOVE EQUALS SIGN with slash  */
	{ "nsubseteqq", "\xe2\xab\x85\xcc\xb8", 5 },
	/*  DOES NOT SUCCEED  */
	{ "nsucc", "\xe2\x8a\x81", 3 },
	/*  SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN with slash  */
	{ "nsucceq", "\xe2\xaa\xb0\xcc\xb8", 5 },
	/*  NOT A SUPERSET OF  */
	{ "nsup", "\xe2\x8a\x85", 3 },
	/*  SUPERSET OF ABOVE EQUALS SIGN with slash  */
	{ "nsupE", "\xe2\xab\x86\xcc\xb8", 5 },
	/*  NEITHER A SUPERSET OF NOR EQUAL TO  */
	{ "nsupe", "\xe2\x8a\x89", 3 },
	/*  SUPERSET OF with vertical line  */
	{ "nsupset", "\xe2\x8a\x83\xe2\x83\x92", 6 },
	/*  NEITHER A SUPERSET OF NOR EQUAL TO  */
	{ "nsupseteq", "\xe2\x8a\x89", 3 },
	/*  SUPERSET OF ABOVE EQUALS SIGN with slash  */
	{ "nsupseteqq", "\xe2\xab\x86\xcc\xb8", 5 },
	/*  NEITHER GREATER-THAN NOR LESS-THAN  */
	{ "ntgl", "\xe2\x89\xb9", 3 },
	/*  LATIN SMALL LETTER N WITH TILDE  */
	{ "ntilde", "\xc3\xb1", 2 },
	/*  NEITHER LESS-THAN NOR GREATER-THAN  */
	{ "ntlg", "\xe2\x89\xb8", 3 },
	/*  NOT NORMAL SUBGROUP OF  */
	{ "ntriangleleft", "\xe2\x8b\xaa", 3 },
	/*  NOT NORMAL SUBGROUP OF OR EQUAL TO  */
	{ "ntrianglelefteq", "\xe2\x8b\xac", 3 },
	/*  DOES NOT CONTAIN AS NORMAL SUBGROUP  */
	{ "ntriangleright", "\xe2\x8b\xab", 3 },
	/*  DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL  */
	{ "ntrianglerighteq", "\xe2\x8b\xad", 3 },
	/*  GREEK SMALL LETTER NU  */
	{ "nu", "\xce\xbd", 2 },
	/*  NUMBER SIGN  */
	{ "num", "\x23", 1 },
	/*  NUMERO SIGN  */
	{ "numero", "\xe2\x84\x96", 3 },
	/*  FIGURE SPACE  */
	{ "numsp", "\xe2\x80\x87", 3 },
	/*  NOT TRUE  */
	{ "nvDash", "\xe2\x8a\xad", 3 },
	/*  LEFT RIGHT DOUBLE ARROW WITH VERTICAL STROKE  */
	{ "nvHarr", "\xe2\xa4\x84", 3 },
	/*  EQUIVALENT TO with vertical line  */
	{ "nvap", "\xe2\x89\x8d\xe2\x83\x92", 6 },
	/*  VERTICAL BAR BESIDE RIGHT TRIANGLE with slash  */
	{ "nvbrtri", "\xe2\xa7\x90\xcc\xb8", 5 },
	/*  DOES NOT PROVE  */
	{ "nvdash", "\xe2\x8a\xac", 3 },
	/*  GREATER-THAN OR EQUAL TO with vertical line  */
	{ "nvge", "\xe2\x89\xa5\xe2\x83\x92", 6 },
	/*  GREATER-THAN SIGN with vertical line  */
	{ "nvgt", "\x3e\xe2\x83\x92", 4 },
	/*  INFINITY NEGATED WITH VERTICAL BAR  */
	{ "nvinfin", "\xe2\xa7\x9e", 3 },
	/*  LEFTWARDS DOUBLE ARROW WITH VERTICAL STROKE  */
	{ "nvlArr", "\xe2\xa4\x82", 3 },
	/*  LESS-THAN OR EQUAL TO with vertical line  */
	{ "nvle", "\xe2\x89\xa4\xe2\x83\x92", 6 },
	/*  LESS-THAN SIGN with vertical line  */
	{ "nvlt", "\x3c\xe2\x83\x92", 4 },
	/*  NORMAL SUBGROUP OF OR EQUAL TO with vertical line  */
	{ "nvltrie", "\xe2\x8a\xb4\xe2\x83\x92", 6 },
	/*  RIGHTWARDS DOUBLE ARROW WITH VERTICAL STROKE  */
	{ "nvrArr", "\xe2\xa4\x83", 3 },
	/*  CONTAINS AS NORMAL SUBGROUP OR EQUAL TO with vertical line  */
	{ "nvrtrie", "\xe2\x8a\xb5\xe2\x83\x92", 6 },
	/*  TILDE OPERATOR with vertical line  */
	{ "nvsim", "\xe2\x88\xbc\xe2\x83\x92", 6 },
	/*  NORTH WEST DOUBLE ARROW  */
	{ "nwArr", "\xe2\x87\x96", 3 },
	/*  NORTH WEST ARROW WITH HOOK  */
	{ "nwarhk", "\xe2\xa4\xa3", 3 },
	/*  NORTH WEST ARROW  */
	{ "nwarr", "\xe2\x86\x96", 3 },
	/*  NORTH WEST ARROW  */
	{ "nwarrow", "\xe2\x86\x96", 3 },
	/*  NORTH WEST ARROW AND NORTH EAST ARROW  */
	{ "nwnear", "\xe2\xa4\xa7", 3 },
	/*  NORTH WEST ARROW CROSSING NORTH EAST ARROW  */
	{ "nwonearr", "\xe2\xa4\xb2", 3 },
	/*  NORTH WEST AND SOUTH EAST ARROW  */
	{ "nwsesarr", "\xe2\xa4\xa1", 3 },
	/*  CIRCLED LATIN CAPITAL LETTER S  */
	{ "oS", "\xe2\x93\x88", 3 },
	/*  GREEK SMALL LETTER OMICRON WITH TONOS  */
	{ "oacgr", "\xcf\x8c", 2 },
	/*  LATIN SMALL LETTER O WITH ACUTE  */
	{ "oacute", "\xc3\xb3", 2 },
	/*  CIRCLED ASTERISK OPERATOR  */
	{ "oast", "\xe2\x8a\x9b", 3 },
	/*  CIRCLED REVERSE SOLIDUS  */
	{ "obsol", "\xe2\xa6\xb8", 3 },
	/*  CIRCLED RING OPERATOR  */
	{ "ocir", "\xe2\x8a\x9a", 3 },
	/*  LATIN SMALL LETTER O WITH CIRCUMFLEX  */
	{ "ocirc", "\xc3\xb4", 2 },
	/*  CYRILLIC SMALL LETTER O  */
	{ "ocy", "\xd0\xbe", 2 },
	/*  CIRCLED DASH  */
	{ "odash", "\xe2\x8a\x9d", 3 },
	/*  LATIN SMALL LETTER O WITH DOUBLE ACUTE  */
	{ "odblac", "\xc5\x91", 2 },
	/*  CIRCLED DIVISION SIGN  */
	{ "odiv", "\xe2\xa8\xb8", 3 },
	/*  CIRCLED DOT OPERATOR  */
	{ "odot", "\xe2\x8a\x99", 3 },
	/*  CIRCLED ANTICLOCKWISE-ROTATED DIVISION SIGN  */
	{ "odsold", "\xe2\xa6\xbc", 3 },
	/*  LATIN SMALL LIGATURE OE  */
	{ "oelig", "\xc5\x93", 2 },
	/*  CIRCLED BULLET  */
	{ "ofcir", "\xe2\xa6\xbf", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL O  */
	{ "ofr", "\xf0\x9d\x94\xac", 4 },
	/*  OGONEK  */
	{ "ogon", "\xcb\x9b", 2 },
	/*  GREEK SMALL LETTER OMICRON  */
	{ "ogr", "\xce\xbf", 2 },
	/*  LATIN SMALL LETTER O WITH GRAVE  */
	{ "ograve", "\xc3\xb2", 2 },
	/*  CIRCLED GREATER-THAN  */
	{ "ogt", "\xe2\xa7\x81", 3 },
	/*  GREEK SMALL LETTER OMEGA WITH TONOS  */
	{ "ohacgr", "\xcf\x8e", 2 },
	/*  CIRCLE WITH HORIZONTAL BAR  */
	{ "ohbar", "\xe2\xa6\xb5", 3 },
	/*  GREEK SMALL LETTER OMEGA  */
	{ "ohgr", "\xcf\x89", 2 },
	/*  GREEK CAPITAL LETTER OMEGA  */
	{ "ohm", "\xce\xa9", 2 },
	/*  CONTOUR INTEGRAL  */
	{ "oint", "\xe2\x88\xae", 3 },
	/*  ANTICLOCKWISE OPEN CIRCLE ARROW  */
	{ "olarr", "\xe2\x86\xba", 3 },
	/*  CIRCLED WHITE BULLET  */
	{ "olcir", "\xe2\xa6\xbe", 3 },
	/*  CIRCLE WITH SUPERIMPOSED X  */
	{ "olcross", "\xe2\xa6\xbb", 3 },
	/*  OVERLINE  */
	{ "oline", "\xe2\x80\xbe", 3 },
	/*  CIRCLED LESS-THAN  */
	{ "olt", "\xe2\xa7\x80", 3 },
	/*  LATIN SMALL LETTER O WITH MACRON  */
	{ "omacr", "\xc5\x8d", 2 },
	/*  GREEK SMALL LETTER OMEGA  */
	{ "omega", "\xcf\x89", 2 },
	/*  GREEK SMALL LETTER OMICRON  */
	{ "omicron", "\xce\xbf", 2 },
	/*  CIRCLED VERTICAL BAR  */
	{ "omid", "\xe2\xa6\xb6", 3 },
	/*  CIRCLED MINUS  */
	{ "ominus", "\xe2\x8a\x96", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL O  */
	{ "oopf", "\xf0\x9d\x95\xa0", 4 },
	/*  CIRCLED PARALLEL  */
	{ "opar", "\xe2\xa6\xb7", 3 },
	/*  CIRCLED PERPENDICULAR  */
	{ "operp", "\xe2\xa6\xb9", 3 },
	/*  DOUBLE-STRUCK SMALL GAMMA  */
	{ "opfgamma", "\xe2\x84\xbd", 3 },
	/*  DOUBLE-STRUCK CAPITAL PI  */
	{ "opfpi", "\xe2\x84\xbf", 3 },
	/*  DOUBLE-STRUCK N-ARY SUMMATION  */
	{ "opfsum", "\xe2\x85\x80", 3 },
	/*  CIRCLED PLUS  */
	{ "oplus", "\xe2\x8a\x95", 3 },
	/*  LOGICAL OR  */
	{ "or", "\xe2\x88\xa8", 3 },
	/*  CLOCKWISE OPEN CIRCLE ARROW  */
	{ "orarr", "\xe2\x86\xbb", 3 },
	/*  LOGICAL OR WITH HORIZONTAL DASH  */
	{ "ord", "\xe2\xa9\x9d", 3 },
	/*  SCRIPT SMALL O  */
	{ "order", "\xe2\x84\xb4", 3 },
	/*  SCRIPT SMALL O  */
	{ "orderof", "\xe2\x84\xb4", 3 },
	/*  FEMININE ORDINAL INDICATOR  */
	{ "ordf", "\xc2\xaa", 2 },
	/*  MASCULINE ORDINAL INDICATOR  */
	{ "ordm", "\xc2\xba", 2 },
	/*  ORIGINAL OF  */
	{ "origof", "\xe2\x8a\xb6", 3 },
	/*  TWO INTERSECTING LOGICAL OR  */
	{ "oror", "\xe2\xa9\x96", 3 },
	/*  SLOPING LARGE OR  */
	{ "orslope", "\xe2\xa9\x97", 3 },
	/*  LOGICAL OR WITH MIDDLE STEM  */
	{ "orv", "\xe2\xa9\x9b", 3 },
	/*  SCRIPT SMALL O  */
	{ "oscr", "\xe2\x84\xb4", 3 },
	/*  LATIN SMALL LETTER O WITH STROKE  */
	{ "oslash", "\xc3\xb8", 2 },
	/*  CIRCLED DIVISION SLASH  */
	{ "osol", "\xe2\x8a\x98", 3 },
	/*  LATIN SMALL LETTER O WITH TILDE  */
	{ "otilde", "\xc3\xb5", 2 },
	/*  CIRCLED TIMES  */
	{ "otimes", "\xe2\x8a\x97", 3 },
	/*  CIRCLED MULTIPLICATION SIGN WITH CIRCUMFLEX ACCENT  */
	{ "otimesas", "\xe2\xa8\xb6", 3 },
	/*  LATIN SMALL LETTER O WITH DIAERESIS  */
	{ "ouml", "\xc3\xb6", 2 },
	/*  APL FUNCTIONAL SYMBOL CIRCLE STILE  */
	{ "ovbar", "\xe2\x8c\xbd", 3 },
	/*  TOP SQUARE BRACKET  */
	{ "ovrbrk", "\xe2\x8e\xb4", 3 },
	/*  TOP CURLY BRACKET  */
	{ "ovrcub", "\xe2\x8f\x9e", 3 },
	/*  TOP PARENTHESIS  */
	{ "ovrpar", "\xe2\x8f\x9c", 3 },
	/*  UP ARROW THROUGH CIRCLE  */
	{ "oxuarr", "\xe2\xa6\xbd", 3 },
	/*  PARALLEL TO  */
	{ "par", "\xe2\x88\xa5", 3 },
	/*  PILCROW SIGN  */
	{ "para", "\xc2\xb6", 2 },
	/*  PARALLEL TO  */
	{ "parallel", "\xe2\x88\xa5", 3 },
	/*  PARALLEL WITH TILDE OPERATOR  */
	{ "parsim", "\xe2\xab\xb3", 3 },
	/*  DOUBLE SOLIDUS OPERATOR  */
	{ "parsl", "\xe2\xab\xbd", 3 },
	/*  PARTIAL DIFFERENTIAL  */
	{ "part", "\xe2\x88\x82", 3 },
	/*  CYRILLIC SMALL LETTER PE  */
	{ "pcy", "\xd0\xbf", 2 },
	/*  PERCENT SIGN  */
	{ "percnt", "\x25", 1 },
	/*  FULL STOP  */
	{ "period", "\x2e", 1 },
	/*  PER MILLE SIGN  */
	{ "permil", "\xe2\x80\xb0", 3 },
	/*  UP TACK  */
	{ "perp", "\xe2\x8a\xa5", 3 },
	/*  PER TEN THOUSAND SIGN  */
	{ "pertenk", "\xe2\x80\xb1", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL P  */
	{ "pfr", "\xf0\x9d\x94\xad", 4 },
	/*  GREEK SMALL LETTER PI  */
	{ "pgr", "\xcf\x80", 2 },
	/*  GREEK SMALL LETTER PHI  */
	{ "phgr", "\xcf\x86", 2 },
	/*  GREEK SMALL LETTER PHI  */
	{ "phi", "\xcf\x86", 2 },
	/*  GREEK PHI SYMBOL  */
	{ "phis", "\xcf\x95", 2 },
	/*  GREEK PHI SYMBOL  */
	{ "phiv", "\xcf\x95", 2 },
	/*  SCRIPT CAPITAL M  */
	{ "phmmat", "\xe2\x84\xb3", 3 },
	/*  BLACK TELEPHONE  */
	{ "phone", "\xe2\x98\x8e", 3 },
	/*  GREEK SMALL LETTER PI  */
	{ "pi", "\xcf\x80", 2 },
	/*  PITCHFORK  */
	{ "pitchfork", "\xe2\x8b\x94", 3 },
	/*  GREEK PI SYMBOL  */
	{ "piv", "\xcf\x96", 2 },
	/*  PLANCK CONSTANT OVER TWO PI  */
	{ "planck", "\xe2\x84\x8f", 3 },
	/*  PLANCK CONSTANT  */
	{ "planckh", "\xe2\x84\x8e", 3 },
	/*  PLANCK CONSTANT OVER TWO PI  */
	{ "plankv", "\xe2\x84\x8f", 3 },
	/*  PLUS SIGN  */
	{ "plus", "\x2b", 1 },
	/*  PLUS SIGN WITH CIRCUMFLEX ACCENT ABOVE  */
	{ "plusacir", "\xe2\xa8\xa3", 3 },
	/*  SQUARED PLUS  */
	{ "plusb", "\xe2\x8a\x9e", 3 },
	/*  PLUS SIGN WITH SMALL CIRCLE ABOVE  */
	{ "pluscir", "\xe2\xa8\xa2", 3 },
	/*  DOT PLUS  */
	{ "plusdo", "\xe2\x88\x94", 3 },
	/*  PLUS SIGN WITH DOT BELOW  */
	{ "plusdu", "\xe2\xa8\xa5", 3 },
	/*  PLUS SIGN ABOVE EQUALS SIGN  */
	{ "pluse", "\xe2\xa9\xb2", 3 },
	/*  PLUS-MINUS SIGN  */
	{ "plusmn", "\xc2\xb1", 2 },
	/*  PLUS SIGN WITH TILDE BELOW  */
	{ "plussim", "\xe2\xa8\xa6", 3 },
	/*  PLUS SIGN WITH BLACK TRIANGLE  */
	{ "plustrif", "\xe2\xa8\xa8", 3 },
	/*  PLUS SIGN WITH SUBSCRIPT TWO  */
	{ "plustwo", "\xe2\xa8\xa7", 3 },
	/*  PLUS-MINUS SIGN  */
	{ "pm", "\xc2\xb1", 2 },
	/*  INTEGRAL AROUND A POINT OPERATOR  */
	{ "pointint", "\xe2\xa8\x95", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL P  */
	{ "popf", "\xf0\x9d\x95\xa1", 4 },
	/*  POUND SIGN  */
	{ "pound", "\xc2\xa3", 2 },
	/*  PRECEDES  */
	{ "pr", "\xe2\x89\xba", 3 },
	/*  PRECEDES ABOVE EQUALS SIGN  */
	{ "prE", "\xe2\xaa\xb3", 3 },
	/*  PRECEDES ABOVE ALMOST EQUAL TO  */
	{ "prap", "\xe2\xaa\xb7", 3 },
	/*  PRECEDES OR EQUAL TO  */
	{ "prcue", "\xe2\x89\xbc", 3 },
	/*  PRECEDES ABOVE SINGLE-LINE EQUALS SIGN  */
	{ "pre", "\xe2\xaa\xaf", 3 },
	/*  PRECEDES  */
	{ "prec", "\xe2\x89\xba", 3 },
	/*  PRECEDES ABOVE ALMOST EQUAL TO  */
	{ "precapprox", "\xe2\xaa\xb7", 3 },
	/*  PRECEDES OR EQUAL TO  */
	{ "preccurlyeq", "\xe2\x89\xbc", 3 },
	/*  PRECEDES ABOVE SINGLE-LINE EQUALS SIGN  */
	{ "preceq", "\xe2\xaa\xaf", 3 },
	/*  PRECEDES ABOVE NOT ALMOST EQUAL TO  */
	{ "precnapprox", "\xe2\xaa\xb9", 3 },
	/*  PRECEDES ABOVE NOT EQUAL TO  */
	{ "precneqq", "\xe2\xaa\xb5", 3 },
	/*  PRECEDES BUT NOT EQUIVALENT TO  */
	{ "precnsim", "\xe2\x8b\xa8", 3 },
	/*  PRECEDES OR EQUIVALENT TO  */
	{ "precsim", "\xe2\x89\xbe", 3 },
	/*  PRIME  */
	{ "prime", "\xe2\x80\xb2", 3 },
	/*  DOUBLE-STRUCK CAPITAL P  */
	{ "primes", "\xe2\x84\x99", 3 },
	/*  PRECEDES ABOVE NOT EQUAL TO  */
	{ "prnE", "\xe2\xaa\xb5", 3 },
	/*  PRECEDES ABOVE NOT ALMOST EQUAL TO  */
	{ "prnap", "\xe2\xaa\xb9", 3 },
	/*  PRECEDES BUT NOT EQUIVALENT TO  */
	{ "prnsim", "\xe2\x8b\xa8", 3 },
	/*  N-ARY PRODUCT  */
	{ "prod", "\xe2\x88\x8f", 3 },
	/*  ALL AROUND-PROFILE  */
	{ "profalar", "\xe2\x8c\xae", 3 },
	/*  ARC  */
	{ "profline", "\xe2\x8c\x92", 3 },
	/*  SEGMENT  */
	{ "profsurf", "\xe2\x8c\x93", 3 },
	/*  PROPORTIONAL TO  */
	{ "prop", "\xe2\x88\x9d", 3 },
	/*  PROPORTIONAL TO  */
	{ "propto", "\xe2\x88\x9d", 3 },
	/*  PRECEDES OR EQUIVALENT TO  */
	{ "prsim", "\xe2\x89\xbe", 3 },
	/*  PRECEDES UNDER RELATION  */
	{ "prurel", "\xe2\x8a\xb0", 3 },
	/*  MATHEMATICAL SCRIPT SMALL P  */
	{ "pscr", "\xf0\x9d\x93\x85", 4 },
	/*  GREEK SMALL LETTER PSI  */
	{ "psgr", "\xcf\x88", 2 },
	/*  GREEK SMALL LETTER PSI  */
	{ "psi", "\xcf\x88", 2 },
	/*  PUNCTUATION SPACE  */
	{ "puncsp", "\xe2\x80\x88", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL Q  */
	{ "qfr", "\xf0\x9d\x94\xae", 4 },
	/*  QUADRUPLE INTEGRAL OPERATOR  */
	{ "qint", "\xe2\xa8\x8c", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL Q  */
	{ "qopf", "\xf0\x9d\x95\xa2", 4 },
	/*  QUADRUPLE PRIME  */
	{ "qprime", "\xe2\x81\x97", 3 },
	/*  MATHEMATICAL SCRIPT SMALL Q  */
	{ "qscr", "\xf0\x9d\x93\x86", 4 },
	/*  DOUBLE-STRUCK CAPITAL H  */
	{ "quaternions", "\xe2\x84\x8d", 3 },
	/*  QUATERNION INTEGRAL OPERATOR  */
	{ "quatint", "\xe2\xa8\x96", 3 },
	/*  QUESTION MARK  */
	{ "quest", "\x3f", 1 },
	/*  QUESTIONED EQUAL TO  */
	{ "questeq", "\xe2\x89\x9f", 3 },
	/*  QUOTATION MARK  */
	{ "quot", "\x22", 1 },
	/*  RIGHTWARDS TRIPLE ARROW  */
	{ "rAarr", "\xe2\x87\x9b", 3 },
	/*  RIGHTWARDS DOUBLE ARROW  */
	{ "rArr", "\xe2\x87\x92", 3 },
	/*  RIGHTWARDS DOUBLE ARROW-TAIL  */
	{ "rAtail", "\xe2\xa4\x9c", 3 },
	/*  RIGHTWARDS TRIPLE DASH ARROW  */
	{ "rBarr", "\xe2\xa4\x8f", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB DOWN  */
	{ "rHar", "\xe2\xa5\xa4", 3 },
	/*  REVERSED TILDE with underline  */
	{ "race", "\xe2\x88\xbd\xcc\xb1", 5 },
	/*  LATIN SMALL LETTER R WITH ACUTE  */
	{ "racute", "\xc5\x95", 2 },
	/*  SQUARE ROOT  */
	{ "radic", "\xe2\x88\x9a", 3 },
	/*  EMPTY SET WITH RIGHT ARROW ABOVE  */
	{ "raemptyv", "\xe2\xa6\xb3", 3 },
	/*  MATHEMATICAL RIGHT ANGLE BRACKET  */
	{ "rang", "\xe2\x9f\xa9", 3 },
	/*  RIGHT ANGLE BRACKET WITH DOT  */
	{ "rangd", "\xe2\xa6\x92", 3 },
	/*  REVERSED ANGLE WITH UNDERBAR  */
	{ "range", "\xe2\xa6\xa5", 3 },
	/*  MATHEMATICAL RIGHT ANGLE BRACKET  */
	{ "rangle", "\xe2\x9f\xa9", 3 },
	/*  RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK  */
	{ "raquo", "\xc2\xbb", 2 },
	/*  RIGHTWARDS ARROW  */
	{ "rarr", "\xe2\x86\x92", 3 },
	/*  RIGHTWARDS PAIRED ARROWS  */
	{ "rarr2", "\xe2\x87\x89", 3 },
	/*  THREE RIGHTWARDS ARROWS  */
	{ "rarr3", "\xe2\x87\xb6", 3 },
	/*  RIGHTWARDS ARROW ABOVE ALMOST EQUAL TO  */
	{ "rarrap", "\xe2\xa5\xb5", 3 },
	/*  RIGHTWARDS ARROW TO BAR  */
	{ "rarrb", "\xe2\x87\xa5", 3 },
	/*  RIGHTWARDS ARROW FROM BAR TO BLACK DIAMOND  */
	{ "rarrbfs", "\xe2\xa4\xa0", 3 },
	/*  WAVE ARROW POINTING DIRECTLY RIGHT  */
	{ "rarrc", "\xe2\xa4\xb3", 3 },
	/*  RIGHTWARDS ARROW TO BLACK DIAMOND  */
	{ "rarrfs", "\xe2\xa4\x9e", 3 },
	/*  RIGHTWARDS ARROW WITH HOOK  */
	{ "rarrhk", "\xe2\x86\xaa", 3 },
	/*  RIGHTWARDS ARROW WITH LOOP  */
	{ "rarrlp", "\xe2\x86\xac", 3 },
	/*  RIGHTWARDS ARROW WITH PLUS BELOW  */
	{ "rarrpl", "\xe2\xa5\x85", 3 },
	/*  RIGHTWARDS ARROW ABOVE TILDE OPERATOR  */
	{ "rarrsim", "\xe2\xa5\xb4", 3 },
	/*  RIGHTWARDS ARROW WITH TAIL  */
	{ "rarrtl", "\xe2\x86\xa3", 3 },
	/*  RIGHTWARDS WAVE ARROW  */
	{ "rarrw", "\xe2\x86\x9d", 3 },
	/*  RIGHTWARDS ARROW THROUGH X  */
	{ "rarrx", "\xe2\xa5\x87", 3 },
	/*  RIGHTWARDS ARROW-TAIL  */
	{ "ratail", "\xe2\xa4\x9a", 3 },
	/*  RATIO  */
	{ "ratio", "\xe2\x88\xb6", 3 },
	/*  DOUBLE-STRUCK CAPITAL Q  */
	{ "rationals", "\xe2\x84\x9a", 3 },
	/*  RIGHTWARDS DOUBLE DASH ARROW  */
	{ "rbarr", "\xe2\xa4\x8d", 3 },
	/*  LIGHT RIGHT TORTOISE SHELL BRACKET ORNAMENT  */
	{ "rbbrk", "\xe2\x9d\xb3", 3 },
	/*  RIGHT CURLY BRACKET  */
	{ "rbrace", "\x7d", 1 },
	/*  RIGHT SQUARE BRACKET  */
	{ "rbrack", "\x5d", 1 },
	/*  RIGHT SQUARE BRACKET WITH UNDERBAR  */
	{ "rbrke", "\xe2\xa6\x8c", 3 },
	/*  RIGHT SQUARE BRACKET WITH TICK IN BOTTOM CORNER  */
	{ "rbrksld", "\xe2\xa6\x8e", 3 },
	/*  RIGHT SQUARE BRACKET WITH TICK IN TOP CORNER  */
	{ "rbrkslu", "\xe2\xa6\x90", 3 },
	/*  LATIN SMALL LETTER R WITH CARON  */
	{ "rcaron", "\xc5\x99", 2 },
	/*  LATIN SMALL LETTER R WITH CEDILLA  */
	{ "rcedil", "\xc5\x97", 2 },
	/*  RIGHT CEILING  */
	{ "rceil", "\xe2\x8c\x89", 3 },
	/*  RIGHT CURLY BRACKET  */
	{ "rcub", "\x7d", 1 },
	/*  CYRILLIC SMALL LETTER ER  */
	{ "rcy", "\xd1\x80", 2 },
	/*  ARROW POINTING DOWNWARDS THEN CURVING RIGHTWARDS  */
	{ "rdca", "\xe2\xa4\xb7", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWN TO BAR  */
	{ "rdharb", "\xe2\xa5\x97", 3 },
	/*  BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT  */
	{ "rdiag", "\xe2\x95\xb1", 3 },
	/*  RISING DIAGONAL CROSSING FALLING DIAGONAL  */
	{ "rdiofdi", "\xe2\xa4\xab", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWN ABOVE LEFTWARDS HARPOON WITH BARB DOWN  */
	{ "rdldhar", "\xe2\xa5\xa9", 3 },
	/*  RISING DIAGONAL CROSSING SOUTH EAST ARROW  */
	{ "rdosearr", "\xe2\xa4\xb0", 3 },
	/*  RIGHT DOUBLE QUOTATION MARK  */
	{ "rdquo", "\xe2\x80\x9d", 3 },
	/*  RIGHT DOUBLE QUOTATION MARK  */
	{ "rdquor", "\xe2\x80\x9d", 3 },
	/*  DOWNWARDS ARROW WITH TIP RIGHTWARDS  */
	{ "rdsh", "\xe2\x86\xb3", 3 },
	/*  BLACK-LETTER CAPITAL R  */
	{ "real", "\xe2\x84\x9c", 3 },
	/*  SCRIPT CAPITAL R  */
	{ "realine", "\xe2\x84\x9b", 3 },
	/*  BLACK-LETTER CAPITAL R  */
	{ "realpart", "\xe2\x84\x9c", 3 },
	/*  DOUBLE-STRUCK CAPITAL R  */
	{ "reals", "\xe2\x84\x9d", 3 },
	/*  WHITE RECTANGLE  */
	{ "rect", "\xe2\x96\xad", 3 },
	/*  REGISTERED SIGN  */
	{ "reg", "\xc2\xae", 2 },
	/*  BOWTIE WITH RIGHT HALF BLACK  */
	{ "rfbowtie", "\xe2\xa7\x92", 3 },
	/*  RIGHT FISH TAIL  */
	{ "rfisht", "\xe2\xa5\xbd", 3 },
	/*  RIGHT FLOOR  */
	{ "rfloor", "\xe2\x8c\x8b", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL R  */
	{ "rfr", "\xf0\x9d\x94\xaf", 4 },
	/*  TIMES WITH RIGHT HALF BLACK  */
	{ "rftimes", "\xe2\xa7\x95", 3 },
	/*  GREEK SMALL LETTER RHO  */
	{ "rgr", "\xcf\x81", 2 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWNWARDS  */
	{ "rhard", "\xe2\x87\x81", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UPWARDS  */
	{ "rharu", "\xe2\x87\x80", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UP ABOVE LONG DASH  */
	{ "rharul", "\xe2\xa5\xac", 3 },
	/*  GREEK SMALL LETTER RHO  */
	{ "rho", "\xcf\x81", 2 },
	/*  GREEK RHO SYMBOL  */
	{ "rhov", "\xcf\xb1", 2 },
	/*  RIGHTWARDS ARROW  */
	{ "rightarrow", "\xe2\x86\x92", 3 },
	/*  RIGHTWARDS ARROW WITH TAIL  */
	{ "rightarrowtail", "\xe2\x86\xa3", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB DOWNWARDS  */
	{ "rightharpoondown", "\xe2\x87\x81", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UPWARDS  */
	{ "rightharpoonup", "\xe2\x87\x80", 3 },
	/*  RIGHTWARDS ARROW OVER LEFTWARDS ARROW  */
	{ "rightleftarrows", "\xe2\x87\x84", 3 },
	/*  RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON  */
	{ "rightleftharpoons", "\xe2\x87\x8c", 3 },
	/*  RIGHTWARDS PAIRED ARROWS  */
	{ "rightrightarrows", "\xe2\x87\x89", 3 },
	/*  RIGHTWARDS WAVE ARROW  */
	{ "rightsquigarrow", "\xe2\x86\x9d", 3 },
	/*  RIGHT SEMIDIRECT PRODUCT  */
	{ "rightthreetimes", "\xe2\x8b\x8c", 3 },
	/*  RIGHT DOUBLE ARROW WITH ROUNDED HEAD  */
	{ "rimply", "\xe2\xa5\xb0", 3 },
	/*  RING ABOVE  */
	{ "ring", "\xcb\x9a", 2 },
	/*  IMAGE OF OR APPROXIMATELY EQUAL TO  */
	{ "risingdotseq", "\xe2\x89\x93", 3 },
	/*  RIGHTWARDS ARROW OVER LEFTWARDS ARROW  */
	{ "rlarr", "\xe2\x87\x84", 3 },
	/*  RIGHTWARDS ARROW OVER LEFTWARDS ARROW  */
	{ "rlarr2", "\xe2\x87\x84", 3 },
	/*  RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON  */
	{ "rlhar", "\xe2\x87\x8c", 3 },
	/*  RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON  */
	{ "rlhar2", "\xe2\x87\x8c", 3 },
	/*  RIGHT-TO-LEFT MARK  */
	{ "rlm", "\xe2\x80\x8f", 3 },
	/*  UPPER RIGHT OR LOWER LEFT CURLY BRACKET SECTION  */
	{ "rmoust", "\xe2\x8e\xb1", 3 },
	/*  UPPER RIGHT OR LOWER LEFT CURLY BRACKET SECTION  */
	{ "rmoustache", "\xe2\x8e\xb1", 3 },
	/*  DOES NOT DIVIDE WITH REVERSED NEGATION SLASH  */
	{ "rnmid", "\xe2\xab\xae", 3 },
	/*  MATHEMATICAL RIGHT WHITE TORTOISE SHELL BRACKET  */
	{ "roang", "\xe2\x9f\xad", 3 },
	/*  RIGHTWARDS OPEN-HEADED ARROW  */
	{ "roarr", "\xe2\x87\xbe", 3 },
	/*  MATHEMATICAL RIGHT WHITE SQUARE BRACKET  */
	{ "robrk", "\xe2\x9f\xa7", 3 },
	/*  RIGHT WHITE CURLY BRACKET  */
	{ "rocub", "\xe2\xa6\x84", 3 },
	/*  RIGHT WHITE PARENTHESIS  */
	{ "ropar", "\xe2\xa6\x86", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL R  */
	{ "ropf", "\xf0\x9d\x95\xa3", 4 },
	/*  PLUS SIGN IN RIGHT HALF CIRCLE  */
	{ "roplus", "\xe2\xa8\xae", 3 },
	/*  MULTIPLICATION SIGN IN RIGHT HALF CIRCLE  */
	{ "rotimes", "\xe2\xa8\xb5", 3 },
	/*  RIGHT PARENTHESIS  */
	{ "rpar", "\x29", 1 },
	/*  RIGHT ARC GREATER-THAN BRACKET  */
	{ "rpargt", "\xe2\xa6\x94", 3 },
	/*  LINE INTEGRATION WITH RECTANGULAR PATH AROUND POLE  */
	{ "rppolint", "\xe2\xa8\x92", 3 },
	/*  RIGHTWARDS PAIRED ARROWS  */
	{ "rrarr", "\xe2\x87\x89", 3 },
	/*  SINGLE RIGHT-POINTING ANGLE QUOTATION MARK  */
	{ "rsaquo", "\xe2\x80\xba", 3 },
	/*  MATHEMATICAL SCRIPT SMALL R  */
	{ "rscr", "\xf0\x9d\x93\x87", 4 },
	/*  UPWARDS ARROW WITH TIP RIGHTWARDS  */
	{ "rsh", "\xe2\x86\xb1", 3 },
	/*  REVERSE SOLIDUS WITH HORIZONTAL STROKE  */
	{ "rsolbar", "\xe2\xa7\xb7", 3 },
	/*  RIGHT SQUARE BRACKET  */
	{ "rsqb", "\x5d", 1 },
	/*  RIGHT SINGLE QUOTATION MARK  */
	{ "rsquo", "\xe2\x80\x99", 3 },
	/*  RIGHT SINGLE QUOTATION MARK  */
	{ "rsquor", "\xe2\x80\x99", 3 },
	/*  RIGHT SEMIDIRECT PRODUCT  */
	{ "rthree", "\xe2\x8b\x8c", 3 },
	/*  RIGHT NORMAL FACTOR SEMIDIRECT PRODUCT  */
	{ "rtimes", "\xe2\x8b\x8a", 3 },
	/*  WHITE RIGHT-POINTING SMALL TRIANGLE  */
	{ "rtri", "\xe2\x96\xb9", 3 },
	/*  CONTAINS AS NORMAL SUBGROUP OR EQUAL TO  */
	{ "rtrie", "\xe2\x8a\xb5", 3 },
	/*  BLACK RIGHT-POINTING SMALL TRIANGLE  */
	{ "rtrif", "\xe2\x96\xb8", 3 },
	/*  RIGHT TRIANGLE ABOVE LEFT TRIANGLE  */
	{ "rtriltri", "\xe2\xa7\x8e", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UP TO BAR  */
	{ "ruharb", "\xe2\xa5\x93", 3 },
	/*  RIGHTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB UP  */
	{ "ruluhar", "\xe2\xa5\xa8", 3 },
	/*  PRESCRIPTION TAKE  */
	{ "rx", "\xe2\x84\x9e", 3 },
	/*  LATIN SMALL LETTER S WITH ACUTE  */
	{ "sacute", "\xc5\x9b", 2 },
	/*  N-ARY COPRODUCT  */
	{ "samalg", "\xe2\x88\x90", 3 },
	/*  GREEK LETTER SAMPI  */
	{ "sampi", "\xcf\xa0", 2 },
	/*  SINGLE LOW-9 QUOTATION MARK  */
	{ "sbquo", "\xe2\x80\x9a", 3 },
	/*  SMALL REVERSE SOLIDUS  */
	{ "sbsol", "\xef\xb9\xa8", 3 },
	/*  SUCCEEDS  */
	{ "sc", "\xe2\x89\xbb", 3 },
	/*  SUCCEEDS ABOVE EQUALS SIGN  */
	{ "scE", "\xe2\xaa\xb4", 3 },
	/*  SUCCEEDS ABOVE ALMOST EQUAL TO  */
	{ "scap", "\xe2\xaa\xb8", 3 },
	/*  LATIN SMALL LETTER S WITH CARON  */
	{ "scaron", "\xc5\xa1", 2 },
	/*  SUCCEEDS OR EQUAL TO  */
	{ "sccue", "\xe2\x89\xbd", 3 },
	/*  SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN  */
	{ "sce", "\xe2\xaa\xb0", 3 },
	/*  LATIN SMALL LETTER S WITH CEDILLA  */
	{ "scedil", "\xc5\x9f", 2 },
	/*  LATIN SMALL LETTER S WITH CIRCUMFLEX  */
	{ "scirc", "\xc5\x9d", 2 },
	/*  SUCCEEDS ABOVE NOT EQUAL TO  */
	{ "scnE", "\xe2\xaa\xb6", 3 },
	/*  SUCCEEDS ABOVE NOT ALMOST EQUAL TO  */
	{ "scnap", "\xe2\xaa\xba", 3 },
	/*  SUCCEEDS BUT NOT EQUIVALENT TO  */
	{ "scnsim", "\xe2\x8b\xa9", 3 },
	/*  LINE INTEGRATION WITH SEMICIRCULAR PATH AROUND POLE  */
	{ "scpolint", "\xe2\xa8\x93", 3 },
	/*  SUCCEEDS OR EQUIVALENT TO  */
	{ "scsim", "\xe2\x89\xbf", 3 },
	/*  CYRILLIC SMALL LETTER ES  */
	{ "scy", "\xd1\x81", 2 },
	/*  DOT OPERATOR  */
	{ "sdot", "\xe2\x8b\x85", 3 },
	/*  SQUARED DOT OPERATOR  */
	{ "sdotb", "\xe2\x8a\xa1", 3 },
	/*  EQUALS SIGN WITH DOT BELOW  */
	{ "sdote", "\xe2\xa9\xa6", 3 },
	/*  SOUTH EAST DOUBLE ARROW  */
	{ "seArr", "\xe2\x87\x98", 3 },
	/*  SOUTH EAST ARROW WITH HOOK  */
	{ "searhk", "\xe2\xa4\xa5", 3 },
	/*  SOUTH EAST ARROW  */
	{ "searr", "\xe2\x86\x98", 3 },
	/*  SOUTH EAST ARROW  */
	{ "searrow", "\xe2\x86\x98", 3 },
	/*  SECTION SIGN  */
	{ "sect", "\xc2\xa7", 2 },
	/*  SEMICOLON  */
	{ "semi", "\x3b", 1 },
	/*  SOUTH EAST ARROW CROSSING NORTH EAST ARROW  */
	{ "seonearr", "\xe2\xa4\xad", 3 },
	/*  SOUTH EAST ARROW AND SOUTH WEST ARROW  */
	{ "seswar", "\xe2\xa4\xa9", 3 },
	/*  SET MINUS  */
	{ "setminus", "\xe2\x88\x96", 3 },
	/*  SET MINUS  */
	{ "setmn", "\xe2\x88\x96", 3 },
	/*  SIX POINTED BLACK STAR  */
	{ "sext", "\xe2\x9c\xb6", 3 },
	/*  GREEK SMALL LETTER FINAL SIGMA  */
	{ "sfgr", "\xcf\x82", 2 },
	/*  MATHEMATICAL FRAKTUR SMALL S  */
	{ "sfr", "\xf0\x9d\x94\xb0", 4 },
	/*  FROWN  */
	{ "sfrown", "\xe2\x8c\xa2", 3 },
	/*  GREEK SMALL LETTER SIGMA  */
	{ "sgr", "\xcf\x83", 2 },
	/*  MUSIC SHARP SIGN  */
	{ "sharp", "\xe2\x99\xaf", 3 },
	/*  CYRILLIC SMALL LETTER SHCHA  */
	{ "shchcy", "\xd1\x89", 2 },
	/*  CYRILLIC SMALL LETTER SHA  */
	{ "shcy", "\xd1\x88", 2 },
	/*  DIVIDES  */
	{ "shortmid", "\xe2\x88\xa3", 3 },
	/*  PARALLEL TO  */
	{ "shortparallel", "\xe2\x88\xa5", 3 },
	/*  SHUFFLE PRODUCT  */
	{ "shuffle", "\xe2\xa7\xa2", 3 },
	/*  SOFT HYPHEN  */
	{ "shy", "\xc2\xad", 2 },
	/*  GREEK SMALL LETTER SIGMA  */
	{ "sigma", "\xcf\x83", 2 },
	/*  GREEK SMALL LETTER FINAL SIGMA  */
	{ "sigmaf", "\xcf\x82", 2 },
	/*  GREEK SMALL LETTER FINAL SIGMA  */
	{ "sigmav", "\xcf\x82", 2 },
	/*  TILDE OPERATOR  */
	{ "sim", "\xe2\x88\xbc", 3 },
	/*  TILDE OPERATOR WITH DOT ABOVE  */
	{ "simdot", "\xe2\xa9\xaa", 3 },
	/*  ASYMPTOTICALLY EQUAL TO  */
	{ "sime", "\xe2\x89\x83", 3 },
	/*  ASYMPTOTICALLY EQUAL TO  */
	{ "simeq", "\xe2\x89\x83", 3 },
	/*  SIMILAR OR GREATER-THAN  */
	{ "simg", "\xe2\xaa\x9e", 3 },
	/*  SIMILAR ABOVE GREATER-THAN ABOVE EQUALS SIGN  */
	{ "simgE", "\xe2\xaa\xa0", 3 },
	/*  SIMILAR OR LESS-THAN  */
	{ "siml", "\xe2\xaa\x9d", 3 },
	/*  SIMILAR ABOVE LESS-THAN ABOVE EQUALS SIGN  */
	{ "simlE", "\xe2\xaa\x9f", 3 },
	/*  APPROXIMATELY BUT NOT ACTUALLY EQUAL TO  */
	{ "simne", "\xe2\x89\x86", 3 },
	/*  PLUS SIGN WITH TILDE ABOVE  */
	{ "simplus", "\xe2\xa8\xa4", 3 },
	/*  TILDE OPERATOR ABOVE RIGHTWARDS ARROW  */
	{ "simrarr", "\xe2\xa5\xb2", 3 },
	/*  LEFTWARDS ARROW  */
	{ "slarr", "\xe2\x86\x90", 3 },
	/*  INTEGRAL AVERAGE WITH SLASH  */
	{ "slint", "\xe2\xa8\x8f", 3 },
	/*  SET MINUS  */
	{ "smallsetminus", "\xe2\x88\x96", 3 },
	/*  SMASH PRODUCT  */
	{ "smashp", "\xe2\xa8\xb3", 3 },
	/*  EQUALS SIGN AND SLANTED PARALLEL WITH TILDE ABOVE  */
	{ "smeparsl", "\xe2\xa7\xa4", 3 },
	/*  DIVIDES  */
	{ "smid", "\xe2\x88\xa3", 3 },
	/*  SMILE  */
	{ "smile", "\xe2\x8c\xa3", 3 },
	/*  SMALLER THAN  */
	{ "smt", "\xe2\xaa\xaa", 3 },
	/*  SMALLER THAN OR EQUAL TO  */
	{ "smte", "\xe2\xaa\xac", 3 },
	/*  SMALLER THAN OR slanted EQUAL  */
	{ "smtes", "\xe2\xaa\xac\xef\xb8\x80", 6 },
	/*  CYRILLIC SMALL LETTER SOFT SIGN  */
	{ "softcy", "\xd1\x8c", 2 },
	/*  SOLIDUS  */
	{ "sol", "\x2f", 1 },
	/*  SQUARED RISING DIAGONAL SLASH  */
	{ "solb", "\xe2\xa7\x84", 3 },
	/*  APL FUNCTIONAL SYMBOL SLASH BAR  */
	{ "solbar", "\xe2\x8c\xbf", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL S  */
	{ "sopf", "\xf0\x9d\x95\xa4", 4 },
	/*  BLACK SPADE SUIT  */
	{ "spades", "\xe2\x99\xa0", 3 },
	/*  BLACK SPADE SUIT  */
	{ "spadesuit", "\xe2\x99\xa0", 3 },
	/*  PARALLEL TO  */
	{ "spar", "\xe2\x88\xa5", 3 },
	/*  SQUARE CAP  */
	{ "sqcap", "\xe2\x8a\x93", 3 },
	/*  SQUARE CAP with serifs  */
	{ "sqcaps", "\xe2\x8a\x93\xef\xb8\x80", 6 },
	/*  SQUARE CUP  */
	{ "sqcup", "\xe2\x8a\x94", 3 },
	/*  SQUARE CUP with serifs  */
	{ "sqcups", "\xe2\x8a\x94\xef\xb8\x80", 6 },
	/*  SQUARE IMAGE OF  */
	{ "sqsub", "\xe2\x8a\x8f", 3 },
	/*  SQUARE IMAGE OF OR EQUAL TO  */
	{ "sqsube", "\xe2\x8a\x91", 3 },
	/*  SQUARE IMAGE OF  */
	{ "sqsubset", "\xe2\x8a\x8f", 3 },
	/*  SQUARE IMAGE OF OR EQUAL TO  */
	{ "sqsubseteq", "\xe2\x8a\x91", 3 },
	/*  SQUARE ORIGINAL OF  */
	{ "sqsup", "\xe2\x8a\x90", 3 },
	/*  SQUARE ORIGINAL OF OR EQUAL TO  */
	{ "sqsupe", "\xe2\x8a\x92", 3 },
	/*  SQUARE ORIGINAL OF  */
	{ "sqsupset", "\xe2\x8a\x90", 3 },
	/*  SQUARE ORIGINAL OF OR EQUAL TO  */
	{ "sqsupseteq", "\xe2\x8a\x92", 3 },
	/*  WHITE SQUARE  */
	{ "squ", "\xe2\x96\xa1", 3 },
	/*  WHITE SQUARE  */
	{ "square", "\xe2\x96\xa1", 3 },
	/*  BLACK SMALL SQUARE  */
	{ "squarf", "\xe2\x96\xaa", 3 },
	/*  SQUARED SQUARE  */
	{ "squb", "\xe2\xa7\x88", 3 },
	/*  ERROR-BARRED WHITE SQUARE  */
	{ "squerr", "\xe2\xa7\xae", 3 },
	/*  BLACK SMALL SQUARE  */
	{ "squf", "\xe2\x96\xaa", 3 },
	/*  ERROR-BARRED BLACK SQUARE  */
	{ "squferr", "\xe2\xa7\xaf", 3 },
	/*  RIGHTWARDS ARROW  */
	{ "srarr", "\xe2\x86\x92", 3 },
	/*  MATHEMATICAL SCRIPT SMALL S  */
	{ "sscr", "\xf0\x9d\x93\x88", 4 },
	/*  SET MINUS  */
	{ "ssetmn", "\xe2\x88\x96", 3 },
	/*  SMILE  */
	{ "ssmile", "\xe2\x8c\xa3", 3 },
	/*  STAR OPERATOR  */
	{ "sstarf", "\xe2\x8b\x86", 3 },
	/*  WHITE STAR  */
	{ "star", "\xe2\x98\x86", 3 },
	/*  BLACK STAR  */
	{ "starf", "\xe2\x98\x85", 3 },
	/*  GREEK LETTER STIGMA  */
	{ "stigma", "\xcf\x9a", 2 },
	/*  GREEK LUNATE EPSILON SYMBOL  */
	{ "straightepsilon", "\xcf\xb5", 2 },
	/*  GREEK PHI SYMBOL  */
	{ "straightphi", "\xcf\x95", 2 },
	/*  MACRON  */
	{ "strns", "\xc2\xaf", 2 },
	/*  SUBSET OF  */
	{ "sub", "\xe2\x8a\x82", 3 },
	/*  SUBSET OF ABOVE EQUALS SIGN  */
	{ "subE", "\xe2\xab\x85", 3 },
	/*  SUBSET WITH DOT  */
	{ "subdot", "\xe2\xaa\xbd", 3 },
	/*  SUBSET OF OR EQUAL TO  */
	{ "sube", "\xe2\x8a\x86", 3 },
	/*  SUBSET OF OR EQUAL TO WITH DOT ABOVE  */
	{ "subedot", "\xe2\xab\x83", 3 },
	/*  SUBSET WITH MULTIPLICATION SIGN BELOW  */
	{ "submult", "\xe2\xab\x81", 3 },
	/*  SUBSET OF ABOVE NOT EQUAL TO  */
	{ "subnE", "\xe2\xab\x8b", 3 },
	/*  SUBSET OF WITH NOT EQUAL TO  */
	{ "subne", "\xe2\x8a\x8a", 3 },
	/*  SUBSET WITH PLUS SIGN BELOW  */
	{ "subplus", "\xe2\xaa\xbf", 3 },
	/*  SUBSET ABOVE RIGHTWARDS ARROW  */
	{ "subrarr", "\xe2\xa5\xb9", 3 },
	/*  SUBSET OF  */
	{ "subset", "\xe2\x8a\x82", 3 },
	/*  SUBSET OF OR EQUAL TO  */
	{ "subseteq", "\xe2\x8a\x86", 3 },
	/*  SUBSET OF ABOVE EQUALS SIGN  */
	{ "subseteqq", "\xe2\xab\x85", 3 },
	/*  SUBSET OF WITH NOT EQUAL TO  */
	{ "subsetneq", "\xe2\x8a\x8a", 3 },
	/*  SUBSET OF ABOVE NOT EQUAL TO  */
	{ "subsetneqq", "\xe2\xab\x8b", 3 },
	/*  SUBSET OF ABOVE TILDE OPERATOR  */
	{ "subsim", "\xe2\xab\x87", 3 },
	/*  SUBSET ABOVE SUBSET  */
	{ "subsub", "\xe2\xab\x95", 3 },
	/*  SUBSET ABOVE SUPERSET  */
	{ "subsup", "\xe2\xab\x93", 3 },
	/*  SUCCEEDS  */
	{ "succ", "\xe2\x89\xbb", 3 },
	/*  SUCCEEDS ABOVE ALMOST EQUAL TO  */
	{ "succapprox", "\xe2\xaa\xb8", 3 },
	/*  SUCCEEDS OR EQUAL TO  */
	{ "succcurlyeq", "\xe2\x89\xbd", 3 },
	/*  SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN  */
	{ "succeq", "\xe2\xaa\xb0", 3 },
	/*  SUCCEEDS ABOVE NOT ALMOST EQUAL TO  */
	{ "succnapprox", "\xe2\xaa\xba", 3 },
	/*  SUCCEEDS ABOVE NOT EQUAL TO  */
	{ "succneqq", "\xe2\xaa\xb6", 3 },
	/*  SUCCEEDS BUT NOT EQUIVALENT TO  */
	{ "succnsim", "\xe2\x8b\xa9", 3 },
	/*  SUCCEEDS OR EQUIVALENT TO  */
	{ "succsim", "\xe2\x89\xbf", 3 },
	/*  N-ARY SUMMATION  */
	{ "sum", "\xe2\x88\x91", 3 },
	/*  SUMMATION WITH INTEGRAL  */
	{ "sumint", "\xe2\xa8\x8b", 3 },
	/*  EIGHTH NOTE  */
	{ "sung", "\xe2\x99\xaa", 3 },
	/*  SUPERSET OF  */
	{ "sup", "\xe2\x8a\x83", 3 },
	/*  SUPERSCRIPT ONE  */
	{ "sup1", "\xc2\xb9", 2 },
	/*  SUPERSCRIPT TWO  */
	{ "sup2", "\xc2\xb2", 2 },
	/*  SUPERSCRIPT THREE  */
	{ "sup3", "\xc2\xb3", 2 },
	/*  SUPERSET OF ABOVE EQUALS SIGN  */
	{ "supE", "\xe2\xab\x86", 3 },
	/*  SUPERSET WITH DOT  */
	{ "supdot", "\xe2\xaa\xbe", 3 },
	/*  SUPERSET BESIDE AND JOINED BY DASH WITH SUBSET  */
	{ "supdsub", "\xe2\xab\x98", 3 },
	/*  SUPERSET OF OR EQUAL TO  */
	{ "supe", "\xe2\x8a\x87", 3 },
	/*  SUPERSET OF OR EQUAL TO WITH DOT ABOVE  */
	{ "supedot", "\xe2\xab\x84", 3 },
	/*  SUPERSET PRECEDING SOLIDUS  */
	{ "suphsol", "\xe2\x9f\x89", 3 },
	/*  SUPERSET BESIDE SUBSET  */
	{ "suphsub", "\xe2\xab\x97", 3 },
	/*  SUPERSET ABOVE LEFTWARDS ARROW  */
	{ "suplarr", "\xe2\xa5\xbb", 3 },
	/*  SUPERSET WITH MULTIPLICATION SIGN BELOW  */
	{ "supmult", "\xe2\xab\x82", 3 },
	/*  SUPERSET OF ABOVE NOT EQUAL TO  */
	{ "supnE", "\xe2\xab\x8c", 3 },
	/*  SUPERSET OF WITH NOT EQUAL TO  */
	{ "supne", "\xe2\x8a\x8b", 3 },
	/*  SUPERSET WITH PLUS SIGN BELOW  */
	{ "supplus", "\xe2\xab\x80", 3 },
	/*  SUPERSET OF  */
	{ "supset", "\xe2\x8a\x83", 3 },
	/*  SUPERSET OF OR EQUAL TO  */
	{ "supseteq", "\xe2\x8a\x87", 3 },
	/*  SUPERSET OF ABOVE EQUALS SIGN  */
	{ "supseteqq", "\xe2\xab\x86", 3 },
	/*  SUPERSET OF WITH NOT EQUAL TO  */
	{ "supsetneq", "\xe2\x8a\x8b", 3 },
	/*  SUPERSET OF ABOVE NOT EQUAL TO  */
	{ "supsetneqq", "\xe2\xab\x8c", 3 },
	/*  SUPERSET OF ABOVE TILDE OPERATOR  */
	{ "supsim", "\xe2\xab\x88", 3 },
	/*  SUPERSET ABOVE SUBSET  */
	{ "supsub", "\xe2\xab\x94", 3 },
	/*  SUPERSET ABOVE SUPERSET  */
	{ "supsup", "\xe2\xab\x96", 3 },
	/*  SOUTH WEST DOUBLE ARROW  */
	{ "swArr", "\xe2\x87\x99", 3 },
	/*  SOUTH WEST ARROW WITH HOOK  */
	{ "swarhk", "\xe2\xa4\xa6", 3 },
	/*  SOUTH WEST ARROW  */
	{ "swarr", "\xe2\x86\x99", 3 },
	/*  SOUTH WEST ARROW  */
	{ "swarrow", "\xe2\x86\x99", 3 },
	/*  SOUTH WEST ARROW AND NORTH WEST ARROW  */
	{ "swnwar", "\xe2\xa4\xaa", 3 },
	/*  LATIN SMALL LETTER SHARP S  */
	{ "szlig", "\xc3\x9f", 2 },
	/*  POSITION INDICATOR  */
	{ "target", "\xe2\x8c\x96", 3 },
	/*  GREEK SMALL LETTER TAU  */
	{ "tau", "\xcf\x84", 2 },
	/*  TOP SQUARE BRACKET  */
	{ "tbrk", "\xe2\x8e\xb4", 3 },
	/*  LATIN SMALL LETTER T WITH CARON  */
	{ "tcaron", "\xc5\xa5", 2 },
	/*  LATIN SMALL LETTER T WITH CEDILLA  */
	{ "tcedil", "\xc5\xa3", 2 },
	/*  CYRILLIC SMALL LETTER TE  */
	{ "tcy", "\xd1\x82", 2 },
	/*  COMBINING THREE DOTS ABOVE  */
	{ "tdot", "\xe2\x83\x9b", 3 },
	/*  TELEPHONE RECORDER  */
	{ "telrec", "\xe2\x8c\x95", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL T  */
	{ "tfr", "\xf0\x9d\x94\xb1", 4 },
	/*  GREEK SMALL LETTER TAU  */
	{ "tgr", "\xcf\x84", 2 },
	/*  THEREFORE  */
	{ "there4", "\xe2\x88\xb4", 3 },
	/*  THEREFORE  */
	{ "therefore", "\xe2\x88\xb4", 3 },
	/*  THERMODYNAMIC  */
	{ "thermod", "\xe2\xa7\xa7", 3 },
	/*  GREEK SMALL LETTER THETA  */
	{ "theta", "\xce\xb8", 2 },
	/*  GREEK SMALL LETTER THETA  */
	{ "thetas", "\xce\xb8", 2 },
	/*  GREEK THETA SYMBOL  */
	{ "thetasym", "\xcf\x91", 2 },
	/*  GREEK THETA SYMBOL  */
	{ "thetav", "\xcf\x91", 2 },
	/*  GREEK SMALL LETTER THETA  */
	{ "thgr", "\xce\xb8", 2 },
	/*  ALMOST EQUAL TO  */
	{ "thickapprox", "\xe2\x89\x88", 3 },
	/*  TILDE OPERATOR  */
	{ "thicksim", "\xe2\x88\xbc", 3 },
	/*  THIN SPACE  */
	{ "thinsp", "\xe2\x80\x89", 3 },
	/*  ALMOST EQUAL TO  */
	{ "thkap", "\xe2\x89\x88", 3 },
	/*  TILDE OPERATOR  */
	{ "thksim", "\xe2\x88\xbc", 3 },
	/*  LATIN SMALL LETTER THORN  */
	{ "thorn", "\xc3\xbe", 2 },
	/*  SMALL TILDE  */
	{ "tilde", "\xcb\x9c", 2 },
	/*  INTEGRAL WITH TIMES SIGN  */
	{ "timeint", "\xe2\xa8\x98", 3 },
	/*  MULTIPLICATION SIGN  */
	{ "times", "\xc3\x97", 2 },
	/*  SQUARED TIMES  */
	{ "timesb", "\xe2\x8a\xa0", 3 },
	/*  MULTIPLICATION SIGN WITH UNDERBAR  */
	{ "timesbar", "\xe2\xa8\xb1", 3 },
	/*  MULTIPLICATION SIGN WITH DOT ABOVE  */
	{ "timesd", "\xe2\xa8\xb0", 3 },
	/*  TRIPLE INTEGRAL  */
	{ "tint", "\xe2\x88\xad", 3 },
	/*  NORTH EAST ARROW AND SOUTH EAST ARROW  */
	{ "toea", "\xe2\xa4\xa8", 3 },
	/*  DOWN TACK  */
	{ "top", "\xe2\x8a\xa4", 3 },
	/*  APL FUNCTIONAL SYMBOL I-BEAM  */
	{ "topbot", "\xe2\x8c\xb6", 3 },
	/*  DOWN TACK WITH CIRCLE BELOW  */
	{ "topcir", "\xe2\xab\xb1", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL T  */
	{ "topf", "\xf0\x9d\x95\xa5", 4 },
	/*  PITCHFORK WITH TEE TOP  */
	{ "topfork", "\xe2\xab\x9a", 3 },
	/*  SOUTH EAST ARROW AND SOUTH WEST ARROW  */
	{ "tosa", "\xe2\xa4\xa9", 3 },
	/*  TRIPLE PRIME  */
	{ "tprime", "\xe2\x80\xb4", 3 },
	/*  TRADE MARK SIGN  */
	{ "trade", "\xe2\x84\xa2", 3 },
	/*  S IN TRIANGLE  */
	{ "triS", "\xe2\xa7\x8c", 3 },
	/*  WHITE UP-POINTING SMALL TRIANGLE  */
	{ "triangle", "\xe2\x96\xb5", 3 },
	/*  WHITE DOWN-POINTING SMALL TRIANGLE  */
	{ "triangledown", "\xe2\x96\xbf", 3 },
	/*  WHITE LEFT-POINTING SMALL TRIANGLE  */
	{ "triangleleft", "\xe2\x97\x83", 3 },
	/*  NORMAL SUBGROUP OF OR EQUAL TO  */
	{ "trianglelefteq", "\xe2\x8a\xb4", 3 },
	/*  DELTA EQUAL TO  */
	{ "triangleq", "\xe2\x89\x9c", 3 },
	/*  WHITE RIGHT-POINTING SMALL TRIANGLE  */
	{ "triangleright", "\xe2\x96\xb9", 3 },
	/*  CONTAINS AS NORMAL SUBGROUP OR EQUAL TO  */
	{ "trianglerighteq", "\xe2\x8a\xb5", 3 },
	/*  TRIANGLE WITH UNDERBAR  */
	{ "tribar", "\xe2\xa7\x8b", 3 },
	/*  WHITE UP-POINTING TRIANGLE WITH DOT  */
	{ "tridot", "\xe2\x97\xac", 3 },
	/*  TRIANGLE WITH DOT ABOVE  */
	{ "tridoto", "\xe2\xa7\x8a", 3 },
	/*  DELTA EQUAL TO  */
	{ "trie", "\xe2\x89\x9c", 3 },
	/*  MINUS SIGN IN TRIANGLE  */
	{ "triminus", "\xe2\xa8\xba", 3 },
	/*  PLUS SIGN IN TRIANGLE  */
	{ "triplus", "\xe2\xa8\xb9", 3 },
	/*  TRIANGLE WITH SERIFS AT BOTTOM  */
	{ "trisb", "\xe2\xa7\x8d", 3 },
	/*  MULTIPLICATION SIGN IN TRIANGLE  */
	{ "tritime", "\xe2\xa8\xbb", 3 },
	/*  WHITE TRAPEZIUM  */
	{ "trpezium", "\xe2\x8f\xa2", 3 },
	/*  MATHEMATICAL SCRIPT SMALL T  */
	{ "tscr", "\xf0\x9d\x93\x89", 4 },
	/*  CYRILLIC SMALL LETTER TSE  */
	{ "tscy", "\xd1\x86", 2 },
	/*  CYRILLIC SMALL LETTER TSHE  */
	{ "tshcy", "\xd1\x9b", 2 },
	/*  LATIN SMALL LETTER T WITH STROKE  */
	{ "tstrok", "\xc5\xa7", 2 },
	/*  TRIPLE VERTICAL BAR DELIMITER  */
	{ "tverbar", "\xe2\xa6\x80", 3 },
	/*  BETWEEN  */
	{ "twixt", "\xe2\x89\xac", 3 },
	/*  LEFTWARDS TWO HEADED ARROW  */
	{ "twoheadleftarrow", "\xe2\x86\x9e", 3 },
	/*  RIGHTWARDS TWO HEADED ARROW  */
	{ "twoheadrightarrow", "\xe2\x86\xa0", 3 },
	/*  UPWARDS TRIPLE ARROW  */
	{ "uAarr", "\xe2\xa4\x8a", 3 },
	/*  UPWARDS DOUBLE ARROW  */
	{ "uArr", "\xe2\x87\x91", 3 },
	/*  UPWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT  */
	{ "uHar", "\xe2\xa5\xa3", 3 },
	/*  GREEK SMALL LETTER UPSILON WITH TONOS  */
	{ "uacgr", "\xcf\x8d", 2 },
	/*  LATIN SMALL LETTER U WITH ACUTE  */
	{ "uacute", "\xc3\xba", 2 },
	/*  UPWARDS ARROW  */
	{ "uarr", "\xe2\x86\x91", 3 },
	/*  UPWARDS PAIRED ARROWS  */
	{ "uarr2", "\xe2\x87\x88", 3 },
	/*  UPWARDS ARROW TO BAR  */
	{ "uarrb", "\xe2\xa4\x92", 3 },
	/*  UPWARDS ARROW WITH HORIZONTAL STROKE  */
	{ "uarrln", "\xe2\xa4\x89", 3 },
	/*  CYRILLIC SMALL LETTER SHORT U  */
	{ "ubrcy", "\xd1\x9e", 2 },
	/*  LATIN SMALL LETTER U WITH BREVE  */
	{ "ubreve", "\xc5\xad", 2 },
	/*  LATIN SMALL LETTER U WITH CIRCUMFLEX  */
	{ "ucirc", "\xc3\xbb", 2 },
	/*  CYRILLIC SMALL LETTER U  */
	{ "ucy", "\xd1\x83", 2 },
	/*  UPWARDS ARROW LEFTWARDS OF DOWNWARDS ARROW  */
	{ "udarr", "\xe2\x87\x85", 3 },
	/*  LATIN SMALL LETTER U WITH DOUBLE ACUTE  */
	{ "udblac", "\xc5\xb1", 2 },
	/*  UPWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT  */
	{ "udhar", "\xe2\xa5\xae", 3 },
	/*  GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS  */
	{ "udiagr", "\xce\xb0", 2 },
	/*  GREEK SMALL LETTER UPSILON WITH DIALYTIKA  */
	{ "udigr", "\xcf\x8b", 2 },
	/*  BOTTOM SQUARE BRACKET  */
	{ "udrbrk", "\xe2\x8e\xb5", 3 },
	/*  BOTTOM CURLY BRACKET  */
	{ "udrcub", "\xe2\x8f\x9f", 3 },
	/*  BOTTOM PARENTHESIS  */
	{ "udrpar", "\xe2\x8f\x9d", 3 },
	/*  UP FISH TAIL  */
	{ "ufisht", "\xe2\xa5\xbe", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL U  */
	{ "ufr", "\xf0\x9d\x94\xb2", 4 },
	/*  GREEK SMALL LETTER UPSILON  */
	{ "ugr", "\xcf\x85", 2 },
	/*  LATIN SMALL LETTER U WITH GRAVE  */
	{ "ugrave", "\xc3\xb9", 2 },
	/*  UPWARDS HARPOON WITH BARB LEFTWARDS  */
	{ "uharl", "\xe2\x86\xbf", 3 },
	/*  UPWARDS HARPOON WITH BARB RIGHTWARDS  */
	{ "uharr", "\xe2\x86\xbe", 3 },
	/*  UPPER HALF BLOCK  */
	{ "uhblk", "\xe2\x96\x80", 3 },
	/*  TOP LEFT CORNER  */
	{ "ulcorn", "\xe2\x8c\x9c", 3 },
	/*  TOP LEFT CORNER  */
	{ "ulcorner", "\xe2\x8c\x9c", 3 },
	/*  TOP LEFT CROP  */
	{ "ulcrop", "\xe2\x8c\x8f", 3 },
	/*  UP BARB LEFT DOWN BARB LEFT HARPOON  */
	{ "uldlshar", "\xe2\xa5\x91", 3 },
	/*  UPWARDS HARPOON WITH BARB LEFT TO BAR  */
	{ "ulharb", "\xe2\xa5\x98", 3 },
	/*  UPPER LEFT TRIANGLE  */
	{ "ultri", "\xe2\x97\xb8", 3 },
	/*  LATIN SMALL LETTER U WITH MACRON  */
	{ "umacr", "\xc5\xab", 2 },
	/*  DIAERESIS  */
	{ "uml", "\xc2\xa8", 2 },
	/*  LATIN SMALL LETTER U WITH OGONEK  */
	{ "uogon", "\xc5\xb3", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL U  */
	{ "uopf", "\xf0\x9d\x95\xa6", 4 },
	/*  UPWARDS ARROW  */
	{ "uparrow", "\xe2\x86\x91", 3 },
	/*  UP DOWN ARROW  */
	{ "updownarrow", "\xe2\x86\x95", 3 },
	/*  UPWARDS HARPOON WITH BARB LEFTWARDS  */
	{ "upharpoonleft", "\xe2\x86\xbf", 3 },
	/*  UPWARDS HARPOON WITH BARB RIGHTWARDS  */
	{ "upharpoonright", "\xe2\x86\xbe", 3 },
	/*  INTEGRAL WITH OVERBAR  */
	{ "upint", "\xe2\xa8\x9b", 3 },
	/*  MULTISET UNION  */
	{ "uplus", "\xe2\x8a\x8e", 3 },
	/*  GREEK SMALL LETTER UPSILON  */
	{ "upsi", "\xcf\x85", 2 },
	/*  GREEK UPSILON WITH HOOK SYMBOL  */
	{ "upsih", "\xcf\x92", 2 },
	/*  GREEK SMALL LETTER UPSILON  */
	{ "upsilon", "\xcf\x85", 2 },
	/*  UPWARDS PAIRED ARROWS  */
	{ "upuparrows", "\xe2\x87\x88", 3 },
	/*  TOP RIGHT CORNER  */
	{ "urcorn", "\xe2\x8c\x9d", 3 },
	/*  TOP RIGHT CORNER  */
	{ "urcorner", "\xe2\x8c\x9d", 3 },
	/*  TOP RIGHT CROP  */
	{ "urcrop", "\xe2\x8c\x8e", 3 },
	/*  UP BARB RIGHT DOWN BARB RIGHT HARPOON  */
	{ "urdrshar", "\xe2\xa5\x8f", 3 },
	/*  UPWARDS HARPOON WITH BARB RIGHT TO BAR  */
	{ "urharb", "\xe2\xa5\x94", 3 },
	/*  LATIN SMALL LETTER U WITH RING ABOVE  */
	{ "uring", "\xc5\xaf", 2 },
	/*  UPPER RIGHT TRIANGLE  */
	{ "urtri", "\xe2\x97\xb9", 3 },
	/*  BLACK UPPER RIGHT TRIANGLE  */
	{ "urtrif", "\xe2\x97\xa5", 3 },
	/*  MATHEMATICAL SCRIPT SMALL U  */
	{ "uscr", "\xf0\x9d\x93\x8a", 4 },
	/*  UP RIGHT DIAGONAL ELLIPSIS  */
	{ "utdot", "\xe2\x8b\xb0", 3 },
	/*  LATIN SMALL LETTER U WITH TILDE  */
	{ "utilde", "\xc5\xa9", 2 },
	/*  WHITE UP-POINTING SMALL TRIANGLE  */
	{ "utri", "\xe2\x96\xb5", 3 },
	/*  BLACK UP-POINTING SMALL TRIANGLE  */
	{ "utrif", "\xe2\x96\xb4", 3 },
	/*  UPWARDS PAIRED ARROWS  */
	{ "uuarr", "\xe2\x87\x88", 3 },
	/*  LATIN SMALL LETTER U WITH DIAERESIS  */
	{ "uuml", "\xc3\xbc", 2 },
	/*  OBLIQUE ANGLE OPENING DOWN  */
	{ "uwangle", "\xe2\xa6\xa7", 3 },
	/*  UP DOWN DOUBLE ARROW  */
	{ "vArr", "\xe2\x87\x95", 3 },
	/*  SHORT UP TACK WITH UNDERBAR  */
	{ "vBar", "\xe2\xab\xa8", 3 },
	/*  SHORT UP TACK ABOVE SHORT DOWN TACK  */
	{ "vBarv", "\xe2\xab\xa9", 3 },
	/*  TRUE  */
	{ "vDash", "\xe2\x8a\xa8", 3 },
	/*  VERTICAL BAR TRIPLE RIGHT TURNSTILE  */
	{ "vDdash", "\xe2\xab\xa2", 3 },
	/*  RIGHT ANGLE VARIANT WITH SQUARE  */
	{ "vangrt", "\xe2\xa6\x9c", 3 },
	/*  GREEK LUNATE EPSILON SYMBOL  */
	{ "varepsilon", "\xcf\xb5", 2 },
	/*  GREEK KAPPA SYMBOL  */
	{ "varkappa", "\xcf\xb0", 2 },
	/*  EMPTY SET  */
	{ "varnothing", "\xe2\x88\x85", 3 },
	/*  GREEK PHI SYMBOL  */
	{ "varphi", "\xcf\x95", 2 },
	/*  GREEK PI SYMBOL  */
	{ "varpi", "\xcf\x96", 2 },
	/*  PROPORTIONAL TO  */
	{ "varpropto", "\xe2\x88\x9d", 3 },
	/*  UP DOWN ARROW  */
	{ "varr", "\xe2\x86\x95", 3 },
	/*  GREEK RHO SYMBOL  */
	{ "varrho", "\xcf\xb1", 2 },
	/*  GREEK SMALL LETTER FINAL SIGMA  */
	{ "varsigma", "\xcf\x82", 2 },
	/*  SUBSET OF WITH NOT EQUAL TO - variant with stroke through bottom members  */
	{ "varsubsetneq", "\xe2\x8a\x8a\xef\xb8\x80", 6 },
	/*  SUBSET OF ABOVE NOT EQUAL TO - variant with stroke through bottom members  */
	{ "varsubsetneqq", "\xe2\xab\x8b\xef\xb8\x80", 6 },
	/*  SUPERSET OF WITH NOT EQUAL TO - variant with stroke through bottom members  */
	{ "varsupsetneq", "\xe2\x8a\x8b\xef\xb8\x80", 6 },
	/*  SUPERSET OF ABOVE NOT EQUAL TO - variant with stroke through bottom members  */
	{ "varsupsetneqq", "\xe2\xab\x8c\xef\xb8\x80", 6 },
	/*  GREEK THETA SYMBOL  */
	{ "vartheta", "\xcf\x91", 2 },
	/*  NORMAL SUBGROUP OF  */
	{ "vartriangleleft", "\xe2\x8a\xb2", 3 },
	/*  CONTAINS AS NORMAL SUBGROUP  */
	{ "vartriangleright", "\xe2\x8a\xb3", 3 },
	/*  VERTICAL BAR BESIDE RIGHT TRIANGLE  */
	{ "vbrtri", "\xe2\xa7\x90", 3 },
	/*  CYRILLIC SMALL LETTER VE  */
	{ "vcy", "\xd0\xb2", 2 },
	/*  RIGHT TACK  */
	{ "vdash", "\xe2\x8a\xa2", 3 },
	/*  LOGICAL OR  */
	{ "vee", "\xe2\x88\xa8", 3 },
	/*  LOGICAL OR WITH DOUBLE UNDERBAR  */
	{ "veeBar", "\xe2\xa9\xa3", 3 },
	/*  XOR  */
	{ "veebar", "\xe2\x8a\xbb", 3 },
	/*  EQUIANGULAR TO  */
	{ "veeeq", "\xe2\x89\x9a", 3 },
	/*  VERTICAL ELLIPSIS  */
	{ "vellip", "\xe2\x8b\xae", 3 },
	/*  DOTTED FENCE  */
	{ "vellip4", "\xe2\xa6\x99", 3 },
	/*  TRIPLE COLON OPERATOR  */
	{ "vellipv", "\xe2\xab\xb6", 3 },
	/*  VERTICAL LINE  */
	{ "verbar", "\x7c", 1 },
	/*  VERTICAL LINE  */
	{ "vert", "\x7c", 1 },
	/*  TRIPLE VERTICAL BAR BINARY RELATION  */
	{ "vert3", "\xe2\xab\xb4", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL V  */
	{ "vfr", "\xf0\x9d\x94\xb3", 4 },
	/*  LEFT SQUARE BRACKET LOWER CORNER  */
	{ "vldash", "\xe2\x8e\xa3", 3 },
	/*  NORMAL SUBGROUP OF  */
	{ "vltri", "\xe2\x8a\xb2", 3 },
	/*  SUBSET OF with vertical line  */
	{ "vnsub", "\xe2\x8a\x82\xe2\x83\x92", 6 },
	/*  SUPERSET OF with vertical line  */
	{ "vnsup", "\xe2\x8a\x83\xe2\x83\x92", 6 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL V  */
	{ "vopf", "\xf0\x9d\x95\xa7", 4 },
	/*  PRIME  */
	{ "vprime", "\xe2\x80\xb2", 3 },
	/*  PROPORTIONAL TO  */
	{ "vprop", "\xe2\x88\x9d", 3 },
	/*  CONTAINS AS NORMAL SUBGROUP  */
	{ "vrtri", "\xe2\x8a\xb3", 3 },
	/*  MATHEMATICAL SCRIPT SMALL V  */
	{ "vscr", "\xf0\x9d\x93\x8b", 4 },
	/*  SUBSET OF ABOVE NOT EQUAL TO - variant with stroke through bottom members  */
	{ "vsubnE", "\xe2\xab\x8b\xef\xb8\x80", 6 },
	/*  SUBSET OF WITH NOT EQUAL TO - variant with stroke through bottom members  */
	{ "vsubne", "\xe2\x8a\x8a\xef\xb8\x80", 6 },
	/*  SUPERSET OF ABOVE NOT EQUAL TO - variant with stroke through bottom members  */
	{ "vsupnE", "\xe2\xab\x8c\xef\xb8\x80", 6 },
	/*  SUPERSET OF WITH NOT EQUAL TO - variant with stroke through bottom members  */
	{ "vsupne", "\xe2\x8a\x8b\xef\xb8\x80", 6 },
	/*  VERTICAL ZIGZAG LINE  */
	{ "vzigzag", "\xe2\xa6\x9a", 3 },
	/*  LATIN SMALL LETTER W WITH CIRCUMFLEX  */
	{ "wcirc", "\xc5\xb5", 2 },
	/*  LOGICAL AND WITH UNDERBAR  */
	{ "wedbar", "\xe2\xa9\x9f", 3 },
	/*  LOGICAL AND  */
	{ "wedge", "\xe2\x88\xa7", 3 },
	/*  ESTIMATES  */
	{ "wedgeq", "\xe2\x89\x99", 3 },
	/*  SCRIPT CAPITAL P  */
	{ "weierp", "\xe2\x84\x98", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL W  */
	{ "wfr", "\xf0\x9d\x94\xb4", 4 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL W  */
	{ "wopf", "\xf0\x9d\x95\xa8", 4 },
	/*  SCRIPT CAPITAL P  */
	{ "wp", "\xe2\x84\x98", 3 },
	/*  WREATH PRODUCT  */
	{ "wr", "\xe2\x89\x80", 3 },
	/*  WREATH PRODUCT  */
	{ "wreath", "\xe2\x89\x80", 3 },
	/*  MATHEMATICAL SCRIPT SMALL W  */
	{ "wscr", "\xf0\x9d\x93\x8c", 4 },
	/*  TWO LOGICAL AND OPERATOR  */
	{ "xandand", "\xe2\xa8\x87", 3 },
	/*  BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT  */
	{ "xbsol", "\xe2\x95\xb1", 3 },
	/*  N-ARY INTERSECTION  */
	{ "xcap", "\xe2\x8b\x82", 3 },
	/*  LARGE CIRCLE  */
	{ "xcirc", "\xe2\x97\xaf", 3 },
	/*  N-ARY UNION  */
	{ "xcup", "\xe2\x8b\x83", 3 },
	/*  N-ARY UNION OPERATOR WITH DOT  */
	{ "xcupdot", "\xe2\xa8\x83", 3 },
	/*  WHITE DOWN-POINTING TRIANGLE  */
	{ "xdtri", "\xe2\x96\xbd", 3 },
	/*  MATHEMATICAL FRAKTUR SMALL X  */
	{ "xfr", "\xf0\x9d\x94\xb5", 4 },
	/*  GREEK SMALL LETTER XI  */
	{ "xgr", "\xce\xbe", 2 },
	/*  LONG LEFT RIGHT DOUBLE ARROW  */
	{ "xhArr", "\xe2\x9f\xba", 3 },
	/*  LONG LEFT RIGHT ARROW  */
	{ "xharr", "\xe2\x9f\xb7", 3 },
	/*  GREEK SMALL LETTER XI  */
	{ "xi", "\xce\xbe", 2 },
	/*  LONG LEFTWARDS DOUBLE ARROW  */
	{ "xlArr", "\xe2\x9f\xb8", 3 },
	/*  LONG LEFTWARDS ARROW  */
	{ "xlarr", "\xe2\x9f\xb5", 3 },
	/*  LONG RIGHTWARDS ARROW FROM BAR  */
	{ "xmap", "\xe2\x9f\xbc", 3 },
	/*  CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE  */
	{ "xnis", "\xe2\x8b\xbb", 3 },
	/*  N-ARY CIRCLED DOT OPERATOR  */
	{ "xodot", "\xe2\xa8\x80", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL X  */
	{ "xopf", "\xf0\x9d\x95\xa9", 4 },
	/*  N-ARY CIRCLED PLUS OPERATOR  */
	{ "xoplus", "\xe2\xa8\x81", 3 },
	/*  TWO LOGICAL OR OPERATOR  */
	{ "xoror", "\xe2\xa8\x88", 3 },
	/*  N-ARY CIRCLED TIMES OPERATOR  */
	{ "xotime", "\xe2\xa8\x82", 3 },
	/*  LONG RIGHTWARDS DOUBLE ARROW  */
	{ "xrArr", "\xe2\x9f\xb9", 3 },
	/*  LONG RIGHTWARDS ARROW  */
	{ "xrarr", "\xe2\x9f\xb6", 3 },
	/*  MATHEMATICAL SCRIPT SMALL X  */
	{ "xscr", "\xf0\x9d\x93\x8d", 4 },
	/*  BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT  */
	{ "xsol", "\xe2\x95\xb2", 3 },
	/*  N-ARY SQUARE INTERSECTION OPERATOR  */
	{ "xsqcap", "\xe2\xa8\x85", 3 },
	/*  N-ARY SQUARE UNION OPERATOR  */
	{ "xsqcup", "\xe2\xa8\x86", 3 },
	/*  WHITE MEDIUM SQUARE  */
	{ "xsqu", "\xe2\x97\xbb", 3 },
	/*  BLACK MEDIUM SQUARE  */
	{ "xsquf", "\xe2\x97\xbc", 3 },
	/*  N-ARY TIMES OPERATOR  */
	{ "xtimes", "\xe2\xa8\x89", 3 },
	/*  N-ARY UNION OPERATOR WITH PLUS  */
	{ "xuplus", "\xe2\xa8\x84", 3 },
	/*  WHITE UP-POINTING TRIANGLE  */
	{ "xutri", "\xe2\x96\xb3", 3 },
	/*  N-ARY LOGICAL OR  */
	{ "xvee", "\xe2\x8b\x81", 3 },
	/*  N-ARY LOGICAL AND  */
	{ "xwedge", "\xe2\x8b\x80", 3 },
	/*  LATIN SMALL LETTER Y WITH ACUTE  */
	{ "yacute", "\xc3\xbd", 2 },
	/*  CYRILLIC SMALL LETTER YA  */
	{ "yacy", "\xd1\x8f", 2 },
	/*  LATIN SMALL LETTER Y WITH CIRCUMFLEX  */
	{ "ycirc", "\xc5\xb7", 2 },
	/*  CYRILLIC SMALL LETTER YERU  */
	{ "ycy", "\xd1\x8b", 2 },
	/*  YEN SIGN  */
	{ "yen", "\xc2\xa5", 2 },
	/*  MATHEMATICAL FRAKTUR SMALL Y  */
	{ "yfr", "\xf0\x9d\x94\xb6", 4 },
	/*  CYRILLIC SMALL LETTER YI  */
	{ "yicy", "\xd1\x97", 2 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL Y  */
	{ "yopf", "\xf0\x9d\x95\xaa", 4 },
	/*  MATHEMATICAL SCRIPT SMALL Y  */
	{ "yscr", "\xf0\x9d\x93\x8e", 4 },
	/*  CYRILLIC SMALL LETTER YU  */
	{ "yucy", "\xd1\x8e", 2 },
	/*  LATIN SMALL LETTER Y WITH DIAERESIS  */
	{ "yuml", "\xc3\xbf", 2 },
	/*  LATIN SMALL LETTER Z WITH ACUTE  */
	{ "zacute", "\xc5\xba", 2 },
	/*  LATIN SMALL LETTER Z WITH CARON  */
	{ "zcaron", "\xc5\xbe", 2 },
	/*  CYRILLIC SMALL LETTER ZE  */
	{ "zcy", "\xd0\xb7", 2 },
	/*  LATIN SMALL LETTER Z WITH DOT ABOVE  */
	{ "zdot", "\xc5\xbc", 2 },
	/*  BLACK-LETTER CAPITAL Z  */
	{ "zeetrf", "\xe2\x84\xa8", 3 },
	/*  GREEK SMALL LETTER ZETA  */
	{ "zeta", "\xce\xb6", 2 },
	/*  MATHEMATICAL FRAKTUR SMALL Z  */
	{ "zfr", "\xf0\x9d\x94\xb7", 4 },
	/*  GREEK SMALL LETTER ZETA  */
	{ "zgr", "\xce\xb6", 2 },
	/*  CYRILLIC SMALL LETTER ZHE  */
	{ "zhcy", "\xd0\xb6", 2 },
	/*  RIGHTWARDS SQUIGGLE ARROW  */
	{ "zigrarr", "\xe2\x87\x9d", 3 },
	/*  MATHEMATICAL DOUBLE-STRUCK SMALL Z  */
	{ "zopf", "\xf0\x9d\x95\xab", 4 },
	/*  MATHEMATICAL SCRIPT SMALL Z  */
	{ "zscr", "\xf0\x9d\x93\x8f", 4 },
	/*  ZERO WIDTH JOINER  */
	{ "zwj", "\xe2\x80\x8d", 3 },
	/*  ZERO WIDTH NON-JOINER  */
	{ "zwnj", "\xe2\x80\x8c", 3 }
};

/*
*    Maxentlen: 32
*    Maxutflen: 6
*/

#endif	/*  sgent2utf.h  */

